@@ -1,5 +1,5 @@
 /*
- * Copyright © 2013 Canonical Ltd.
+ * Copyright © 2013-2014 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 3 as
@@ -18,19 +18,17 @@
 
 /// \example demo_shell.cpp A simple mir shell
 
+#include "demo_renderer.h"
 #include "window_manager.h"
 #include "fullscreen_placement_strategy.h"
 #include "../server_configuration.h"
 
+#include "mir/options/default_configuration.h"
 #include "mir/run_mir.h"
 #include "mir/report_exception.h"
-#include "mir/shell/session_manager.h"
-#include "mir/shell/registration_order_focus_sequence.h"
-#include "mir/shell/default_focus_mechanism.h"
-#include "mir/shell/session_container.h"
-#include "mir/shell/organising_surface_factory.h"
 #include "mir/graphics/display.h"
 #include "mir/input/composite_event_filter.h"
+#include "mir/compositor/renderer_factory.h"
 
 #include <iostream>
 
@@ -39,24 +37,41 @@ namespace msh = mir::shell;
 namespace mg = mir::graphics;
 namespace mf = mir::frontend;
 namespace mi = mir::input;
+namespace mo = mir::options;
 
 namespace mir
 {
 namespace examples
 {
 
-struct DemoServerConfiguration : mir::examples::ServerConfiguration
+class DemoRendererFactory : public compositor::RendererFactory
 {
+public:
+    std::unique_ptr<compositor::Renderer> create_renderer_for(
+        geometry::Rectangle const& rect) override
+    {
+        return std::unique_ptr<compositor::Renderer>(new DemoRenderer(rect));
+    }
+};
+
+class DemoServerConfiguration : public mir::examples::ServerConfiguration
+{
+public:
     DemoServerConfiguration(int argc, char const* argv[],
                             std::initializer_list<std::shared_ptr<mi::EventFilter>> const& filter_list)
-      : ServerConfiguration(argc, argv),
+      : ServerConfiguration([argc, argv]
+        {
+            auto result = std::make_shared<mo::DefaultConfiguration>(argc, argv);
+
+            namespace po = boost::program_options;
+
+            result->add_options()
+                ("fullscreen-surfaces", "Make all surfaces fullscreen");
+
+            return result;
+        }()),
         filter_list(filter_list)
     {
-        namespace po = boost::program_options;
-
-        add_options()
-            ("fullscreen-surfaces", po::value<bool>(),
-                "Make all surfaces fullscreen [bool:default=false]");
     }
 
     std::shared_ptr<msh::PlacementStrategy> the_shell_placement_strategy() override
@@ -80,6 +95,12 @@ struct DemoServerConfiguration : mir::examples::ServerConfiguration
         return composite_filter;
     }
 
+    std::shared_ptr<compositor::RendererFactory> the_renderer_factory() override
+    {
+        return std::make_shared<DemoRendererFactory>();
+    }
+
+private:
     std::vector<std::shared_ptr<mi::EventFilter>> const filter_list;
 };
 
@@ -97,7 +118,6 @@ try
             // We use this strange two stage initialization to avoid a circular dependency between the EventFilters
             // and the SessionStore
             wm->set_focus_controller(config.the_focus_controller());
-            wm->set_session_manager(config.the_session_manager());
             wm->set_display(config.the_display());
             wm->set_compositor(config.the_compositor());
         });
