@@ -21,6 +21,7 @@
 
 #include "mir/input/event_filter.h"
 #include "mir/geometry/displacement.h"
+#include "mir/geometry/size.h"
 
 #include <memory>
 
@@ -29,7 +30,6 @@ namespace mir
 namespace shell
 {
 class FocusController;
-class SessionManager;
 }
 namespace graphics
 {
@@ -49,7 +49,6 @@ public:
     ~WindowManager() = default;
 
     void set_focus_controller(std::shared_ptr<shell::FocusController> const& focus_controller);
-    void set_session_manager(std::shared_ptr<shell::SessionManager> const& sm);
     void set_display(std::shared_ptr<graphics::Display> const& display);
     void set_compositor(std::shared_ptr<compositor::Compositor> const& compositor);
     
@@ -61,12 +60,14 @@ protected:
 
 private:
     std::shared_ptr<shell::FocusController> focus_controller;
-    std::shared_ptr<shell::SessionManager> session_manager;
     std::shared_ptr<graphics::Display> display;
     std::shared_ptr<compositor::Compositor> compositor;
 
-    geometry::Displacement relative_click;  // Click location in window space
-    geometry::Point click;                  // Click location in screen space
+    geometry::Point click;
+    geometry::Point old_pos;
+    geometry::Point old_cursor;
+    geometry::Size old_size;
+    float old_pinch_diam;
     int max_fingers;  // Maximum number of fingers touched during gesture
 };
 
