@@ -23,6 +23,7 @@
 #include <signal.h>
 #include <time.h>
 #include <EGL/egl.h>
+#include <GLES2/gl2.h>
 
 #include <xkbcommon/xkbcommon-keysyms.h>
 
@@ -75,6 +76,7 @@ void mir_eglapp_swap_buffers(void)
     time_t now = time(NULL);
     time_t dtime;
     int dcount;
+    EGLint width, height;
 
     if (!running)
         return;
@@ -90,9 +92,21 @@ void mir_eglapp_swap_buffers(void)
         lasttime = now;
         lastcount = count;
     }
+
+    /*
+     * Querying the surface (actually the current buffer) dimensions here is
+     * the only truly safe way to be sure that the dimensions we think we
+     * have are those of the buffer being rendered to. But this should be
+     * improved in future; https://bugs.launchpad.net/mir/+bug/1194384
+     */
+    if (eglQuerySurface(egldisplay, eglsurface, EGL_WIDTH, &width) &&
+        eglQuerySurface(egldisplay, eglsurface, EGL_HEIGHT, &height))
+    {
+        glViewport(0, 0, width, height);
+    }
 }
 
-static void mir_eglapp_handle_input(MirSurface* surface, MirEvent const* ev, void* context)
+static void mir_eglapp_handle_event(MirSurface* surface, MirEvent const* ev, void* context)
 {
     (void) surface;
     (void) context;
@@ -102,22 +116,16 @@ static void mir_eglapp_handle_input(MirSurface* surface, MirEvent const* ev, voi
     {
         running = 0;
     }
-}
-
-static unsigned int get_bpp(MirPixelFormat pf)
-{
-    switch (pf)
+    else if (ev->type == mir_event_type_resize)
     {
-        case mir_pixel_format_abgr_8888:
-        case mir_pixel_format_xbgr_8888:
-        case mir_pixel_format_argb_8888:
-        case mir_pixel_format_xrgb_8888:
-            return 32;
-        case mir_pixel_format_bgr_888:
-            return 24;
-        case mir_pixel_format_invalid:
-        default:
-            return 0;
+        /*
+         * FIXME: https://bugs.launchpad.net/mir/+bug/1194384
+         * It is unsafe to set the width and height here because we're in a
+         * different thread to that doing the rendering. So we either need
+         * support for event queuing (directing them to another thread) or
+         * full single-threaded callbacks. (LP: #1194384).
+         */
+        printf("Resized to %dx%d\n", ev->resize.width, ev->resize.height);
     }
 }
 
@@ -162,7 +170,7 @@ mir_eglapp_bool mir_eglapp_init(int argc, char *argv[],
     };
     MirEventDelegate delegate = 
     {
-        mir_eglapp_handle_input,
+        mir_eglapp_handle_event,
         NULL
     };
     EGLConfig eglconfig;
@@ -255,6 +263,12 @@ mir_eglapp_bool mir_eglapp_init(int argc, char *argv[],
                 case 'm':
                     mir_socket = argv[++i];
                     break;
+                case 'q':
+                    {
+                        FILE *unused = freopen("/dev/null", "a", stdout);
+                        (void)unused;
+                        break;
+                    }
                 case 'h':
                 default:
                     help = 1;
@@ -276,6 +290,7 @@ mir_eglapp_bool mir_eglapp_init(int argc, char *argv[],
                        "  -n               Don't sync to vblank\n"
                        "  -m socket        Mir server socket\n"
                        "  -s WIDTHxHEIGHT  Force surface size\n"
+                       "  -q               Quiet mode (no messages output)\n"
                        , argv[0]);
                 return 0;
             }
@@ -300,12 +315,11 @@ mir_eglapp_bool mir_eglapp_init(int argc, char *argv[],
 
     const MirDisplayMode *mode = &output->modes[output->current_mode];
 
-    const unsigned int max_formats = 10;
-    unsigned int format[max_formats];
+    unsigned int format[mir_pixel_formats];
     unsigned int nformats;
 
     mir_connection_get_available_surface_formats(connection,
-        format, max_formats, &nformats);
+        format, mir_pixel_formats, &nformats);
 
     surfaceparm.pixel_format = format[0];
     for (unsigned int f = 0; f < nformats; f++)
@@ -322,19 +336,18 @@ mir_eglapp_bool mir_eglapp_init(int argc, char *argv[],
         }
     }
 
-    printf("Connected to display: resolution (%dx%d), position(%dx%d), "
-           "supports %d pixel formats\n",
+    printf("Current active output is %dx%d %+d%+d\n",
            mode->horizontal_resolution, mode->vertical_resolution,
-           output->position_x, output->position_y,
-           output->num_output_formats);
+           output->position_x, output->position_y);
 
     surfaceparm.width = *width > 0 ? *width : mode->horizontal_resolution;
     surfaceparm.height = *height > 0 ? *height : mode->vertical_resolution;
 
     mir_display_config_destroy(display_config);
 
-    printf("Using pixel format #%d\n", surfaceparm.pixel_format);
-    unsigned int bpp = get_bpp(surfaceparm.pixel_format);
+    printf("Server supports %d of %d surface pixel formats. Using format: %d\n",
+        nformats, mir_pixel_formats, surfaceparm.pixel_format);
+    unsigned int bpp = 8 * MIR_BYTES_PER_PIXEL(surfaceparm.pixel_format);
     EGLint attribs[] =
     {
         EGL_SURFACE_TYPE, EGL_WINDOW_BIT,
