@@ -1,5 +1,5 @@
 /*
- * Copyright © 2012 Canonical Ltd.
+ * Copyright © 2012-2014 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 3 as
@@ -16,8 +16,10 @@
  * Authored by: Alexandros Frantzis <alexandros.frantzis@canonical.com>
  */
 
-#include "mir/compositor/default_display_buffer_compositor_factory.h"
+#include "mir/compositor/display_buffer_compositor_factory.h"
+#include "mir/server_status_listener.h"
 #include "mir/compositor/display_buffer_compositor.h"
+#include "mir/options/default_configuration.h"
 #include "mir/graphics/graphic_buffer_allocator.h"
 #include "mir/frontend/connector.h"
 #include "mir/shell/surface_creation_parameters.h"
@@ -27,16 +29,22 @@
 #include "mir/graphics/cursor.h"
 #include "mir/graphics/display.h"
 #include "mir/graphics/display_buffer.h"
-#include "mir/shell/surface_builder.h"
-#include "mir/surfaces/surface.h"
+#include "mir/graphics/gl_context.h"
+#include "mir/shell/surface_factory.h"
+#include "mir/scene/surface.h"
+#include "mir/scene/surface_coordinator.h"
 #include "mir/run_mir.h"
 #include "mir/report_exception.h"
+#include "mir/raii.h"
 
 #include "mir_image.h"
 #include "buffer_render_target.h"
 #include "image_renderer.h"
 #include "server_configuration.h"
 
+#define GLM_FORCE_RADIANS
+#include <glm/gtc/matrix_transform.hpp>
+
 #include <thread>
 #include <atomic>
 #include <chrono>
@@ -45,16 +53,17 @@
 #include <sstream>
 #include <vector>
 
-#include <glm/gtc/matrix_transform.hpp>
-
 namespace mg = mir::graphics;
 namespace mc = mir::compositor;
-namespace ms = mir::surfaces;
+namespace ms = mir::scene;
 namespace mf = mir::frontend;
+namespace mo = mir::options;
 namespace msh = mir::shell;
 namespace mi = mir::input;
 namespace geom = mir::geometry;
 namespace mt = mir::tools;
+namespace me = mir::examples;
+
 
 ///\page render_surfaces-example render_surfaces.cpp: A simple program using the mir library.
 ///\tableofcontents
@@ -80,10 +89,12 @@ namespace mt = mir::tools;
 
 namespace
 {
+std::atomic<bool> created{false};
 bool input_is_on = false;
 std::weak_ptr<mg::Cursor> cursor;
 static const uint32_t bg_color = 0x00000000;
 static const uint32_t fg_color = 0xffdd4814;
+static const float min_alpha = 0.3f;
 
 void update_cursor(uint32_t bg_color, uint32_t fg_color)
 {
@@ -184,16 +195,16 @@ class Moveable
 {
 public:
     Moveable() {}
-    Moveable(ms::Surface& s, const geom::Size& display_size,
+    Moveable(std::shared_ptr<msh::Surface> const& s, const geom::Size& display_size,
              float dx, float dy, const glm::vec3& rotation_axis, float alpha_offset)
-        : surface(&s), display_size(display_size),
-          x{static_cast<float>(s.top_left().x.as_uint32_t())},
-          y{static_cast<float>(s.top_left().y.as_uint32_t())},
-          w{static_cast<float>(s.size().width.as_uint32_t())},
-          h{static_cast<float>(s.size().height.as_uint32_t())},
+        : surface(s), display_size(display_size),
+          x{static_cast<float>(s->top_left().x.as_uint32_t())},
+          y{static_cast<float>(s->top_left().y.as_uint32_t())},
+          w{static_cast<float>(s->size().width.as_uint32_t())},
+          h{static_cast<float>(s->size().height.as_uint32_t())},
           dx{dx},
           dy{dy},
-          rotation_axis{rotation_axis},
+          rotation_axis(rotation_axis),
           alpha_offset{alpha_offset}
     {
     }
@@ -227,12 +238,20 @@ public:
             y = new_y;
         }
 
-        surface->set_rotation(total_elapsed_sec * 120.0f, rotation_axis);
-        surface->set_alpha(0.5 + 0.5 * sin(alpha_offset + 2 * M_PI * total_elapsed_sec / 3.0));
+        glm::mat4 trans = glm::rotate(glm::mat4(1.0f),
+                                      glm::radians(total_elapsed_sec * 120.0f),
+                                      rotation_axis);
+        surface->set_transformation(trans);
+
+        float const alpha_amplitude = (1.0f - min_alpha) / 2.0f;
+        surface->set_alpha(min_alpha + alpha_amplitude +
+                           alpha_amplitude *
+                           sin(alpha_offset + 2 * M_PI * total_elapsed_sec /
+                               3.0));
     }
 
 private:
-    ms::Surface* surface;
+    std::shared_ptr<msh::Surface> surface;
     geom::Size display_size;
     float x;
     float y;
@@ -248,20 +267,25 @@ private:
 
 ///\internal [RenderSurfacesServerConfiguration_tag]
 // Extend the default configuration to manage moveables.
-class RenderSurfacesServerConfiguration : public mir::examples::ServerConfiguration
+class RenderSurfacesServerConfiguration : public me::ServerConfiguration
 {
 public:
-    RenderSurfacesServerConfiguration(int argc, char const** argv)
-        : ServerConfiguration(argc, argv)
-    {
-        namespace po = boost::program_options;
+    RenderSurfacesServerConfiguration(int argc, char const** argv) :
+        ServerConfiguration([argc, argv]
+        {
+            auto result = std::make_shared<mo::DefaultConfiguration>(argc, argv);
 
-        add_options()
-            (surfaces_to_render, po::value<int>(),  "Number of surfaces to render"
-                                                    " [int:default=5]")
-            (display_cursor, po::value<bool>(), "Display test cursor. (If input is "
-                                                "disabled it gets animated.) "
-                                                "[bool:default=false]");
+            namespace po = boost::program_options;
+
+            result->add_options()
+                (surfaces_to_render, po::value<int>()->default_value(5),
+                    "Number of surfaces to render")
+                (display_cursor, po::value<bool>()->default_value(false),
+                    "Display test cursor. (If input is disabled it gets animated.)");
+
+            return result;
+        }())
+    {
     }
 
     ///\internal [RenderSurfacesServerConfiguration_stubs_tag]
@@ -287,12 +311,17 @@ public:
         class RenderResourcesBufferInitializer : public mg::BufferInitializer
         {
         public:
-            RenderResourcesBufferInitializer()
+            RenderResourcesBufferInitializer(std::unique_ptr<mg::GLContext> gl_context)
+                : gl_context{std::move(gl_context)}
             {
             }
 
             void operator()(mg::Buffer& buffer)
             {
+                auto using_gl_context = mir::raii::paired_calls(
+                    [this] { gl_context->make_current(); },
+                    [this] { gl_context->release_current(); });
+
                 mt::ImageRenderer img_renderer{mir_image.pixel_data,
                                geom::Size{mir_image.width, mir_image.height},
                                mir_image.bytes_per_pixel};
@@ -300,12 +329,41 @@ public:
                 brt.make_current();
                 img_renderer.render();
             }
+
+        private:
+            std::unique_ptr<mg::GLContext> const gl_context;
+
         };
 
-        return std::make_shared<RenderResourcesBufferInitializer>();
+        return std::make_shared<RenderResourcesBufferInitializer>(the_display()->create_gl_context());
     }
     ///\internal [RenderResourcesBufferInitializer_tag]
 
+    // Unless the compositor starts before we create the surfaces it won't respond to
+    // the change notification that causes.
+    std::shared_ptr<mir::ServerStatusListener> the_server_status_listener()
+    {
+        struct ServerStatusListener : mir::ServerStatusListener
+        {
+            ServerStatusListener(std::function<void()> create_surfaces, std::shared_ptr<mir::ServerStatusListener> wrapped) :
+                create_surfaces(create_surfaces), wrapped(wrapped) {}
+
+            virtual void paused() override { wrapped->paused(); }
+            virtual void resumed() override { wrapped->resumed(); }
+            virtual void started() override { wrapped->started(); create_surfaces(); create_surfaces = []{}; }
+
+            std::function<void()> create_surfaces;
+            std::shared_ptr<mir::ServerStatusListener> const wrapped;
+        };
+
+        return server_status_listener(
+            [this]()
+            {
+                auto wrapped = ServerConfiguration::the_server_status_listener();
+                return std::make_shared<ServerStatusListener>([this] { create_surfaces(); }, wrapped);
+            });
+    }
+
     ///\internal [RenderSurfacesDisplayBufferCompositor_tag]
     // Decorate the DefaultDisplayBufferCompositor in order to move surfaces.
     std::shared_ptr<mc::DisplayBufferCompositorFactory> the_display_buffer_compositor_factory() override
@@ -322,8 +380,9 @@ public:
             {
             }
 
-            void composite()
+            bool composite()
             {
+                while (!created) std::this_thread::yield();
                 animate_cursor();
                 stop_watch.stop();
                 if (stop_watch.elapsed_seconds_since_last_restart() >= 1)
@@ -340,6 +399,7 @@ public:
                     m.step();
 
                 frames++;
+                return false;
             }
 
         private:
@@ -349,32 +409,32 @@ public:
             uint32_t frames;
         };
 
-        class RenderSurfacesDisplayBufferCompositorFactory : public mc::DefaultDisplayBufferCompositorFactory
+        class RenderSurfacesDisplayBufferCompositorFactory : public mc::DisplayBufferCompositorFactory
         {
         public:
             RenderSurfacesDisplayBufferCompositorFactory(
-                std::shared_ptr<mc::Scene> const& scene,
-                std::shared_ptr<mc::RendererFactory> const& renderer_factory,
-                std::shared_ptr<mc::OverlayRenderer> const& overlay_renderer,
+                std::shared_ptr<mc::DisplayBufferCompositorFactory> const& factory,
                 std::vector<Moveable>& moveables)
-                : DefaultDisplayBufferCompositorFactory{scene, renderer_factory, overlay_renderer},
+                : factory{factory},
                   moveables(moveables)
             {
             }
 
             std::unique_ptr<mc::DisplayBufferCompositor> create_compositor_for(mg::DisplayBuffer& display_buffer)
             {
-                auto cs = DefaultDisplayBufferCompositorFactory::create_compositor_for(display_buffer);
-                auto raw = new RenderSurfacesDisplayBufferCompositor(std::move(cs), moveables);
+                auto compositor = factory->create_compositor_for(display_buffer);
+                auto raw = new RenderSurfacesDisplayBufferCompositor(
+                    std::move(compositor), moveables);
                 return std::unique_ptr<RenderSurfacesDisplayBufferCompositor>(raw);
             }
+
+        private:
+            std::shared_ptr<mc::DisplayBufferCompositorFactory> const factory;
             std::vector<Moveable>& moveables;
         };
 
         return std::make_shared<RenderSurfacesDisplayBufferCompositorFactory>(
-            the_scene(),
-            the_renderer_factory(),
-            the_overlay_renderer(),
+            me::ServerConfiguration::the_display_buffer_compositor_factory(),
             moveables);
     }
     ///\internal [RenderSurfacesDisplayBufferCompositor_tag]
@@ -382,11 +442,11 @@ public:
     // New function to initialize moveables with surfaces
     void create_surfaces()
     {
-        moveables.resize(the_options()->get(surfaces_to_render, 5));
+        moveables.resize(the_options()->get<int>(surfaces_to_render));
         std::cout << "Rendering " << moveables.size() << " surfaces" << std::endl;
 
         auto const display = the_display();
-        auto const surface_builder = the_surface_builder();
+        auto const surface_coordinator = the_surface_coordinator();
         /* TODO: Get proper configuration */
         geom::Rectangles view_area;
         display->for_each_display_buffer([&view_area](mg::DisplayBuffer const& db)
@@ -405,18 +465,23 @@ public:
         int i = 0;
         for (auto& m : moveables)
         {
-            std::shared_ptr<ms::Surface> s = surface_builder->create_surface(
-                    nullptr,
+            auto const s = surface_coordinator->add_surface(
                     msh::a_surface().of_size(surface_size)
                                    .of_pixel_format(surface_pf)
-                                   .of_buffer_usage(mg::BufferUsage::hardware)
-                    ).lock();
+                                   .of_buffer_usage(mg::BufferUsage::hardware),
+                    {});
 
             /*
-             * Let the system know that the surface is suitable for rendering
-             * (i.e., that it contains buffers with valid contents).
+             * We call swap_buffers() twice so that the surface is
+             * considers the first buffer to be posted.
+             * (TODO There must be a better way!)
              */
-            s->flag_for_render();
+            {
+                mg::Buffer* buffer{nullptr};
+                auto const complete = [&](mg::Buffer* new_buf){ buffer = new_buf; };
+                s->swap_buffers(buffer, complete);
+                s->swap_buffers(buffer, complete);
+            }
 
             /*
              * Place each surface at a different starting location and give it a
@@ -426,23 +491,25 @@ public:
             uint32_t const y = h * (0.5 + 0.25 * sin(i * angular_step)) - surface_side / 2.0;
 
             s->move_to({x, y});
-            m = Moveable(*s, display_size,
+            m = Moveable(s, display_size,
                     cos(0.1f + i * M_PI / 6.0f) * w / 3.0f,
                     sin(0.1f + i * M_PI / 6.0f) * h / 3.0f,
                     glm::vec3{(i % 3 == 0) * 1.0f, (i % 3 == 1) * 1.0f, (i % 3 == 2) * 1.0f},
                     2.0f * M_PI * cos(i));
             ++i;
         }
+
+        created = true;
     }
 
     bool input_is_on()
     {
-        return the_options()->get("enable-input", ::input_is_on);
+        return the_options()->get<bool>(mo::enable_input_opt);
     }
 
     std::weak_ptr<mg::Cursor> the_cursor()
     {
-        if (the_options()->get(display_cursor, false))
+        if (the_options()->get<bool>(display_cursor))
         {
             return the_display()->the_cursor();
         }
@@ -466,8 +533,6 @@ try
 
     mir::run_mir(conf, [&](mir::DisplayServer&)
     {
-        conf.create_surfaces();
-
         cursor = conf.the_cursor();
 
         input_is_on = conf.input_is_on();
