@@ -21,15 +21,12 @@
 #include "mir/default_server_configuration.h"
 #include "mir/graphics/display.h"
 #include "mir/graphics/display_buffer.h"
-#include "mir/graphics/default_display_configuration_policy.h"
-#include "mir/graphics/platform.h"
 #include "mir/report_exception.h"
 
 #include <csignal>
 #include <iostream>
 
 namespace mg=mir::graphics;
-namespace ml=mir::logging;
 namespace mo=mir::options;
 
 namespace
@@ -56,8 +53,7 @@ try
 
     mir::DefaultServerConfiguration conf{argc, argv};
 
-    auto platform = conf.the_graphics_platform();
-    auto display = platform->create_display(std::make_shared<mg::DefaultDisplayConfigurationPolicy>());
+    auto display = conf.the_display();
 
     mir::draw::glAnimationBasic gl_animation;
 
