@@ -27,6 +27,8 @@
 extern "C" {
 #endif
 
+struct gbm_device;
+
 typedef void (*mir_drm_auth_magic_callback)(int status, void *context);
 
 /* Authenticates a DRM magic cookie */
@@ -35,6 +37,18 @@ MirWaitHandle *mir_connection_drm_auth_magic(MirConnection *connection,
                                              mir_drm_auth_magic_callback callback,
                                              void *context);
 
+/**
+ * Set the gbm_device to be used by the EGL implementation.
+ * This is required if the application needs to create EGLImages from
+ * gbm buffers objects created on that gbm device.
+ * \param [in] connection  The connection
+ * \param [in] dev         The gbm_device to set
+ * \return                 A non-zero value if the operation was successful,
+ *                         0 otherwise
+ */
+int mir_connection_drm_set_gbm_device(MirConnection* connection,
+                                      struct gbm_device* dev);
+
 #ifdef __cplusplus
 }
 /**@}*/
