@@ -19,27 +19,34 @@
 #ifndef MIR_COMPOSITOR_RENDERER_H_
 #define MIR_COMPOSITOR_RENDERER_H_
 
-#include <memory>
-#include <functional>
+#include "mir/geometry/rectangle.h"
 
 namespace mir
 {
-namespace surfaces
+namespace graphics
 {
-class BufferStream;
+class Buffer;
+class Renderable;
 }
 namespace compositor
 {
-class CompositingCriteria;
 
 class Renderer
 {
 public:
     virtual ~Renderer() = default;
 
-    virtual void clear(unsigned long frameno) = 0;
-    virtual void render(std::function<void(std::shared_ptr<void> const&)> save_resource,
-                                           CompositingCriteria const& info, surfaces::BufferStream& stream) = 0;
+    virtual void set_viewport(geometry::Rectangle const& rect) = 0;
+    virtual void set_rotation(float degrees) = 0;
+    virtual void begin() const = 0;
+
+    // XXX The buffer parameter here could now be replaced with
+    //     renderable::buffer().
+    virtual void render(graphics::Renderable const& renderable,
+                        graphics::Buffer& buffer) const = 0;
+    virtual void end() const = 0;
+
+    virtual void suspend() = 0; // called when begin/render/end skipped
 
 protected:
     Renderer() = default;
