@@ -20,26 +20,23 @@
 #define MIR_COMPOSITOR_SCENE_H_
 
 #include "mir/geometry/forward.h"
+#include "mir/graphics/renderable.h"
 
 #include <memory>
 #include <functional>
 
 namespace mir
 {
-namespace surfaces
-{
-class BufferStream;
-}
+namespace graphics { class Renderable; }
 namespace compositor
 {
-class CompositingCriteria;
 
 class FilterForScene
 {
 public:
     virtual ~FilterForScene() {}
 
-    virtual bool operator()(CompositingCriteria const&) = 0;
+    virtual bool operator()(graphics::Renderable const&) = 0;
 
 protected:
     FilterForScene() = default;
@@ -52,7 +49,7 @@ class OperatorForScene
 public:
     virtual ~OperatorForScene() {}
 
-    virtual void operator()(CompositingCriteria const&, surfaces::BufferStream&) = 0;
+    virtual void operator()(graphics::Renderable const&) = 0;
 
 protected:
     OperatorForScene() = default;
@@ -66,6 +63,13 @@ class Scene
 public:
     virtual ~Scene() {}
 
+    /**
+     * Generate a valid list of renderables based on the current state of the Scene.
+     * \returns a list of mg::Renderables. The list is in stacking order from back to front.
+     */
+    virtual graphics::RenderableList generate_renderable_list() const = 0;
+
+    // Back to front; normal rendering order
     virtual void for_each_if(FilterForScene& filter, OperatorForScene& op) = 0;
 
     /**
@@ -73,7 +77,7 @@ public:
      * Scene changes.
      *
      * The supplied callback should not directly or indirectly (e.g.,
-     * by changing a property of a Renderable) change the state of
+     * by changing a property of a surface) change the state of
      * the Scene, otherwise a deadlock may occur.
      */
     virtual void set_change_callback(std::function<void()> const& f) = 0;
