@@ -1,5 +1,5 @@
 /*
- * Copyright © 2012 Canonical Ltd.
+ * Copyright © 2012-2014 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3,
@@ -20,7 +20,6 @@
 
 #include "mir/cached_ptr.h"
 #include "mir/server_configuration.h"
-#include "mir/options/program_option.h"
 
 #include <memory>
 #include <string>
@@ -35,8 +34,8 @@ class Scene;
 class Drawer;
 class DisplayBufferCompositorFactory;
 class Compositor;
-class OverlayRenderer;
 class RendererFactory;
+class CompositorReport;
 }
 namespace frontend
 {
@@ -50,41 +49,43 @@ class MessageProcessorReport;
 class SessionAuthorizer;
 class EventSink;
 class DisplayChanger;
+class Screencast;
 }
 
 namespace shell
 {
 class SurfaceFactory;
-class SurfaceBuilder;
-class SurfaceController;
 class InputTargeter;
-class SessionContainer;
 class FocusSetter;
-class FocusSequence;
 class PlacementStrategy;
 class SessionListener;
 class FocusController;
-class SessionManager;
-class PixelBuffer;
-class SnapshotStrategy;
 class DisplayLayout;
-class SurfaceConfigurator;
-class MediatingDisplayChanger;
-class SessionEventSink;
-class SessionEventHandlerRegister;
-class BroadcastingSessionEventSink;
 }
 namespace time
 {
-class TimeSource;
+class Clock;
 }
-namespace surfaces
+namespace scene
 {
+class SurfaceFactory;
+class BroadcastingSessionEventSink;
 class BufferStreamFactory;
+class MediatingDisplayChanger;
+class PixelBuffer;
+class SessionContainer;
+class SessionEventSink;
+class SessionEventHandlerRegister;
+class SessionManager;
+class SnapshotStrategy;
+class SurfaceCoordinator;
+class SurfaceConfigurator;
 class SurfaceStackModel;
 class SurfaceStack;
+class SurfaceRanker;
 class SurfaceController;
 class InputRegistrar;
+class SceneReport;
 }
 namespace graphics
 {
@@ -93,6 +94,7 @@ class Display;
 class BufferInitializer;
 class DisplayReport;
 class GraphicBufferAllocator;
+class GLConfig;
 namespace nested { class HostConnection; }
 }
 namespace input
@@ -105,6 +107,7 @@ class InputConfiguration;
 class CursorListener;
 class InputRegion;
 class NestedInputRelay;
+class EventHandler;
 }
 
 namespace logging
@@ -112,10 +115,22 @@ namespace logging
 class Logger;
 }
 
+namespace options
+{
+class Option;
+class Configuration;
+}
+
+namespace report
+{
+class ReportFactory;
+}
+
 class DefaultServerConfiguration : public virtual ServerConfiguration
 {
 public:
     DefaultServerConfiguration(int argc, char const* argv[]);
+    explicit DefaultServerConfiguration(std::shared_ptr<options::Configuration> const& configuration_options);
 
     /** @name DisplayServer dependencies
      * dependencies of DisplayServer on the rest of the Mir
@@ -125,7 +140,7 @@ public:
     virtual std::shared_ptr<compositor::Compositor> the_compositor();
     virtual std::shared_ptr<input::InputManager>    the_input_manager();
     virtual std::shared_ptr<MainLoop>               the_main_loop();
-    virtual std::shared_ptr<PauseResumeListener>    the_pause_resume_listener();
+    virtual std::shared_ptr<ServerStatusListener>   the_server_status_listener();
     virtual std::shared_ptr<DisplayChanger>         the_display_changer();
     virtual std::shared_ptr<graphics::Platform>     the_graphics_platform();
     virtual std::shared_ptr<input::InputConfiguration> the_input_configuration();
@@ -138,7 +153,8 @@ public:
     virtual std::shared_ptr<compositor::RendererFactory>   the_renderer_factory();
     virtual std::shared_ptr<graphics::DisplayConfigurationPolicy> the_display_configuration_policy();
     virtual std::shared_ptr<graphics::nested::HostConnection> the_host_connection();
-    virtual std::shared_ptr<input::NestedInputRelay> the_nested_input_relay();
+    virtual std::shared_ptr<input::EventFilter> the_nested_event_filter();
+    virtual std::shared_ptr<graphics::GLConfig> the_gl_config();
     /** @} */
 
     /** @name graphics configuration - dependencies
@@ -150,8 +166,8 @@ public:
     /** @name compositor configuration - customization
      * configurable interfaces for modifying compositor
      *  @{ */
+    virtual std::shared_ptr<compositor::CompositorReport> the_compositor_report();
     virtual std::shared_ptr<compositor::DisplayBufferCompositorFactory> the_display_buffer_compositor_factory();
-    virtual std::shared_ptr<compositor::OverlayRenderer>          the_overlay_renderer();
     /** @} */
 
     /** @name compositor configuration - dependencies
@@ -170,6 +186,7 @@ public:
     virtual std::shared_ptr<frontend::Shell>                  the_frontend_shell();
     virtual std::shared_ptr<frontend::EventSink>              the_global_event_sink();
     virtual std::shared_ptr<frontend::DisplayChanger>         the_frontend_display_changer();
+    virtual std::shared_ptr<frontend::Screencast>             the_screencast();
     /** @name frontend configuration - internal dependencies
      * internal dependencies of frontend
      *  @{ */
@@ -184,38 +201,33 @@ public:
      * configurable interfaces for modifying shell
      *  @{ */
     virtual std::shared_ptr<shell::SurfaceFactory>      the_shell_surface_factory();
-    virtual std::shared_ptr<shell::SessionContainer>    the_shell_session_container();
     virtual std::shared_ptr<shell::FocusSetter>         the_shell_focus_setter();
-    virtual std::shared_ptr<shell::FocusSequence>       the_shell_focus_sequence();
     virtual std::shared_ptr<shell::PlacementStrategy>   the_shell_placement_strategy();
     virtual std::shared_ptr<shell::SessionListener>     the_shell_session_listener();
-    virtual std::shared_ptr<shell::PixelBuffer>         the_shell_pixel_buffer();
-    virtual std::shared_ptr<shell::SnapshotStrategy>    the_shell_snapshot_strategy();
     virtual std::shared_ptr<shell::DisplayLayout>       the_shell_display_layout();
-    virtual std::shared_ptr<shell::SurfaceConfigurator> the_shell_surface_configurator();
-    virtual std::shared_ptr<shell::SessionEventSink>    the_shell_session_event_sink();
-    virtual std::shared_ptr<shell::SessionEventHandlerRegister> the_shell_session_event_handler_register();
     /** @} */
 
-    /** @name shell configuration - dependencies
-     * dependencies of shell on the rest of the Mir
+    /** @name internal scene configuration
+     * builder functions used in the default implementation.
+     * The interfaces returned are not published, so the functions are only useful in tests
      *  @{ */
-    virtual std::shared_ptr<shell::SurfaceBuilder>     the_surface_builder();
-    virtual std::shared_ptr<surfaces::SurfaceController>     the_surface_controller();
-
+    virtual std::shared_ptr<scene::PixelBuffer>       the_pixel_buffer();
+    virtual std::shared_ptr<scene::SnapshotStrategy>  the_snapshot_strategy();
+    virtual std::shared_ptr<scene::SessionContainer>  the_session_container();
+    virtual std::shared_ptr<scene::SessionEventSink>  the_session_event_sink();
+    virtual std::shared_ptr<scene::SessionEventHandlerRegister> the_session_event_handler_register();
+    virtual std::shared_ptr<scene::SurfaceStackModel> the_surface_stack_model();
+    virtual std::shared_ptr<scene::SurfaceRanker>     the_surface_ranker();
+    virtual std::shared_ptr<scene::SurfaceFactory>    the_surface_factory();
+    virtual std::shared_ptr<scene::SurfaceCoordinator>the_surface_coordinator();
+    virtual std::shared_ptr<scene::SurfaceConfigurator> the_surface_configurator();
     /** @} */
 
-
-    /** @name surfaces configuration - customization
-     * configurable interfaces for modifying surfaces
+    /** @name scene configuration - dependencies
+     * dependencies of scene on the rest of the Mir
      *  @{ */
-    virtual std::shared_ptr<surfaces::SurfaceStackModel> the_surface_stack_model();
-    /** @} */
-
-    /** @name surfaces configuration - dependencies
-     * dependencies of surfaces on the rest of the Mir
-     *  @{ */
-    virtual std::shared_ptr<surfaces::BufferStreamFactory> the_buffer_stream_factory();
+    virtual std::shared_ptr<scene::BufferStreamFactory> the_buffer_stream_factory();
+    virtual std::shared_ptr<scene::SceneReport>      the_scene_report();
     /** @} */
 
 
@@ -223,7 +235,7 @@ public:
      *  @{ */
     virtual std::shared_ptr<input::InputReport> the_input_report();
     virtual std::shared_ptr<input::CompositeEventFilter> the_composite_event_filter();
-    virtual std::shared_ptr<surfaces::InputRegistrar> the_input_registrar();
+    virtual std::shared_ptr<scene::InputRegistrar> the_input_registrar();
     virtual std::shared_ptr<shell::InputTargeter> the_input_targeter();
     virtual std::shared_ptr<input::CursorListener> the_cursor_listener();
     virtual std::shared_ptr<input::InputRegion>    the_input_region();
@@ -235,25 +247,18 @@ public:
     virtual std::shared_ptr<logging::Logger> the_logger();
     /** @} */
 
-    virtual std::shared_ptr<time::TimeSource>    the_time_source();
-
-    virtual std::shared_ptr<shell::SessionManager> the_session_manager();
+    virtual std::shared_ptr<time::Clock> the_clock();
 
 protected:
-    // add_options() allows configuration specializations to add their
-    // own options. This MUST be called before the first invocation of
-    // the_options() - typically during construction.
-    boost::program_options::options_description_easy_init add_options();
-    virtual void parse_options(boost::program_options::options_description& options_description, options::ProgramOption& options) const;
-    virtual std::shared_ptr<options::Option> the_options() const;
+    std::shared_ptr<options::Option> the_options() const;
 
     virtual std::shared_ptr<input::InputChannelFactory> the_input_channel_factory();
-    virtual std::shared_ptr<shell::MediatingDisplayChanger> the_mediating_display_changer();
-    virtual std::shared_ptr<shell::BroadcastingSessionEventSink> the_broadcasting_session_event_sink();
+    virtual std::shared_ptr<scene::MediatingDisplayChanger> the_mediating_display_changer();
+    virtual std::shared_ptr<frontend::ProtobufIpcFactory> the_ipc_factory(
+        std::shared_ptr<frontend::Shell> const& shell,
+        std::shared_ptr<graphics::GraphicBufferAllocator> const& allocator);
 
     CachedPtr<frontend::Connector>   connector;
-    CachedPtr<shell::SessionManager> session_manager;
-
 
     CachedPtr<input::InputConfiguration> input_configuration;
 
@@ -261,7 +266,7 @@ protected:
     CachedPtr<input::CompositeEventFilter> composite_event_filter;
     CachedPtr<input::InputManager>    input_manager;
     CachedPtr<input::InputRegion>     input_region;
-    CachedPtr<surfaces::InputRegistrar> input_registrar;
+    CachedPtr<scene::InputRegistrar> input_registrar;
     CachedPtr<shell::InputTargeter> input_targeter;
     CachedPtr<input::CursorListener> cursor_listener;
     CachedPtr<graphics::Platform>     graphics_platform;
@@ -276,49 +281,54 @@ protected:
     CachedPtr<frontend::SessionAuthorizer> session_authorizer;
     CachedPtr<frontend::EventSink> global_event_sink;
     CachedPtr<frontend::SessionCreator>    session_creator;
+    CachedPtr<frontend::Screencast> screencast;
     CachedPtr<compositor::RendererFactory> renderer_factory;
     CachedPtr<compositor::BufferStreamFactory> buffer_stream_factory;
-    CachedPtr<surfaces::SurfaceStack> surface_stack;
+    CachedPtr<scene::SurfaceStack> surface_stack;
+    CachedPtr<scene::SceneReport> scene_report;
+
     CachedPtr<shell::SurfaceFactory> shell_surface_factory;
-    CachedPtr<shell::SessionContainer>  shell_session_container;
+    CachedPtr<scene::SurfaceFactory> surface_factory;
+    CachedPtr<scene::SessionContainer>  session_container;
     CachedPtr<shell::FocusSetter>       shell_focus_setter;
-    CachedPtr<shell::FocusSequence>     shell_focus_sequence;
     CachedPtr<shell::PlacementStrategy> shell_placement_strategy;
     CachedPtr<shell::SessionListener> shell_session_listener;
-    CachedPtr<shell::PixelBuffer>       shell_pixel_buffer;
-    CachedPtr<shell::SnapshotStrategy>  shell_snapshot_strategy;
+    CachedPtr<scene::PixelBuffer>       pixel_buffer;
+    CachedPtr<scene::SnapshotStrategy>  snapshot_strategy;
     CachedPtr<shell::DisplayLayout>     shell_display_layout;
-    CachedPtr<shell::SurfaceConfigurator> shell_surface_configurator;
+    CachedPtr<scene::SurfaceConfigurator> surface_configurator;
     CachedPtr<compositor::DisplayBufferCompositorFactory> display_buffer_compositor_factory;
-    CachedPtr<compositor::OverlayRenderer> overlay_renderer;
     CachedPtr<compositor::Compositor> compositor;
+    CachedPtr<compositor::CompositorReport> compositor_report;
     CachedPtr<logging::Logger> logger;
     CachedPtr<graphics::DisplayReport> display_report;
-    CachedPtr<surfaces::SurfaceController> surface_controller;
-    CachedPtr<time::TimeSource> time_source;
+    CachedPtr<time::Clock> clock;
     CachedPtr<MainLoop> main_loop;
-    CachedPtr<PauseResumeListener> pause_resume_listener;
+    CachedPtr<ServerStatusListener> server_status_listener;
     CachedPtr<graphics::DisplayConfigurationPolicy> display_configuration_policy;
     CachedPtr<graphics::nested::HostConnection> host_connection;
-    CachedPtr<input::NestedInputRelay> nested_input_relay;
-    CachedPtr<shell::MediatingDisplayChanger> mediating_display_changer;
-    CachedPtr<shell::BroadcastingSessionEventSink> broadcasting_session_event_sink;
-
-    int default_ipc_threads = 10;
+    CachedPtr<scene::MediatingDisplayChanger> mediating_display_changer;
+    CachedPtr<graphics::GLConfig> gl_config;
 
 private:
-    int const argc;
-    char const** const argv;
-    std::shared_ptr<boost::program_options::options_description> const program_options;
+    std::shared_ptr<options::Configuration> const configuration_options;
     std::shared_ptr<input::EventFilter> const default_filter;
-    std::shared_ptr<options::Option> mutable options;
-
-    // the communications interface to use
-    virtual std::shared_ptr<frontend::ProtobufIpcFactory> the_ipc_factory(
-        std::shared_ptr<frontend::Shell> const& shell,
-        std::shared_ptr<graphics::GraphicBufferAllocator> const& allocator);
 
     virtual std::string the_socket_file() const;
+
+    // The following caches and factory functions are internal to the
+    // default implementations of corresponding the Mir components
+    CachedPtr<scene::BroadcastingSessionEventSink> broadcasting_session_event_sink;
+    CachedPtr<input::NestedInputRelay> nested_input_relay;
+    CachedPtr<scene::SurfaceController> surface_controller;
+    CachedPtr<scene::SessionManager> session_manager;
+
+    std::shared_ptr<scene::BroadcastingSessionEventSink> the_broadcasting_session_event_sink();
+    std::shared_ptr<input::NestedInputRelay>        the_nested_input_relay();
+    std::shared_ptr<scene::SessionManager>       the_session_manager();
+    std::shared_ptr<scene::SurfaceController>    the_surface_controller();
+
+    auto report_factory(char const* report_opt) -> std::unique_ptr<report::ReportFactory>;
 };
 }
 
