@@ -27,16 +27,16 @@ namespace mir
 {
 namespace input
 {
-class Surface 
+class Surface
 {
 public:
-    virtual std::string const& name() const = 0;
-    virtual geometry::Point position() const = 0;
+    virtual std::string name() const = 0;
+    virtual geometry::Point top_left() const = 0;
     virtual geometry::Size size() const = 0;
     virtual bool contains(geometry::Point const& point) const = 0;
 
 protected:
-    Surface() = default; 
+    Surface() = default;
     virtual ~Surface() = default;
     Surface(const Surface&) = delete;
     Surface& operator=(const Surface& ) = delete;
