@@ -49,7 +49,7 @@ class InputConfiguration;
 }
 
 class MainLoop;
-class PauseResumeListener;
+class ServerStatusListener;
 class DisplayChanger;
 
 class ServerConfiguration
@@ -62,7 +62,7 @@ public:
     virtual std::shared_ptr<compositor::Compositor> the_compositor() = 0;
     virtual std::shared_ptr<input::InputManager> the_input_manager() = 0;
     virtual std::shared_ptr<MainLoop> the_main_loop() = 0;
-    virtual std::shared_ptr<PauseResumeListener> the_pause_resume_listener() = 0;
+    virtual std::shared_ptr<ServerStatusListener> the_server_status_listener() = 0;
     virtual std::shared_ptr<DisplayChanger> the_display_changer() = 0;
     virtual std::shared_ptr<graphics::Platform>  the_graphics_platform() = 0;
     virtual std::shared_ptr<input::InputConfiguration> the_input_configuration() = 0;
