@@ -24,6 +24,7 @@ namespace mir
 
 namespace shell
 {
+class Session;
 struct SurfaceCreationParameters;
 
 class PlacementStrategy
@@ -32,7 +33,7 @@ public:
     virtual ~PlacementStrategy() {}
     // TODO: It is strange to work in terms of SurfaceCreationParameters here,
     // perhaps a new interface is needed.
-    virtual SurfaceCreationParameters place(SurfaceCreationParameters const& request_parameters) = 0;
+    virtual SurfaceCreationParameters place(shell::Session const& session, SurfaceCreationParameters const& request_parameters) = 0;
 
 
 protected:
