@@ -19,12 +19,12 @@
 #ifndef MIR_SHELL_SURFACE_CREATION_PARAMETERS_H_
 #define MIR_SHELL_SURFACE_CREATION_PARAMETERS_H_
 
-#include "mir/geometry/pixel_format.h"
+#include "mir_toolkit/common.h"
 #include "mir/geometry/point.h"
 #include "mir/geometry/size.h"
 #include "mir/graphics/buffer_properties.h"
 #include "mir/graphics/display_configuration.h"
-#include "mir/surfaces/depth_id.h"
+#include "mir/scene/depth_id.h"
 #include "mir/input/input_reception_mode.h"
 
 #include <memory>
@@ -44,15 +44,15 @@ struct SurfaceCreationParameters
     SurfaceCreationParameters& of_size(geometry::Size new_size);
 
     SurfaceCreationParameters& of_size(geometry::Width::ValueType width, geometry::Height::ValueType height);
-    
+
     SurfaceCreationParameters& of_position(geometry::Point const& top_left);
 
     SurfaceCreationParameters& of_buffer_usage(graphics::BufferUsage new_buffer_usage);
 
-    SurfaceCreationParameters& of_pixel_format(geometry::PixelFormat new_pixel_format);
-    
-    SurfaceCreationParameters& of_depth(surfaces::DepthId const& new_depth);
-    
+    SurfaceCreationParameters& of_pixel_format(MirPixelFormat new_pixel_format);
+
+    SurfaceCreationParameters& of_depth(scene::DepthId const& new_depth);
+
     SurfaceCreationParameters& with_input_mode(input::InputReceptionMode const& new_mode);
 
     SurfaceCreationParameters& with_output_id(graphics::DisplayConfigurationOutputId const& output_id);
@@ -61,8 +61,8 @@ struct SurfaceCreationParameters
     geometry::Size size;
     geometry::Point top_left;
     graphics::BufferUsage buffer_usage;
-    geometry::PixelFormat pixel_format;
-    surfaces::DepthId depth;
+    MirPixelFormat pixel_format;
+    scene::DepthId depth;
     input::InputReceptionMode input_mode;
     graphics::DisplayConfigurationOutputId output_id;
 };
