@@ -25,7 +25,7 @@
 
 namespace mir
 {
-namespace graphics 
+namespace graphics
 {
 namespace android
 {
@@ -39,7 +39,9 @@ public:
     int query(int key, int* value) const;
     int perform(int key, va_list args );
     int dequeueBuffer(struct ANativeWindowBuffer** buffer, int* fence);
+    int dequeueBufferAndWait(struct ANativeWindowBuffer** buffer);
     int queueBuffer(struct ANativeWindowBuffer* buffer, int fence);
+    int cancelBuffer(struct ANativeWindowBuffer* buffer, int fence);
     int setSwapInterval(int interval);
 private:
 
