@@ -34,11 +34,18 @@
 extern "C" {
 #endif
 
+typedef enum MirBool
+{
+    mir_false = 0,
+    mir_true = 1
+} MirBool;
+
 /* Display server connection API */
 typedef void* MirEGLNativeWindowType;
 typedef void* MirEGLNativeDisplayType;
 typedef struct MirConnection MirConnection;
 typedef struct MirSurface MirSurface;
+typedef struct MirScreencast MirScreencast;
 
 /**
  * Returned by asynchronous functions. Must not be free'd by
@@ -96,25 +103,6 @@ typedef void (*mir_lifecycle_event_callback)(
 typedef void (*mir_display_config_callback)(
     MirConnection* connection, void* context);
 
-/**
- * The order of components in a format enum matches the
- * order of the components as they would be written in an
- *  integer representing a pixel value of that format.
- *
- * For example, abgr_8888 corresponds to 0xAABBGGRR, which will
- * end up as R,G,B,A in memory in a little endian system, and
- * as A,B,G,R in memory in a big endian system.
- */
-typedef enum MirPixelFormat
-{
-    mir_pixel_format_invalid,
-    mir_pixel_format_abgr_8888,
-    mir_pixel_format_xbgr_8888,
-    mir_pixel_format_argb_8888,
-    mir_pixel_format_xrgb_8888,
-    mir_pixel_format_bgr_888
-} MirPixelFormat;
-
 /**
  * MirBufferUsage specifies how a surface can and will be used. A "hardware"
  * surface can be used for OpenGL accelerated rendering. A "software" surface
@@ -156,7 +144,7 @@ enum { mir_platform_package_max = 32 };
 typedef enum MirPlatformType
 {
     mir_platform_type_gbm,
-    mir_platform_type_android    
+    mir_platform_type_android
 } MirPlatformType;
 
 typedef struct MirPlatformPackage
@@ -183,7 +171,7 @@ typedef struct MirGraphicsRegion
 
 } MirGraphicsRegion;
 
-/** 
+/**
  * DEPRECATED. use MirDisplayConfiguration
  */
 enum { mir_supported_pixel_format_max = 32 };
@@ -191,7 +179,7 @@ typedef struct MirDisplayInfo
 {
     uint32_t width;
     uint32_t height;
-    
+
     int supported_pixel_format_items;
     MirPixelFormat supported_pixel_format[mir_supported_pixel_format_max];
 } MirDisplayInfo;
@@ -239,11 +227,11 @@ typedef struct MirDisplayOutput
     uint32_t num_modes;
     MirDisplayMode* modes;
     uint32_t preferred_mode;
-    uint32_t current_mode; 
+    uint32_t current_mode;
 
     uint32_t num_output_formats;
     MirPixelFormat* output_formats;
-    uint32_t current_output_format;
+    MirPixelFormat current_format;
 
     uint32_t card_id;
     uint32_t output_id;
@@ -256,8 +244,9 @@ typedef struct MirDisplayOutput
 
     uint32_t physical_width_mm;
     uint32_t physical_height_mm;
-    
+
     MirPowerMode power_mode;
+    MirOrientation orientation;
 } MirDisplayOutput;
 
 typedef struct MirDisplayConfiguration
@@ -278,6 +267,45 @@ typedef struct MirEventDelegate
     void *context;
 } MirEventDelegate;
 
+typedef struct MirRectangle
+{
+    int left;
+    int top;
+    unsigned int width;
+    unsigned int height;
+} MirRectangle;
+
+/**
+ * MirScreencastParameters is the structure of required information that
+ * you must provide to Mir in order to create a MirScreencast.
+ * The width and height parameters can be used to down-scale the screencast
+ * For no scaling set them to the region width and height.
+ */
+typedef struct MirScreencastParameters
+{
+    /**
+     * The rectangular region of the screen to capture -
+     * The region is specified in virtual screen space hence multiple screens can be captured simultaneously
+     */
+    MirRectangle region;
+    /** The width of the screencast which can be different than the screen region capture width */
+    unsigned int width;
+    /** The height of the screencast which can be different than the screen region capture height */
+    unsigned int height;
+    /**
+     * The pixel format of the screencast.
+     * It must be a supported format obtained from mir_connection_get_available_surface_formats.
+     */
+    MirPixelFormat pixel_format;
+} MirScreencastParameters;
+
+/**
+ * Callback to be passed when calling MirScreencast functions.
+ *   \param [in] screencast          the screencast being updated
+ *   \param [in,out] client_context  context provided by the client
+ */
+typedef void (*mir_screencast_callback)(MirScreencast *screencast, void *client_context);
+
 #ifdef __cplusplus
 }
 /**@}*/
