@@ -37,7 +37,7 @@ typedef enum MirSurfaceAttrib
     mir_surface_attrib_state,
     mir_surface_attrib_swapinterval,
     mir_surface_attrib_focus,
-    mir_surface_attrib_enum_max_
+    mir_surface_attribs
 } MirSurfaceAttrib;
 
 typedef enum MirSurfaceType
@@ -49,7 +49,7 @@ typedef enum MirSurfaceType
     mir_surface_type_freestyle,
     mir_surface_type_popover,
     mir_surface_type_inputmethod,
-    mir_surface_type_enum_max_
+    mir_surface_types
 } MirSurfaceType;
 
 typedef enum MirSurfaceState
@@ -63,14 +63,13 @@ typedef enum MirSurfaceState
        Omitted for now, since it's functionally a subset of vertmaximized and
        differs only in the X coordinate. */
     mir_surface_state_fullscreen,
-    mir_surface_state_enum_max_
+    mir_surface_states
 } MirSurfaceState;
 
 typedef enum MirSurfaceFocusState
 {
     mir_surface_unfocused = 0,
-    mir_surface_focused,
-    mir_surface_focus_enum_max_
+    mir_surface_focused
 } MirSurfaceFocusState;
 
 typedef enum MirLifecycleState
@@ -87,6 +86,38 @@ typedef enum MirPowerMode
     mir_power_mode_suspend, /* Blanked, lowest power. */
     mir_power_mode_off /* Powered down. */
 } MirPowerMode;
+
+/**
+ * The order of components in a format enum matches the
+ * order of the components as they would be written in an
+ *  integer representing a pixel value of that format.
+ *
+ * For example, abgr_8888 corresponds to 0xAABBGGRR, which will
+ * end up as R,G,B,A in memory in a little endian system, and
+ * as A,B,G,R in memory in a big endian system.
+ */
+typedef enum MirPixelFormat
+{
+    mir_pixel_format_invalid,
+    mir_pixel_format_abgr_8888,
+    mir_pixel_format_xbgr_8888,
+    mir_pixel_format_argb_8888,
+    mir_pixel_format_xrgb_8888,
+    mir_pixel_format_bgr_888,
+    mir_pixel_formats
+} MirPixelFormat;
+
+/* This could be improved... https://bugs.launchpad.net/mir/+bug/1236254 */
+#define MIR_BYTES_PER_PIXEL(f) (((f) == mir_pixel_format_bgr_888) ? 3 : 4)
+
+typedef enum MirOrientation
+{
+    mir_orientation_normal = 0,
+    mir_orientation_left = 90,
+    mir_orientation_inverted = 180,
+    mir_orientation_right = 270
+} MirOrientation;
+
 /**@}*/
 
 #endif
