@@ -20,7 +20,7 @@
 #ifndef MIR_CLIENT_MIR_NATIVE_BUFFER_H_
 #define MIR_CLIENT_MIR_NATIVE_BUFFER_H_
 
-enum { mir_buffer_package_max = 31 };
+enum { mir_buffer_package_max = 30 };
 
 typedef enum
 {
@@ -33,10 +33,14 @@ typedef struct MirBufferPackage
     int fd_items;
 
     int data[mir_buffer_package_max];
-    int unused1;  /* Retain ABI compatibility (avoid rebuilding Mesa) */
+
+    int width;  /* These must come after data[] to keep ABI compatibility */
+    int height;
 
     int fd[mir_buffer_package_max];
 
+    int unused0;  /* Retain ABI compatibility (avoid rebuilding Mesa) */
+
     unsigned int flags;  /* MirBufferFlag's */
     int stride;
     int age; /**< Number of frames submitted by the client since the client has rendered to this buffer. */
@@ -48,6 +52,6 @@ typedef struct MirBufferPackage
 struct ANativeWindowBuffer;
 typedef struct ANativeWindowBuffer MirNativeBuffer;
 #else
-typedef struct MirBufferPackage MirNativeBuffer; 
+typedef struct MirBufferPackage MirNativeBuffer;
 #endif
 #endif /* MIR_CLIENT_MIR_NATIVE_BUFFER_H_ */
