@@ -29,7 +29,7 @@ namespace test
 {
 namespace doubles
 {
-struct MockFrontendSurface : public frontend::ClientTrackingSurface
+struct MockFrontendSurface : public frontend::Surface
 {
     MockFrontendSurface()
     {
@@ -39,10 +39,10 @@ struct MockFrontendSurface : public frontend::ClientTrackingSurface
 
     MOCK_METHOD0(destroy, void());
     MOCK_METHOD0(force_requests_to_complete, void());
-    MOCK_METHOD0(advance_client_buffer, std::shared_ptr<graphics::Buffer>());
+    MOCK_METHOD2(swap_buffers, void(graphics::Buffer*, std::function<void(graphics::Buffer*)> complete));
 
     MOCK_CONST_METHOD0(size, geometry::Size());
-    MOCK_CONST_METHOD0(pixel_format, geometry::PixelFormat());
+    MOCK_CONST_METHOD0(pixel_format, MirPixelFormat());
 
     MOCK_CONST_METHOD0(supports_input, bool());
     MOCK_CONST_METHOD0(client_input_fd, int());
