@@ -18,7 +18,7 @@
 #ifndef MIR_TEST_DOUBLES_MOCK_INTERPRETER_RESOURCE_CACHE_H_
 #define MIR_TEST_DOUBLES_MOCK_INTERPRETER_RESOURCE_CACHE_H_
 
-#include "src/server/graphics/android/interpreter_resource_cache.h"
+#include "src/platform/graphics/android/interpreter_resource_cache.h"
 
 namespace mir
 {
