@@ -33,11 +33,12 @@ namespace doubles
 
 struct MockSurfaceFactory : public shell::SurfaceFactory
 {
-    MOCK_METHOD4(create_surface, std::shared_ptr<shell::Surface>(
+    MOCK_METHOD3(create_surface, std::shared_ptr<shell::Surface>(
         shell::Session*,
         const shell::SurfaceCreationParameters&,
-        frontend::SurfaceId,
-        std::shared_ptr<frontend::EventSink> const&));
+        std::shared_ptr<scene::SurfaceObserver> const&));
+
+    void destroy_surface(std::shared_ptr<shell::Surface> const& /*surface*/) override {}
 };
 
 }
