@@ -29,13 +29,13 @@ namespace doubles
 {
 class NullDisplayConfiguration : public graphics::DisplayConfiguration
 {
-    void for_each_card(std::function<void(graphics::DisplayConfigurationCard const&)>) const
+    void for_each_card(std::function<void(graphics::DisplayConfigurationCard const&)>) const override
     {
     }
-    void for_each_output(std::function<void(graphics::DisplayConfigurationOutput const&)>) const
+    void for_each_output(std::function<void(graphics::DisplayConfigurationOutput const&)>) const override
     {
     }
-    void configure_output(graphics::DisplayConfigurationOutputId, bool, geometry::Point, size_t, MirPowerMode) override
+    void for_each_output(std::function<void(graphics::UserDisplayConfigurationOutput&)>) override
     {
     }
 };
