@@ -29,6 +29,8 @@ namespace doubles
 struct NullEventSink : public frontend::EventSink
 {
     void handle_event(MirEvent const&) {}
+    void handle_lifecycle_event(MirLifecycleState) {}
+    void handle_display_config_change(graphics::DisplayConfiguration const&) {}
 };
 }
 }
