@@ -39,7 +39,8 @@ class NullPlatform : public graphics::Platform
     }
 
     std::shared_ptr<graphics::Display> create_display(
-        std::shared_ptr<graphics::DisplayConfigurationPolicy> const&)
+        std::shared_ptr<graphics::DisplayConfigurationPolicy> const&,
+        std::shared_ptr<graphics::GLConfig> const&)
     {
         return std::make_shared<NullDisplay>();
     }
@@ -54,10 +55,14 @@ class NullPlatform : public graphics::Platform
         return std::shared_ptr<graphics::InternalClient>();
     }
 
-    void fill_ipc_package(std::shared_ptr<graphics::BufferIPCPacker> const&,
-                          std::shared_ptr<graphics::Buffer> const&) const
+    void fill_ipc_package(graphics::BufferIPCPacker*, graphics::Buffer const*) const
     {
     }
+
+    EGLNativeDisplayType egl_native_display() const
+    {
+        return EGLNativeDisplayType();
+    }
 };
 }
 }
