@@ -19,7 +19,7 @@
 #ifndef MIR_TEST_DOUBLES_NULL_SURFACE_CONFIGURATOR_H_
 #define MIR_TEST_DOUBLES_NULL_SURFACE_CONFIGURATOR_H_
 
-#include "mir/shell/surface_configurator.h"
+#include "mir/scene/surface_configurator.h"
 
 namespace mir
 {
@@ -28,14 +28,14 @@ namespace test
 namespace doubles
 {
 
-struct NullSurfaceConfigurator : public shell::SurfaceConfigurator
+struct NullSurfaceConfigurator : public scene::SurfaceConfigurator
 {
-    int select_attribute_value(shell::Surface const&,
+    int select_attribute_value(scene::Surface const&,
                                MirSurfaceAttrib, int requested_value)
     {
         return requested_value;
     }
-    void attribute_set(shell::Surface const&,
+    void attribute_set(scene::Surface const&,
                        MirSurfaceAttrib, int)
     {
     }
