@@ -39,22 +39,33 @@ class StubBuffer : public graphics::BufferBasic
 {
 public:
     StubBuffer()
-        : buf_size{0, 0},
-          buf_pixel_format{geometry::PixelFormat::abgr_8888}
+        : StubBuffer{
+              graphics::BufferProperties{
+                  geometry::Size{},
+                  mir_pixel_format_abgr_8888,
+                  graphics::BufferUsage::hardware}}
+
     {
     }
 
     StubBuffer(graphics::BufferProperties const& properties)
+        : StubBuffer{properties, geometry::Stride{}}
+    {
+    }
+
+    StubBuffer(graphics::BufferProperties const& properties,
+               geometry::Stride stride)
         : buf_size{properties.size},
-          buf_pixel_format{properties.format}
+          buf_pixel_format{properties.format},
+          buf_stride{stride}
     {
     }
 
     virtual geometry::Size size() const { return buf_size; }
 
-    virtual geometry::Stride stride() const { return geometry::Stride(); }
+    virtual geometry::Stride stride() const { return buf_stride; }
 
-    virtual geometry::PixelFormat pixel_format() const { return buf_pixel_format; }
+    virtual MirPixelFormat pixel_format() const { return buf_pixel_format; }
 
     virtual std::shared_ptr<graphics::NativeBuffer> native_buffer_handle() const
     {
@@ -69,7 +80,8 @@ public:
     virtual bool can_bypass() const override { return false; }
 
     geometry::Size const buf_size;
-    geometry::PixelFormat const buf_pixel_format;
+    MirPixelFormat const buf_pixel_format;
+    geometry::Stride const buf_stride;
 };
 }
 }
