@@ -37,24 +37,16 @@ namespace doubles
 
 struct StubBufferAllocator : public graphics::GraphicBufferAllocator
 {
-    StubBufferAllocator() : id{1} {}
-
     std::shared_ptr<graphics::Buffer> alloc_buffer(
-        graphics::BufferProperties const&)
+        graphics::BufferProperties const& properties)
     {
-        graphics::BufferProperties properties{geometry::Size{id, id},
-                                        geometry::PixelFormat::abgr_8888,
-                                        graphics::BufferUsage::hardware};
-        ++id;
         return std::make_shared<StubBuffer>(properties);
     }
 
-    std::vector<geometry::PixelFormat> supported_pixel_formats()
+    std::vector<MirPixelFormat> supported_pixel_formats()
     {
         return {};
     }
-
-    unsigned int id;
 };
 
 }
