@@ -1,5 +1,5 @@
 /*
- * Copyright © 2012 Canonical Ltd.
+ * Copyright © 2012-2014 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3,
@@ -21,9 +21,8 @@
 #define MIR_TEST_DOUBLES_STUB_IPC_FACTORY_H_
 
 #include "mir_test/fake_shared.h"
-#include "mir/frontend/protobuf_ipc_factory.h"
-#include "mir/frontend/resource_cache.h"
-#include "mir/frontend/null_message_processor_report.h"
+#include "src/server/frontend/protobuf_ipc_factory.h"
+#include "src/server/frontend/resource_cache.h"
 
 namespace mir
 {
@@ -42,22 +41,17 @@ public:
     }
 
     std::shared_ptr<protobuf::DisplayServer> make_ipc_server(
-        std::shared_ptr<frontend::EventSink> const&, bool)
+        pid_t, std::shared_ptr<frontend::EventSink> const&) override
     {
         return server;
     }
 
 private:
-    virtual std::shared_ptr<frontend::ResourceCache> resource_cache()
+    virtual std::shared_ptr<frontend::ResourceCache> resource_cache() override
     {
         return cache;
     }
 
-    virtual std::shared_ptr<frontend::MessageProcessorReport> report()
-    {
-        return std::make_shared<frontend::NullMessageProcessorReport>();
-    }
-
     std::shared_ptr<protobuf::DisplayServer> server;
     std::shared_ptr<frontend::ResourceCache> const cache;
 };
