@@ -52,8 +52,6 @@ class FakeEventHubInputConfiguration;
 namespace mir_test_framework
 {
 
-enum ClientLifecycleState { starting, appeared, vanished };
-
 class InputTestingServerConfiguration : public TestingServerConfiguration
 {
 public:
@@ -61,26 +59,20 @@ public:
 
     void exec();
     void on_exit();
-    
+
     std::shared_ptr<mir::input::InputConfiguration> the_input_configuration() override;
-    std::shared_ptr<mir::frontend::Shell> the_frontend_shell() override;
+
+    mir::input::android::FakeEventHub* fake_event_hub;
 
 protected:
     virtual void inject_input() = 0;
-    mir::input::android::FakeEventHub* fake_event_hub;
 
     void wait_until_client_appears(std::string const& surface_name);
 
 private:
-    std::mutex lifecycle_lock;
-
-    std::condition_variable lifecycle_condition;
-    std::map<std::string, ClientLifecycleState> client_lifecycles;
-    
     std::thread input_injection_thread;
-    
+
     std::shared_ptr<mir::test::doubles::FakeEventHubInputConfiguration> input_configuration;
-    std::shared_ptr<mir::frontend::Shell> frontend_shell;
 };
 
 }
