@@ -22,7 +22,6 @@
 #include "android_client_buffer_factory.h"
 #include "client_surface_interpreter.h"
 #include "../mir_connection.h"
-#include "../native_client_platform_factory.h"
 
 #include <EGL/egl.h>
 
@@ -44,12 +43,6 @@ struct EmptyDeleter
 
 }
 
-std::shared_ptr<mcl::ClientPlatform>
-mcl::NativeClientPlatformFactory::create_client_platform(mcl::ClientContext* /*context*/)
-{
-    return std::make_shared<mcla::AndroidClientPlatform>();
-}
-
 std::shared_ptr<mcl::ClientBufferFactory> mcla::AndroidClientPlatform::create_buffer_factory()
 {
     const hw_module_t *hw_module;
@@ -105,9 +98,9 @@ mcla::AndroidClientPlatform::create_egl_native_display()
 
 MirPlatformType mcla::AndroidClientPlatform::platform_type() const
 {
-    return mir_platform_type_android; 
+    return mir_platform_type_android;
 }
- 
+
 MirNativeBuffer* mcla::AndroidClientPlatform::convert_native_buffer(graphics::NativeBuffer* buf) const
 {
     return buf->anwb();
