@@ -29,7 +29,7 @@ mcla::ClientSurfaceInterpreter::ClientSurfaceInterpreter(ClientSurface& surface)
  :  surface(surface),
     driver_pixel_format(-1),
     sync_ops(std::make_shared<mga::RealSyncFileOps>())
-    
+
 {
 }
 
@@ -43,16 +43,13 @@ mir::graphics::NativeBuffer* mcla::ClientSurfaceInterpreter::driver_requests_buf
     return buffer_to_driver.get();
 }
 
-static void empty(MirSurface * /*surface*/, void * /*client_context*/)
-{}
-
 void mcla::ClientSurfaceInterpreter::driver_returns_buffer(ANativeWindowBuffer*, int fence_fd)
 {
     //TODO: pass fence to server instead of waiting here
     mga::SyncFence sync_fence(sync_ops, fence_fd);
     sync_fence.wait();
 
-    mir_wait_for(surface.next_buffer(empty, NULL));
+    surface.request_and_wait_for_next_buffer();
 }
 
 void mcla::ClientSurfaceInterpreter::dispatch_driver_request_format(int format)
@@ -75,7 +72,7 @@ int mcla::ClientSurfaceInterpreter::driver_requests_info(int key) const
         case NATIVE_WINDOW_TRANSFORM_HINT:
             return 0;
         case NATIVE_WINDOW_MIN_UNDEQUEUED_BUFFERS:
-            return 1;
+            return 2;
         default:
             throw std::runtime_error("driver requested unsupported query");
     }
