@@ -22,7 +22,6 @@
 
 #include "mir/graphics/native_buffer.h"
 #include "mir_toolkit/common.h"
-#include "mir/geometry/pixel_format.h"
 #include "mir/geometry/size.h"
 
 #include <memory>
@@ -46,7 +45,7 @@ struct MemoryRegion
     geometry::Width width;
     geometry::Height height;
     geometry::Stride stride;
-    geometry::PixelFormat format;
+    MirPixelFormat format;
     std::shared_ptr<char> vaddr;
 };
 
@@ -54,14 +53,20 @@ class ClientBuffer
 {
 public:
     virtual ~ClientBuffer() = default;
+
     virtual std::shared_ptr<MemoryRegion> secure_for_cpu_write() = 0;
     virtual geometry::Size size() const = 0;
     virtual geometry::Stride stride() const = 0;
-    virtual geometry::PixelFormat pixel_format() const = 0;
+    virtual MirPixelFormat pixel_format() const = 0;
     virtual uint32_t age() const = 0;
     virtual void increment_age() = 0;
     virtual void mark_as_submitted() = 0;
     virtual std::shared_ptr<graphics::NativeBuffer> native_buffer_handle() const = 0;
+
+protected:
+    ClientBuffer() = default;
+    ClientBuffer(ClientBuffer const&) = delete;
+    ClientBuffer& operator=(ClientBuffer const&) = delete;
 };
 
 }
