@@ -21,6 +21,7 @@
 #include "mir/graphics/native_buffer.h"
 #include "mir_toolkit/client_types.h"
 #include "mir_toolkit/mir_native_buffer.h"
+#include "egl_native_window_factory.h"
 
 #include <EGL/eglplatform.h>
 #include <memory>
@@ -37,7 +38,7 @@ class ClientContext;
  * Interface to client-side platform specific support for graphics operations.
  * \ingroup platform_enablement
  */
-class ClientPlatform
+class ClientPlatform : public EGLNativeWindowFactory
 {
 public:
     ClientPlatform() = default;
@@ -46,7 +47,7 @@ public:
 
     virtual ~ClientPlatform() { /* TODO: make nothrow */ }
 
-    virtual MirPlatformType platform_type() const = 0; 
+    virtual MirPlatformType platform_type() const = 0;
     virtual std::shared_ptr<ClientBufferFactory> create_buffer_factory() = 0;
     virtual std::shared_ptr<EGLNativeWindowType> create_egl_native_window(ClientSurface *surface) = 0;
     virtual std::shared_ptr<EGLNativeDisplayType> create_egl_native_display() = 0;
