@@ -21,6 +21,8 @@
 
 #include <memory>
 
+namespace google { namespace protobuf { class RpcChannel; } }
+
 namespace mir
 {
 
@@ -40,12 +42,7 @@ class Logger;
 namespace client
 {
 
-namespace rpc
-{
-class MirBasicRpcChannel;
-}
-
-class SurfaceMap;
+class ConnectionSurfaceMap;
 class Logger;
 class ClientPlatformFactory;
 class DisplayConfiguration;
@@ -56,8 +53,8 @@ class ConnectionConfiguration
 public:
     virtual ~ConnectionConfiguration() = default;
 
-    virtual std::shared_ptr<SurfaceMap> the_surface_map() = 0;
-    virtual std::shared_ptr<rpc::MirBasicRpcChannel> the_rpc_channel() = 0;
+    virtual std::shared_ptr<ConnectionSurfaceMap> the_surface_map() = 0;
+    virtual std::shared_ptr<google::protobuf::RpcChannel> the_rpc_channel() = 0;
     virtual std::shared_ptr<mir::logging::Logger> the_logger() = 0;
     virtual std::shared_ptr<ClientPlatformFactory> the_client_platform_factory() = 0;
     virtual std::shared_ptr<input::receiver::InputPlatform> the_input_platform() = 0;
