@@ -22,12 +22,16 @@
 #include "rpc/make_rpc_channel.h"
 #include "rpc/null_rpc_report.h"
 #include "mir/logging/dumb_console_logger.h"
-#include "native_client_platform_factory.h"
 #include "mir/input/input_platform.h"
+#include "mir/input/null_input_receiver_report.h"
 #include "logging/rpc_report.h"
+#include "logging/input_receiver_report.h"
 #include "lttng/rpc_report.h"
+#include "lttng/input_receiver_report.h"
 #include "connection_surface_map.h"
 #include "lifecycle_control.h"
+#include "mir/shared_library.h"
+#include "client_platform_factory.h"
 
 namespace mcl = mir::client;
 
@@ -36,6 +40,23 @@ namespace
 std::string const off_opt_val{"off"};
 std::string const log_opt_val{"log"};
 std::string const lttng_opt_val{"lttng"};
+std::string const default_platform_lib{"libmirclientplatform.so"};
+
+mir::SharedLibrary const* load_library(std::string const& libname)
+{
+    // There's no point in loading twice, and it isn't safe to unload...
+    static std::map<std::string, std::shared_ptr<mir::SharedLibrary>> libraries_cache;
+
+    if (auto& ptr = libraries_cache[libname])
+    {
+        return ptr.get();
+    }
+    else
+    {
+        ptr = std::make_shared<mir::SharedLibrary>(libname);
+        return ptr.get();
+    }
+}
 }
 
 mcl::DefaultConnectionConfiguration::DefaultConnectionConfiguration(
@@ -44,7 +65,7 @@ mcl::DefaultConnectionConfiguration::DefaultConnectionConfiguration(
 {
 }
 
-std::shared_ptr<mcl::SurfaceMap>
+std::shared_ptr<mcl::ConnectionSurfaceMap>
 mcl::DefaultConnectionConfiguration::the_surface_map()
 {
     return surface_map([]
@@ -53,7 +74,7 @@ mcl::DefaultConnectionConfiguration::the_surface_map()
         });
 }
 
-std::shared_ptr<mcl::rpc::MirBasicRpcChannel>
+std::shared_ptr<google::protobuf::RpcChannel>
 mcl::DefaultConnectionConfiguration::the_rpc_channel()
 {
     return rpc_channel(
@@ -80,7 +101,15 @@ mcl::DefaultConnectionConfiguration::the_client_platform_factory()
     return client_platform_factory(
         []
         {
-            return std::make_shared<mcl::NativeClientPlatformFactory>();
+            auto const val_raw = getenv("MIR_CLIENT_PLATFORM_LIB");
+            std::string const val{val_raw ? val_raw : default_platform_lib};
+            auto const platform_lib = ::load_library(val);
+
+            auto const create_client_platform_factory =
+                platform_lib->load_function<mcl::CreateClientPlatformFactory>(
+                    "create_client_platform_factory");
+
+            return create_client_platform_factory();
         });
 }
 
@@ -88,9 +117,9 @@ std::shared_ptr<mir::input::receiver::InputPlatform>
 mcl::DefaultConnectionConfiguration::the_input_platform()
 {
     return input_platform(
-        []
+        [this]
         {
-            return mir::input::receiver::InputPlatform::create();
+            return mir::input::receiver::InputPlatform::create(the_input_receiver_report());
         });
 }
 
@@ -118,6 +147,24 @@ mcl::DefaultConnectionConfiguration::the_rpc_report()
         });
 }
 
+std::shared_ptr<mir::input::receiver::InputReceiverReport>
+mcl::DefaultConnectionConfiguration::the_input_receiver_report()
+{
+    return input_receiver_report(
+        [this] () -> std::shared_ptr<mir::input::receiver::InputReceiverReport>
+        {
+            auto val_raw = getenv("MIR_CLIENT_INPUT_RECEIVER_REPORT");
+            std::string const val{val_raw ? val_raw : off_opt_val};
+
+            if (val == log_opt_val)
+                return std::make_shared<mcl::logging::InputReceiverReport>(the_logger());
+            else if (val == lttng_opt_val)
+                return std::make_shared<mcl::lttng::InputReceiverReport>();
+            else
+                return std::make_shared<mir::input::receiver::NullInputReceiverReport>();
+        });
+}
+
 std::shared_ptr<mcl::DisplayConfiguration> mcl::DefaultConnectionConfiguration::the_display_configuration()
 {
     return display_configuration(
