@@ -45,7 +45,7 @@ void mcll::RpcReport::invocation_requested(
     ss << "Invocation request: id: " << invocation.id()
        << " method_name: " << invocation.method_name();
 
-    logger->log<ml::Logger::debug>(ss.str(), component);
+    logger->log(ml::Logger::debug, ss.str(), component);
 }
 
 void mcll::RpcReport::invocation_succeeded(
@@ -55,7 +55,7 @@ void mcll::RpcReport::invocation_succeeded(
     ss << "Invocation succeeded: id: " << invocation.id()
        << " method_name: " << invocation.method_name();
 
-    logger->log<ml::Logger::debug>(ss.str(), component);
+    logger->log(ml::Logger::debug, ss.str(), component);
 }
 
 void mcll::RpcReport::invocation_failed(
@@ -67,7 +67,7 @@ void mcll::RpcReport::invocation_failed(
        << " method_name: " << invocation.method_name()
        << " error: " << error.message();
 
-    logger->log<ml::Logger::error>(ss.str(), component);
+    logger->log(ml::Logger::error, ss.str(), component);
 }
 
 void mcll::RpcReport::header_receipt_failed(
@@ -76,7 +76,7 @@ void mcll::RpcReport::header_receipt_failed(
     std::stringstream ss;
     ss << "Header receipt failed: " << " error: " << error.message();
 
-    logger->log<ml::Logger::error>(ss.str(), component);
+    logger->log(ml::Logger::error, ss.str(), component);
 }
 
 void mcll::RpcReport::result_receipt_succeeded(
@@ -85,7 +85,7 @@ void mcll::RpcReport::result_receipt_succeeded(
     std::stringstream ss;
     ss << "Result received: id: " << result.id();
 
-    logger->log<ml::Logger::debug>(ss.str(), component);
+    logger->log(ml::Logger::debug, ss.str(), component);
 }
 
 void mcll::RpcReport::result_receipt_failed(
@@ -94,7 +94,7 @@ void mcll::RpcReport::result_receipt_failed(
     std::stringstream ss;
     ss << "Result receipt failed: reason: " << ex.what();
 
-    logger->log<ml::Logger::error>(ss.str(), component);
+    logger->log(ml::Logger::error, ss.str(), component);
 }
 
 void mcll::RpcReport::event_parsing_succeeded(
@@ -104,7 +104,7 @@ void mcll::RpcReport::event_parsing_succeeded(
     /* TODO: Log more information about event */
     ss << "Event parsed";
 
-    logger->log<ml::Logger::error>(ss.str(), component);
+    logger->log(ml::Logger::debug, ss.str(), component);
 }
 
 void mcll::RpcReport::event_parsing_failed(
@@ -114,7 +114,7 @@ void mcll::RpcReport::event_parsing_failed(
     /* TODO: Log more information about event */
     ss << "Event parsing failed";
 
-    logger->log<ml::Logger::warning>(ss.str(), component);
+    logger->log(ml::Logger::warning, ss.str(), component);
 }
 
 void mcll::RpcReport::orphaned_result(
@@ -123,7 +123,7 @@ void mcll::RpcReport::orphaned_result(
     std::stringstream ss;
     ss << "Orphaned result: " << result.ShortDebugString();
 
-    logger->log<ml::Logger::error>(ss.str(), component);
+    logger->log(ml::Logger::error, ss.str(), component);
 }
 
 void mcll::RpcReport::complete_response(
@@ -132,7 +132,7 @@ void mcll::RpcReport::complete_response(
     std::stringstream ss;
     ss << "Complete response: id: " << result.id();
 
-    logger->log<ml::Logger::debug>(ss.str(), component);
+    logger->log(ml::Logger::debug, ss.str(), component);
 }
 
 void mcll::RpcReport::result_processing_failed(
@@ -142,7 +142,7 @@ void mcll::RpcReport::result_processing_failed(
     std::stringstream ss;
     ss << "Result processing failed: reason: " << ex.what();
 
-    logger->log<ml::Logger::error>(ss.str(), component);
+    logger->log(ml::Logger::error, ss.str(), component);
 }
 
 void mcll::RpcReport::file_descriptors_received(
@@ -154,7 +154,7 @@ void mcll::RpcReport::file_descriptors_received(
     for (auto f : fds)
         ss << f << " ";
 
-    logger->log<ml::Logger::debug>(ss.str(), component);
+    logger->log(ml::Logger::debug, ss.str(), component);
 }
 
 void mcll::RpcReport::connection_failure(std::exception const& x)
@@ -162,5 +162,5 @@ void mcll::RpcReport::connection_failure(std::exception const& x)
     std::stringstream ss;
     ss << "Connection failure: " << boost::diagnostic_information(x) << std::endl;
 
-    logger->log<ml::Logger::warning>(ss.str(), component);
+    logger->log(ml::Logger::warning, ss.str(), component);
 }
