@@ -17,6 +17,7 @@
  */
 
 #include "mir/default_configuration.h"
+#include "mir/raii.h"
 #include "mir_toolkit/mir_client_library.h"
 #include "mir_toolkit/mir_client_library_drm.h"
 #include "mir_toolkit/mir_client_library_debug.h"
@@ -24,14 +25,15 @@
 #include "mir_connection.h"
 #include "display_configuration.h"
 #include "mir_surface.h"
-#include "native_client_platform_factory.h"
 #include "egl_native_display_container.h"
 #include "default_connection_configuration.h"
 #include "lifecycle_control.h"
+#include "api_impl_types.h"
 
 #include <set>
 #include <unordered_set>
 #include <cstddef>
+#include <cstring>
 
 namespace mcl = mir::client;
 
@@ -72,6 +74,11 @@ void assign_result(void *result, void **context)
         *context = result;
 }
 
+size_t division_ceiling(size_t a, size_t b)
+{
+    return ((a - 1) / b) + 1;
+}
+
 }
 
 MirWaitHandle* mir_default_connect(
@@ -101,11 +108,10 @@ MirWaitHandle* mir_default_connect(
     }
     catch (std::exception const& x)
     {
-        MirConnection* error_connection = new MirConnection();
+        MirConnection* error_connection = new MirConnection(x.what());
         error_connections.insert(error_connection);
-        error_connection->set_error_message(x.what());
         callback(error_connection, context);
-        return 0;
+        return nullptr;
     }
 }
 
@@ -114,8 +120,17 @@ void mir_default_connection_release(MirConnection * connection)
 {
     if (!error_connections.contains(connection))
     {
-        auto wait_handle = connection->disconnect();
-        wait_handle->wait_for_all();
+        try
+        {
+            auto wait_handle = connection->disconnect();
+            wait_handle->wait_for_all();
+        }
+        catch (std::exception const&)
+        {
+            // We're implementing a C API so no exceptions are to be
+            // propagated. And that's OK because if disconnect() fails,
+            // we don't care why. We're finished with the connection anyway.
+        }
     }
     else
     {
@@ -130,19 +145,30 @@ void mir_default_connection_release(MirConnection * connection)
 
 //TODO: we could have a more comprehensive solution that allows us to substitute any of the functions
 //for test purposes, not just the connect functions
-MirWaitHandle* (*mir_connect_impl)(
-    char const *server, char const *app_name,
-    mir_connected_callback callback, void *context) = mir_default_connect;
-void (*mir_connection_release_impl) (MirConnection *connection) = mir_default_connection_release;
+mir_connect_impl_func mir_connect_impl = mir_default_connect;
+mir_connection_release_impl_func mir_connection_release_impl = mir_default_connection_release;
 
 MirWaitHandle* mir_connect(char const* socket_file, char const* name, mir_connected_callback callback, void * context)
 {
-    return mir_connect_impl(socket_file, name, callback, context);
+    try
+    {
+        return mir_connect_impl(socket_file, name, callback, context);
+    }
+    catch (std::exception const&)
+    {
+        return nullptr;
+    }
 }
 
 void mir_connection_release(MirConnection *connection)
 {
-    return mir_connection_release_impl(connection);
+    try
+    {
+        return mir_connection_release_impl(connection);
+    }
+    catch (std::exception const&)
+    {
+    }
 }
 
 MirConnection *mir_connect_sync(char const *server,
@@ -156,9 +182,9 @@ MirConnection *mir_connect_sync(char const *server,
     return conn;
 }
 
-int mir_connection_is_valid(MirConnection * connection)
+MirBool mir_connection_is_valid(MirConnection * connection)
 {
-    return MirConnection::is_valid(connection);
+    return MirConnection::is_valid(connection) ? mir_true : mir_false;
 }
 
 char const * mir_connection_get_error_message(MirConnection * connection)
@@ -176,7 +202,7 @@ void mir_connection_get_available_surface_formats(
     unsigned const int format_size, unsigned int *num_valid_formats)
 {
     if ((connection) && (formats) && (num_valid_formats))
-        connection->possible_pixel_formats(formats, format_size, *num_valid_formats);
+        connection->available_surface_formats(formats, format_size, *num_valid_formats);
 }
 
 MirWaitHandle* mir_connection_create_surface(
@@ -194,7 +220,7 @@ MirWaitHandle* mir_connection_create_surface(
     catch (std::exception const&)
     {
         // TODO callback with an error surface
-        return 0; // TODO
+        return nullptr;
     }
 
 }
@@ -222,7 +248,14 @@ MirWaitHandle* mir_surface_release(
     MirSurface * surface,
     mir_surface_callback callback, void * context)
 {
-    return surface->release_surface(callback, context);
+    try
+    {
+        return surface->release_surface(callback, context);
+    }
+    catch (std::exception const&)
+    {
+        return nullptr;
+    }
 }
 
 void mir_surface_release_sync(MirSurface *surface)
@@ -239,12 +272,12 @@ int mir_surface_get_id(MirSurface * surface)
 
 int mir_debug_surface_id(MirSurface * surface)
 {
-    return surface->id();    
+    return surface->id();
 }
 
-int mir_surface_is_valid(MirSurface* surface)
+MirBool mir_surface_is_valid(MirSurface* surface)
 {
-    return surface->is_valid();
+    return surface->is_valid() ? mir_true : mir_false;
 }
 
 char const * mir_surface_get_error_message(MirSurface * surface)
@@ -292,51 +325,48 @@ void mir_display_config_destroy(MirDisplayConfiguration* configuration)
 //TODO: DEPRECATED: remove this function
 void mir_connection_get_display_info(MirConnection *connection, MirDisplayInfo *display_info)
 {
-    auto config = mir_connection_create_display_config(connection);
+    auto const config = mir::raii::deleter_for(
+        mir_connection_create_display_config(connection),
+        &mir_display_config_destroy);
 
-    do
+    if (config->num_outputs < 1)
+        return;
+
+    MirDisplayOutput* state = nullptr;
+    // We can't handle more than one display, so just populate based on the first
+    // active display we find.
+    for (unsigned int i = 0; i < config->num_outputs; ++i)
     {
-        if (config->num_outputs < 1)
-            break;
-
-        MirDisplayOutput* state = nullptr;
-        // We can't handle more than one display, so just populate based on the first
-        // active display we find.
-        for (unsigned int i = 0; i < config->num_outputs; ++i)
+        if (config->outputs[i].used && config->outputs[i].connected &&
+            config->outputs[i].current_mode < config->outputs[i].num_modes)
         {
-            if (config->outputs[i].used && config->outputs[i].connected &&
-                config->outputs[i].current_mode < config->outputs[i].num_modes)
-            {
-                state = &config->outputs[i];
-                break;
-            }
-        }
-        // Oh, oh! No connected outputs?!
-        if (state == nullptr)
-        {
-            memset(display_info, 0, sizeof(*display_info));
+            state = &config->outputs[i];
             break;
         }
+    }
+    // Oh, oh! No connected outputs?!
+    if (state == nullptr)
+    {
+        memset(display_info, 0, sizeof(*display_info));
+        return;
+    }
 
-        MirDisplayMode mode = state->modes[state->current_mode];
+    MirDisplayMode mode = state->modes[state->current_mode];
 
-        display_info->width = mode.horizontal_resolution;
-        display_info->height = mode.vertical_resolution;
+    display_info->width = mode.horizontal_resolution;
+    display_info->height = mode.vertical_resolution;
 
-        unsigned int format_items;
-        if (state->num_output_formats > mir_supported_pixel_format_max)
-             format_items = mir_supported_pixel_format_max;
-        else
-             format_items = state->num_output_formats;
+    unsigned int format_items;
+    if (state->num_output_formats > mir_supported_pixel_format_max)
+         format_items = mir_supported_pixel_format_max;
+    else
+         format_items = state->num_output_formats;
 
-        display_info->supported_pixel_format_items = format_items;
-        for(auto i=0u; i < format_items; i++)
-        {
-            display_info->supported_pixel_format[i] = state->output_formats[i];
-        }
-    } while (false);
-
-    mir_display_config_destroy(config);
+    display_info->supported_pixel_format_items = format_items;
+    for(auto i=0u; i < format_items; i++)
+    {
+        display_info->supported_pixel_format[i] = state->output_formats[i];
+    }
 }
 
 void mir_surface_get_graphics_region(MirSurface * surface, MirGraphicsRegion * graphics_region)
@@ -351,7 +381,7 @@ try
 }
 catch (std::exception const&)
 {
-    return 0;
+    return nullptr;
 }
 
 void mir_surface_swap_buffers_sync(MirSurface *surface)
@@ -375,21 +405,20 @@ void mir_wait_for_one(MirWaitHandle* wait_handle)
 
 MirEGLNativeWindowType mir_surface_get_egl_native_window(MirSurface *surface)
 {
-    return surface->generate_native_window();
-}
-
-MirWaitHandle *mir_connection_drm_auth_magic(MirConnection* connection,
-                                             unsigned int magic,
-                                             mir_drm_auth_magic_callback callback,
-                                             void* context)
-{
-    return connection->drm_auth_magic(magic, callback, context);
+    return reinterpret_cast<MirEGLNativeWindowType>(surface->generate_native_window());
 }
 
 MirWaitHandle* mir_surface_set_type(MirSurface *surf,
-                                                           MirSurfaceType type)
+                                    MirSurfaceType type)
 {
-    return surf ? surf->configure(mir_surface_attrib_type, type) : NULL;
+    try
+    {
+        return surf ? surf->configure(mir_surface_attrib_type, type) : nullptr;
+    }
+    catch (std::exception const&)
+    {
+        return nullptr;
+    }
 }
 
 MirSurfaceType mir_surface_get_type(MirSurface *surf)
@@ -410,25 +439,38 @@ MirSurfaceType mir_surface_get_type(MirSurface *surf)
 
 MirWaitHandle* mir_surface_set_state(MirSurface *surf, MirSurfaceState state)
 {
-    return surf ? surf->configure(mir_surface_attrib_state, state) : NULL;
+    try
+    {
+        return surf ? surf->configure(mir_surface_attrib_state, state) : nullptr;
+    }
+    catch (std::exception const&)
+    {
+        return nullptr;
+    }
 }
 
 MirSurfaceState mir_surface_get_state(MirSurface *surf)
 {
     MirSurfaceState state = mir_surface_state_unknown;
 
-    if (surf)
+    try
     {
-        int s = surf->attrib(mir_surface_attrib_state);
-
-        if (s == mir_surface_state_unknown)
+        if (surf)
         {
-            surf->configure(mir_surface_attrib_state,
-                            mir_surface_state_unknown)->wait_for_all();
-            s = surf->attrib(mir_surface_attrib_state);
-        }
+            int s = surf->attrib(mir_surface_attrib_state);
 
-        state = static_cast<MirSurfaceState>(s);
+            if (s == mir_surface_state_unknown)
+            {
+                surf->configure(mir_surface_attrib_state,
+                                mir_surface_state_unknown)->wait_for_all();
+                s = surf->attrib(mir_surface_attrib_state);
+            }
+
+            state = static_cast<MirSurfaceState>(s);
+        }
+    }
+    catch (std::exception const&)
+    {
     }
 
     return state;
@@ -437,8 +479,16 @@ MirSurfaceState mir_surface_get_state(MirSurface *surf)
 MirWaitHandle* mir_surface_set_swapinterval(MirSurface* surf, int interval)
 {
     if ((interval < 0) || (interval > 1))
-        return NULL;
-    return surf ? surf->configure(mir_surface_attrib_swapinterval, interval) : NULL;
+        return nullptr;
+
+    try
+    {
+        return surf ? surf->configure(mir_surface_attrib_swapinterval, interval) : nullptr;
+    }
+    catch (std::exception const&)
+    {
+        return nullptr;
+    }
 }
 
 int mir_surface_get_swapinterval(MirSurface* surf)
@@ -462,8 +512,35 @@ void mir_connection_set_display_config_change_callback(MirConnection* connection
 
 MirWaitHandle* mir_connection_apply_display_config(MirConnection *connection, MirDisplayConfiguration* display_configuration)
 {
-    if (!connection)
-        return NULL;
- 
-    return connection->configure_display(display_configuration);
+    try
+    {
+        return connection ? connection->configure_display(display_configuration) : nullptr;
+    }
+    catch (std::exception const&)
+    {
+        return nullptr;
+    }
+}
+
+/**************************
+ * DRM specific functions *
+ **************************/
+
+MirWaitHandle *mir_connection_drm_auth_magic(MirConnection* connection,
+                                             unsigned int magic,
+                                             mir_drm_auth_magic_callback callback,
+                                             void* context)
+{
+    return connection->drm_auth_magic(magic, callback, context);
+}
+
+int mir_connection_drm_set_gbm_device(MirConnection* connection,
+                                      struct gbm_device* gbm_dev)
+{
+    size_t const pointer_size_in_ints = division_ceiling(sizeof(gbm_dev), sizeof(int));
+    std::vector<int> extra_data(pointer_size_in_ints);
+
+    memcpy(extra_data.data(), &gbm_dev, sizeof(gbm_dev));
+
+    return connection->set_extra_platform_data(extra_data);
 }
