@@ -20,6 +20,8 @@
 
 #include <memory>
 
+namespace google { namespace protobuf { class RpcChannel; } }
+
 namespace mir
 {
 namespace client
@@ -30,10 +32,9 @@ class LifecycleControl;
 
 namespace rpc
 {
-class MirBasicRpcChannel;
 class RpcReport;
 
-std::shared_ptr<MirBasicRpcChannel>
+std::shared_ptr<google::protobuf::RpcChannel>
 make_rpc_channel(std::string const& name,
                  std::shared_ptr<SurfaceMap> const& map,
                  std::shared_ptr<DisplayConfiguration> const& disp_conf,
