@@ -54,8 +54,8 @@ class PendingCallCache
 public:
     PendingCallCache(std::shared_ptr<RpcReport> const& rpc_report);
 
-    SendBuffer& save_completion_details(
-        mir::protobuf::wire::Invocation& invoke,
+    void save_completion_details(
+        mir::protobuf::wire::Invocation const& invoke,
         google::protobuf::Message* response,
         std::shared_ptr<google::protobuf::Closure> const& complete);
 
@@ -78,7 +78,6 @@ private:
         PendingCall()
         : response(0), complete() {}
 
-        SendBuffer send_buffer;
         google::protobuf::Message* response;
         std::shared_ptr<google::protobuf::Closure> complete;
     };
@@ -96,8 +95,9 @@ public:
     ~MirBasicRpcChannel();
 
 protected:
-    mir::protobuf::wire::Invocation invocation_for(const google::protobuf::MethodDescriptor* method,
-        const google::protobuf::Message* request);
+    mir::protobuf::wire::Invocation invocation_for(
+        google::protobuf::MethodDescriptor const* method,
+        google::protobuf::Message const* request);
     int next_id();
 
 private:
