@@ -39,6 +39,11 @@
 namespace mcl = mir::client;
 namespace mclr = mir::client::rpc;
 
+namespace
+{
+std::chrono::milliseconds const timeout(200);
+}
+
 mclr::MirSocketRpcChannel::MirSocketRpcChannel(
     std::string const& endpoint,
     std::shared_ptr<mcl::SurfaceMap> const& surface_map,
@@ -82,14 +87,15 @@ void mclr::MirSocketRpcChannel::notify_disconnected()
     if (!disconnected.exchange(true))
     {
         io_service.stop();
+        socket.close();
         lifecycle_control->call_lifecycle_event_handler(mir_lifecycle_connection_lost);
-        pending_calls.force_completion();
     }
+    pending_calls.force_completion();
 }
 
 void mclr::MirSocketRpcChannel::init()
 {
-    io_service_thread = std::thread([&]
+    io_service_thread = std::thread([this]
         {
             // Our IO threads must not receive any signals
             sigset_t all_signals;
@@ -134,68 +140,87 @@ mclr::MirSocketRpcChannel::~MirSocketRpcChannel()
 void mclr::MirSocketRpcChannel::receive_file_descriptors(google::protobuf::Message* response,
     google::protobuf::Closure* complete)
 {
-    auto surface = dynamic_cast<mir::protobuf::Surface*>(response);
-    if (surface)
+    if (!disconnected.load())
     {
-        surface->clear_fd();
+        auto const message_type = response->GetTypeName();
 
-        if (surface->fds_on_side_channel() > 0)
+        mir::protobuf::Surface* surface = nullptr;
+        mir::protobuf::Buffer* buffer = nullptr;
+        mir::protobuf::Platform* platform = nullptr;
+
+        if (message_type == "mir.protobuf.Buffer")
         {
-            std::vector<int32_t> fds(surface->fds_on_side_channel());
-            receive_file_descriptors(fds);
-            for (auto &fd: fds)
-                surface->add_fd(fd);
+            buffer = static_cast<mir::protobuf::Buffer*>(response);
+        }
+        else if (message_type == "mir.protobuf.Surface")
+        {
+            surface = static_cast<mir::protobuf::Surface*>(response);
+            if (surface && surface->has_buffer())
+                buffer = surface->mutable_buffer();
+        }
+        else if (message_type == "mir.protobuf.Screencast")
+        {
+            auto screencast = static_cast<mir::protobuf::Screencast*>(response);
+            if (screencast && screencast->has_buffer())
+                buffer = screencast->mutable_buffer();
+        }
+        else if (message_type == "mir.protobuf.Platform")
+        {
+            platform = static_cast<mir::protobuf::Platform*>(response);
+        }
+        else if (message_type == "mir.protobuf.Connection")
+        {
+            auto connection = static_cast<mir::protobuf::Connection*>(response);
+            if (connection && connection->has_platform())
+                platform = connection->mutable_platform();
+        }
 
-            rpc_report->file_descriptors_received(*response, fds);
+        if (surface)
+        {
+            surface->clear_fd();
+
+            if (surface->fds_on_side_channel() > 0)
+            {
+                std::vector<int32_t> fds(surface->fds_on_side_channel());
+                receive_file_descriptors(fds);
+                for (auto &fd: fds)
+                    surface->add_fd(fd);
+
+                rpc_report->file_descriptors_received(*response, fds);
+            }
+        }
+
+        if (buffer)
+        {
+            buffer->clear_fd();
+
+            if (buffer->fds_on_side_channel() > 0)
+            {
+                std::vector<int32_t> fds(buffer->fds_on_side_channel());
+                receive_file_descriptors(fds);
+                for (auto &fd: fds)
+                    buffer->add_fd(fd);
+
+                rpc_report->file_descriptors_received(*response, fds);
+            }
+        }
+
+        if (platform)
+        {
+            platform->clear_fd();
+
+            if (platform->fds_on_side_channel() > 0)
+            {
+                std::vector<int32_t> fds(platform->fds_on_side_channel());
+                receive_file_descriptors(fds);
+                for (auto &fd: fds)
+                    platform->add_fd(fd);
+
+                rpc_report->file_descriptors_received(*response, fds);
+            }
         }
     }
 
-    auto buffer = dynamic_cast<mir::protobuf::Buffer*>(response);
-    if (!buffer)
-    {
-        if (surface && surface->has_buffer())
-            buffer = surface->mutable_buffer();
-    }
-
-    if (buffer)
-    {
-        buffer->clear_fd();
-
-        if (buffer->fds_on_side_channel() > 0)
-        {
-            std::vector<int32_t> fds(buffer->fds_on_side_channel());
-            receive_file_descriptors(fds);
-            for (auto &fd: fds)
-                buffer->add_fd(fd);
-
-            rpc_report->file_descriptors_received(*response, fds);
-        }
-    }
-
-    auto platform = dynamic_cast<mir::protobuf::Platform*>(response);
-    if (!platform)
-    {
-        auto connection = dynamic_cast<mir::protobuf::Connection*>(response);
-        if (connection && connection->has_platform())
-            platform = connection->mutable_platform();
-    }
-
-    if (platform)
-    {
-        platform->clear_fd();
-
-        if (platform->fds_on_side_channel() > 0)
-        {
-            std::vector<int32_t> fds(platform->fds_on_side_channel());
-            receive_file_descriptors(fds);
-            for (auto &fd: fds)
-                platform->add_fd(fd);
-
-            rpc_report->file_descriptors_received(*response, fds);
-        }
-    }
-
-
     complete->Run();
 }
 
@@ -227,8 +252,14 @@ void mclr::MirSocketRpcChannel::receive_file_descriptors(std::vector<int> &fds)
     message->cmsg_level = SOL_SOCKET;
     message->cmsg_type = SCM_RIGHTS;
 
+    using std::chrono::steady_clock;
+    auto time_limit = steady_clock::now() + timeout;
+
     while (recvmsg(socket.native_handle(), &header, 0) < 0)
-        ; // FIXME: Avoid spinning forever
+    {
+        if (steady_clock::now() > time_limit)
+            return;
+    }
 
     // Copy file descriptors back to caller
     n_fds = (message->cmsg_len - sizeof(struct cmsghdr)) / sizeof(int);
@@ -245,7 +276,7 @@ void mclr::MirSocketRpcChannel::CallMethod(
     google::protobuf::Message* response,
     google::protobuf::Closure* complete)
 {
-    mir::protobuf::wire::Invocation invocation = invocation_for(method, parameters);
+    auto const& invocation = invocation_for(method, parameters);
 
     rpc_report->invocation_requested(invocation);
 
@@ -253,15 +284,14 @@ void mclr::MirSocketRpcChannel::CallMethod(
         google::protobuf::NewPermanentCallback(this, &MirSocketRpcChannel::receive_file_descriptors, response, complete));
 
     // Only save details after serialization succeeds
-    auto& send_buffer = pending_calls.save_completion_details(invocation, response, callback);
+    pending_calls.save_completion_details(invocation, response, callback);
 
     // Only send message when details saved for handling response
-    send_message(invocation, send_buffer, invocation);
+    send_message(invocation, invocation);
 }
 
 void mclr::MirSocketRpcChannel::send_message(
     mir::protobuf::wire::Invocation const& body,
-    detail::SendBuffer& send_buffer,
     mir::protobuf::wire::Invocation const& invocation)
 {
     const size_t size = body.ByteSize();
@@ -271,7 +301,7 @@ void mclr::MirSocketRpcChannel::send_message(
         static_cast<unsigned char>((size >> 0) & 0xff)
     };
 
-    send_buffer.resize(sizeof header_bytes + size);
+    detail::SendBuffer send_buffer(sizeof header_bytes + size);
     std::copy(header_bytes, header_bytes + sizeof header_bytes, send_buffer.begin());
     body.SerializeToArray(send_buffer.data() + sizeof header_bytes, size);
 
@@ -288,8 +318,8 @@ void mclr::MirSocketRpcChannel::send_message(
         notify_disconnected();
         BOOST_THROW_EXCEPTION(std::runtime_error("Failed to send message to server: " + error.message()));
     }
-    else
-        rpc_report->invocation_succeeded(invocation);
+
+    rpc_report->invocation_succeeded(invocation);
 }
 
 void mclr::MirSocketRpcChannel::on_header_read(const boost::system::error_code& error)
@@ -325,7 +355,7 @@ void mclr::MirSocketRpcChannel::read_message()
     {
         const size_t body_size = read_message_header();
 
-        result = read_message_body(body_size);
+        read_message_body(result, body_size);
 
         rpc_report->result_receipt_succeeded(result);
     }
@@ -401,7 +431,7 @@ void mclr::MirSocketRpcChannel::process_event_sequence(std::string const& event)
             {
                 rpc_report->event_parsing_failed(event);
             }
-        } 
+        }
     }
 }
 
@@ -411,18 +441,17 @@ size_t mclr::MirSocketRpcChannel::read_message_header()
     return body_size;
 }
 
-mir::protobuf::wire::Result mclr::MirSocketRpcChannel::read_message_body(const size_t body_size)
+void mclr::MirSocketRpcChannel::read_message_body(
+    mir::protobuf::wire::Result& result,
+    size_t const body_size)
 {
     boost::system::error_code error;
-    boost::asio::streambuf message;
-    boost::asio::read(socket, message, boost::asio::transfer_exactly(body_size), error);
+    body_bytes.resize(body_size);
+    boost::asio::read(socket, boost::asio::buffer(body_bytes), error);
     if (error)
     {
         BOOST_THROW_EXCEPTION(std::runtime_error("Failed to read message body: " + error.message()));
     }
 
-    std::istream in(&message);
-    mir::protobuf::wire::Result result;
-    result.ParseFromIstream(&in);
-    return result;
+    result.ParseFromArray(body_bytes.data(), body_size);
 }
