@@ -80,10 +80,11 @@ private:
 
     static size_t const size_of_header = 2;
     unsigned char header_bytes[size_of_header];
+    std::vector<char> body_bytes;
 
     void receive_file_descriptors(google::protobuf::Message* response, google::protobuf::Closure* complete);
     void receive_file_descriptors(std::vector<int> &fds);
-    void send_message(mir::protobuf::wire::Invocation const& body, detail::SendBuffer& buffer,
+    void send_message(mir::protobuf::wire::Invocation const& body,
                       mir::protobuf::wire::Invocation const& invocation);
     void on_header_read(const boost::system::error_code& error);
 
@@ -92,7 +93,8 @@ private:
 
     size_t read_message_header();
 
-    mir::protobuf::wire::Result read_message_body(const size_t body_size);
+    void read_message_body(mir::protobuf::wire::Result& result,
+                           size_t const body_size);
     void notify_disconnected();
 
     std::shared_ptr<SurfaceMap> surface_map;
