@@ -34,10 +34,22 @@ class BufferBundle
 {
 public:
     virtual ~BufferBundle() noexcept {}
-    virtual std::shared_ptr<graphics::Buffer> client_acquire() = 0;
-    virtual void client_release(std::shared_ptr<graphics::Buffer> const&) = 0;
+    virtual void client_acquire(std::function<void(graphics::Buffer* buffer)> complete) = 0;
+    virtual void client_release(graphics::Buffer*) = 0;
+
+    /**
+     * Acquire the next buffer that's ready to display/composite.
+     *
+     * \param [in] user_id A unique identifier of who is going to use the
+     *                     buffer, to ensure that separate users representing
+     *                     separate monitors who need the same frame will get
+     *                     the same buffer. However consecutive calls for the
+     *                     same user will get different buffers. To avoid
+     *                     collisions, all callers should determine user_id
+     *                     in the same way (e.g. always use "this" pointer).
+     */
     virtual std::shared_ptr<graphics::Buffer>
-        compositor_acquire(unsigned long frameno) = 0;
+        compositor_acquire(void const* user_id) = 0;
     virtual void compositor_release(std::shared_ptr<graphics::Buffer> const&) = 0;
     virtual std::shared_ptr<graphics::Buffer> snapshot_acquire() = 0;
     virtual void snapshot_release(std::shared_ptr<graphics::Buffer> const&) = 0;
@@ -45,6 +57,8 @@ public:
     virtual graphics::BufferProperties properties() const = 0;
     virtual void allow_framedropping(bool dropping_allowed) = 0;
     virtual void force_requests_to_complete() = 0;
+    virtual void resize(const geometry::Size &newsize) = 0;
+    virtual int buffers_ready_for_compositor() const = 0;
 protected:
     BufferBundle() = default;
     BufferBundle(BufferBundle const&) = delete;
