@@ -18,8 +18,8 @@
  *   Thomas Voss <thomas.voss@canonical.com>
  */
 
-#include "mir/compositor/buffer_stream_factory.h"
-#include "mir/compositor/buffer_stream_surfaces.h"
+#include "buffer_stream_factory.h"
+#include "buffer_stream_surfaces.h"
 #include "mir/graphics/buffer_properties.h"
 #include "switching_bundle.h"
 #include "mir/graphics/buffer.h"
@@ -32,7 +32,7 @@
 
 namespace mc = mir::compositor;
 namespace mg = mir::graphics;
-namespace ms = mir::surfaces;
+namespace ms = mir::scene;
 
 mc::BufferStreamFactory::BufferStreamFactory(
     const std::shared_ptr<mg::GraphicBufferAllocator> &gralloc)
@@ -42,7 +42,7 @@ mc::BufferStreamFactory::BufferStreamFactory(
 }
 
 
-std::shared_ptr<ms::BufferStream> mc::BufferStreamFactory::create_buffer_stream(
+std::shared_ptr<mc::BufferStream> mc::BufferStreamFactory::create_buffer_stream(
     mg::BufferProperties const& buffer_properties)
 {
     // Note: Framedropping and bypass both require a minimum 3 buffers
