@@ -17,7 +17,7 @@
  * Kevin DuBois <kevin.dubois@canonical.com>
  */
 
-#include "mir/compositor/buffer_stream_surfaces.h"
+#include "buffer_stream_surfaces.h"
 #include "buffer_bundle.h"
 #include "mir/graphics/buffer_properties.h"
 
@@ -38,10 +38,10 @@ mc::BufferStreamSurfaces::~BufferStreamSurfaces()
 }
 
 std::shared_ptr<mg::Buffer> mc::BufferStreamSurfaces::lock_compositor_buffer(
-    unsigned long frameno)
+    void const* user_id)
 {
     return std::make_shared<mc::TemporaryCompositorBuffer>(
-        buffer_bundle, frameno);
+        buffer_bundle, user_id);
 }
 
 std::shared_ptr<mg::Buffer> mc::BufferStreamSurfaces::lock_snapshot_buffer()
@@ -49,19 +49,29 @@ std::shared_ptr<mg::Buffer> mc::BufferStreamSurfaces::lock_snapshot_buffer()
     return std::make_shared<mc::TemporarySnapshotBuffer>(buffer_bundle);
 }
 
-std::shared_ptr<mg::Buffer> mc::BufferStreamSurfaces::secure_client_buffer()
+void mc::BufferStreamSurfaces::swap_client_buffers(graphics::Buffer* old_buffer, std::function<void(graphics::Buffer* new_buffer)> complete)
 {
-    return std::make_shared<mc::TemporaryClientBuffer>(buffer_bundle);
+    if (old_buffer)
+    {
+        buffer_bundle->client_release(old_buffer);
+    }
+
+    buffer_bundle->client_acquire(complete);
 }
 
-geom::PixelFormat mc::BufferStreamSurfaces::get_stream_pixel_format()
+MirPixelFormat mc::BufferStreamSurfaces::get_stream_pixel_format()
 {
-    return buffer_bundle->properties().format; 
+    return buffer_bundle->properties().format;
 }
 
 geom::Size mc::BufferStreamSurfaces::stream_size()
 {
-    return buffer_bundle->properties().size; 
+    return buffer_bundle->properties().size;
+}
+
+void mc::BufferStreamSurfaces::resize(geom::Size const& size)
+{
+    buffer_bundle->resize(size);
 }
 
 void mc::BufferStreamSurfaces::force_requests_to_complete()
@@ -73,3 +83,8 @@ void mc::BufferStreamSurfaces::allow_framedropping(bool allow)
 {
     buffer_bundle->allow_framedropping(allow);
 }
+
+int mc::BufferStreamSurfaces::buffers_ready_for_compositor() const
+{
+    return buffer_bundle->buffers_ready_for_compositor();
+}
