@@ -20,6 +20,7 @@
 #define MIR_COMPOSITOR_DEFAULT_DISPLAY_BUFFER_COMPOSITOR_H_
 
 #include "mir/compositor/display_buffer_compositor.h"
+#include "mir/compositor/compositor_report.h"
 #include <memory>
 
 namespace mir
@@ -33,7 +34,6 @@ namespace compositor
 
 class Scene;
 class Renderer;
-class OverlayRenderer;
 
 class DefaultDisplayBufferCompositor : public DisplayBufferCompositor
 {
@@ -42,18 +42,18 @@ public:
         graphics::DisplayBuffer& display_buffer,
         std::shared_ptr<Scene> const& scene,
         std::shared_ptr<Renderer> const& renderer,
-        std::shared_ptr<OverlayRenderer> const& overlay_renderer);
+        std::shared_ptr<CompositorReport> const& report);
 
-    void composite() override;
+    bool composite() override;
 
 private:
     graphics::DisplayBuffer& display_buffer;
 
     std::shared_ptr<Scene> const scene;
     std::shared_ptr<Renderer> const renderer;
-    std::shared_ptr<OverlayRenderer> const overlay_renderer;
+    std::shared_ptr<CompositorReport> const report;
 
-    unsigned long local_frameno;
+    bool last_pass_rendered_anything;
 };
 
 }
