@@ -1,5 +1,5 @@
 /*
- * Copyright © 2013 Canonical Ltd.
+ * Copyright © 2013-2014 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3,
@@ -16,12 +16,13 @@
  * Authored by: Alexandros Frantzis <alexandros.frantzis@canonical.com>
  */
 
-#include "mir/compositor/multi_threaded_compositor.h"
+#include "multi_threaded_compositor.h"
 #include "mir/graphics/display.h"
 #include "mir/graphics/display_buffer.h"
 #include "mir/compositor/display_buffer_compositor.h"
 #include "mir/compositor/display_buffer_compositor_factory.h"
 #include "mir/compositor/scene.h"
+#include "mir/compositor/compositor_report.h"
 
 #include <thread>
 #include <condition_variable>
@@ -56,15 +57,17 @@ class CompositingFunctor
 {
 public:
     CompositingFunctor(std::shared_ptr<mc::DisplayBufferCompositorFactory> const& db_compositor_factory,
-                       mg::DisplayBuffer& buffer)
+                       mg::DisplayBuffer& buffer,
+                       std::shared_ptr<CompositorReport> const& report)
         : display_buffer_compositor_factory{db_compositor_factory},
           buffer(buffer),
           running{true},
-          frames_scheduled{0}
+          frames_scheduled{0},
+          report{report}
     {
     }
 
-    void operator()()
+    void operator()() noexcept  // noexcept is important! (LP: #1237332)
     {
         std::unique_lock<std::mutex> lock{run_mutex};
 
@@ -76,13 +79,18 @@ public:
 
         auto display_buffer_compositor = display_buffer_compositor_factory->create_compositor_for(buffer);
 
+        CompositorReport::SubCompositorId report_id =
+            display_buffer_compositor.get();
+
+        const auto& r = buffer.view_area();
+        report->added_display(r.size.width.as_int(), r.size.height.as_int(),
+                              r.top_left.x.as_int(), r.top_left.y.as_int(),
+                              report_id);
+
         while (running)
         {
             /* Wait until compositing has been scheduled or we are stopped */
-            while (!frames_scheduled && running)
-                run_cv.wait(lock);
-
-            frames_scheduled--;
+            run_cv.wait(lock, [&]{ return frames_scheduled || !running; });
 
             /*
              * Check if we are running before compositing, since we may have
@@ -90,9 +98,19 @@ public:
              */
             if (running)
             {
+                frames_scheduled = false;
                 lock.unlock();
-                display_buffer_compositor->composite();
+                auto more_frames_pending = display_buffer_compositor->composite();
+
+                /*
+                 * Each surface could have a number of frames ready in its buffer
+                 * queue. And we need to ensure that we render all of them so that
+                 * none linger in the queue indefinitely (seen as input lag).
+                 * more_frames_pending indicates that there are we need to schedule
+                 * more frames to ensure all surfaces' queues are fully drained.
+                 */
                 lock.lock();
+                frames_scheduled |= more_frames_pending;
             }
         }
     }
@@ -101,15 +119,7 @@ public:
     {
         std::lock_guard<std::mutex> lock{run_mutex};
 
-        /*
-         * Each surface could have a number of frames ready in its buffer
-         * queue. And we need to ensure that we render all of them so that
-         * none linger in the queue indefinitely (seen as input lag). So while
-         * there's no API support for finding out queue lengths, assume the
-         * worst and schedule enough frames to ensure all surfaces' queues
-         * are fully drained.
-         */
-        frames_scheduled = max_client_buffers;
+        frames_scheduled = true;
         run_cv.notify_one();
     }
 
@@ -124,9 +134,10 @@ private:
     std::shared_ptr<mc::DisplayBufferCompositorFactory> const display_buffer_compositor_factory;
     mg::DisplayBuffer& buffer;
     bool running;
-    int frames_scheduled;
+    bool frames_scheduled;
     std::mutex run_mutex;
     std::condition_variable run_cv;
+    std::shared_ptr<CompositorReport> const report;
 };
 
 }
@@ -135,10 +146,15 @@ private:
 mc::MultiThreadedCompositor::MultiThreadedCompositor(
     std::shared_ptr<mg::Display> const& display,
     std::shared_ptr<mc::Scene> const& scene,
-    std::shared_ptr<DisplayBufferCompositorFactory> const& db_compositor_factory)
+    std::shared_ptr<DisplayBufferCompositorFactory> const& db_compositor_factory,
+    std::shared_ptr<CompositorReport> const& compositor_report,
+    bool compose_on_start)
     : display{display},
       scene{scene},
-      display_buffer_compositor_factory{db_compositor_factory}
+      display_buffer_compositor_factory{db_compositor_factory},
+      report{compositor_report},
+      started{false},
+      compose_on_start{compose_on_start}
 {
 }
 
@@ -147,12 +163,28 @@ mc::MultiThreadedCompositor::~MultiThreadedCompositor()
     stop();
 }
 
+void mc::MultiThreadedCompositor::schedule_compositing()
+{
+    std::unique_lock<std::mutex> lk(started_guard);
+    report->scheduled();
+    for (auto& f : thread_functors)
+        f->schedule_compositing();
+}
+
 void mc::MultiThreadedCompositor::start()
 {
+    std::unique_lock<std::mutex> lk(started_guard);
+    if (started)
+    {
+        return;
+    }
+
+    report->started();
+
     /* Start the compositing threads */
     display->for_each_display_buffer([this](mg::DisplayBuffer& buffer)
     {
-        auto thread_functor_raw = new mc::CompositingFunctor{display_buffer_compositor_factory, buffer};
+        auto thread_functor_raw = new mc::CompositingFunctor{display_buffer_compositor_factory, buffer, report};
         auto thread_functor = std::unique_ptr<mc::CompositingFunctor>(thread_functor_raw);
 
         threads.push_back(std::thread{std::ref(*thread_functor)});
@@ -162,18 +194,31 @@ void mc::MultiThreadedCompositor::start()
     /* Recomposite whenever the scene changes */
     scene->set_change_callback([this]()
     {
-        for (auto& f : thread_functors)
-            f->schedule_compositing();
+        schedule_compositing();
     });
 
-    /* First render */
-    for (auto& f : thread_functors)
-        f->schedule_compositing();
+    started = true;
+
+    /* Optional first render */
+    if (compose_on_start)
+    {
+        lk.unlock();
+        schedule_compositing();
+    }
+
 }
 
 void mc::MultiThreadedCompositor::stop()
 {
+    std::unique_lock<std::mutex> lk(started_guard);
+    if (!started)
+    {
+        return;
+    }
+
+    lk.unlock();
     scene->set_change_callback([]{});
+    lk.lock();
 
     for (auto& f : thread_functors)
         f->stop();
@@ -183,4 +228,12 @@ void mc::MultiThreadedCompositor::stop()
 
     thread_functors.clear();
     threads.clear();
+
+    report->stopped();
+
+    started = false;
+
+    // If the compositor is restarted we've likely got clients blocked
+    // so we will need to schedule compositing immediately
+    compose_on_start = true;
 }
