@@ -16,24 +16,22 @@
  * Authored by: Kevin DuBois <kevin.dubois@canonical.com>
  */
 
-#include "mir/compositor/rendering_operator.h"
+#include "rendering_operator.h"
+#include "mir/compositor/buffer_stream.h"
+#include "mir/graphics/renderable.h"
 
-namespace ms=mir::surfaces;
 namespace mc=mir::compositor;
 
 mc::RenderingOperator::RenderingOperator(
-    Renderer& renderer,
-    std::function<void(std::shared_ptr<void> const&)> save_resource) :
-    renderer(renderer),
-    save_resource(save_resource)
+    Renderer& renderer)
+    : renderer(renderer)
 {
 }
 
-mc::RenderingOperator::~RenderingOperator()
+void mc::RenderingOperator::operator()(graphics::Renderable const& renderable)
 {
-}
-
-void mc::RenderingOperator::operator()(CompositingCriteria const& info, ms::BufferStream& stream)
-{
-    renderer.render(save_resource, info, stream);
+    auto compositor_buffer = renderable.buffer(&renderer);
+    // preserves buffers used in rendering until after post_update()
+    saved_resources.push_back(compositor_buffer);
+    renderer.render(renderable, *compositor_buffer);
 }
