@@ -28,7 +28,7 @@
  *
  * The successive stages are contiguous elements in the ring (starting at
  * element "first_compositor"):
- *    first_compositor * ncompositors(one or more)
+ *    first_compositor * ncompositors(zero or more)
  *    first_ready      * nready(zero or more)
  *    first_client     * nclients(zero or more)
  *
@@ -61,6 +61,7 @@
 
 #include <boost/throw_exception.hpp>
 #include <utility>
+#include <ostream>
 
 namespace mc=mir::compositor;
 namespace mg = mir::graphics;
@@ -72,22 +73,28 @@ mc::SwitchingBundle::SwitchingBundle(
     : bundle_properties{property_request},
       gralloc{gralloc},
       nbuffers{nbuffers},
-      first_compositor{0}, ncompositors{1},
-      first_ready{first_compositor + ncompositors}, nready{0},
-      first_client{first_ready + nready}, nclients{0},
+      first_compositor{0}, ncompositors{0},
+      first_ready{0}, nready{0},
+      first_client{0}, nclients{0},
       snapshot{-1}, nsnapshotters{0},
-      last_consumed{0},
       overlapping_compositors{false},
       framedropping{false}, force_drop{0}
 {
-    if (nbuffers < 2 || nbuffers > MAX_NBUFFERS)
+    if (nbuffers < min_buffers || nbuffers > max_buffers)
     {
         BOOST_THROW_EXCEPTION(std::logic_error("SwitchingBundle only supports "
-                                               "nbuffers between 2 and " +
-                                               std::to_string(MAX_NBUFFERS)));
+                                               "nbuffers between " +
+                                               std::to_string(min_buffers) +
+                                               " and " +
+                                               std::to_string(max_buffers)));
     }
 }
 
+mc::SwitchingBundle::~SwitchingBundle() noexcept
+{
+    force_requests_to_complete();
+}
+
 int mc::SwitchingBundle::nfree() const
 {
     return nbuffers - ncompositors - nready - nclients;
@@ -175,9 +182,33 @@ const std::shared_ptr<mg::Buffer> &mc::SwitchingBundle::alloc_buffer(int slot)
     return ring[slot].buf;
 }
 
-std::shared_ptr<mg::Buffer> mc::SwitchingBundle::client_acquire()
+inline
+bool mc::SwitchingBundle::client_buffers_available(std::unique_lock<std::mutex> const& /*lock*/)
+{
+    /*
+     * Even if there are free buffers available, we might wish to still
+     * wait. This is so we don't touch (hence allocate) a third or higher
+     * buffer until/unless it's absolutely necessary. It becomes necessary
+     * only when framedropping (above) or with overlapping compositors
+     * (like with bypass).
+     * The performance benefit of triple buffering is usually minimal,
+     * but always uses 50% more memory. So try to avoid it when possible.
+     */
+
+    int min_free =
+#if 0  // FIXME: This memory optimization breaks timing tests
+        (nbuffers > 2 && !overlapping_compositors) ?  nbuffers - 1 : 1;
+#else
+        1;
+#endif
+
+    return nfree() >= min_free;
+}
+
+void mc::SwitchingBundle::client_acquire(std::function<void(graphics::Buffer* buffer)> complete)
 {
     std::unique_lock<std::mutex> lock(guard);
+    client_acquire_todo = std::move(complete);
 
     if ((framedropping || force_drop) && nbuffers > 1)
     {
@@ -191,27 +222,17 @@ std::shared_ptr<mg::Buffer> mc::SwitchingBundle::client_acquire()
     }
     else
     {
-        /*
-         * Even if there are free buffers available, we might wish to still
-         * wait. This is so we don't touch (hence allocate) a third or higher
-         * buffer until/unless it's absolutely necessary. It becomes necessary
-         * only when framedropping (above) or with overlapping compositors
-         * (like with bypass).
-         * The performance benefit of triple buffering is usually minimal,
-         * but always uses 50% more memory. So try to avoid it when possible.
-         */
-
-        int min_free = 
-#if 0  // FIXME: This memory optimization breaks timing tests
-            (nbuffers > 2 && !overlapping_compositors) ?  nbuffers - 1 : 1;
-#else
-            1;
-#endif
-
-        while (nfree() < min_free)
-            cond.wait(lock);
+        if (!client_buffers_available(lock))
+            return;
     }
 
+    complete_client_acquire(std::move(lock));
+}
+
+void mc::SwitchingBundle::complete_client_acquire(std::unique_lock<std::mutex> lock)
+{
+    auto complete = std::move(client_acquire_todo);
+
     if (force_drop > 0)
         force_drop--;
 
@@ -239,14 +260,29 @@ std::shared_ptr<mg::Buffer> mc::SwitchingBundle::client_acquire()
         }
     }
 
-    return ret;
+    if (ret->size() != bundle_properties.size)
+    {
+        ret = gralloc->alloc_buffer(bundle_properties);
+        ring[client].buf = ret;
+    }
+
+    lock.unlock();
+
+    try
+    {
+        complete(ret.get());
+    }
+    catch (...)
+    {
+        // TODO comms errors should not propagate to compositing threads
+    }
 }
 
-void mc::SwitchingBundle::client_release(std::shared_ptr<mg::Buffer> const& released_buffer)
+void mc::SwitchingBundle::client_release(graphics::Buffer* released_buffer)
 {
     std::unique_lock<std::mutex> lock(guard);
 
-    if (nclients <= 0 || ring[first_client].buf != released_buffer)
+    if (nclients <= 0 || ring[first_client].buf.get() != released_buffer)
     {
         BOOST_THROW_EXCEPTION(std::logic_error(
             "Client release out of order"));
@@ -259,14 +295,34 @@ void mc::SwitchingBundle::client_release(std::shared_ptr<mg::Buffer> const& rele
 }
 
 std::shared_ptr<mg::Buffer> mc::SwitchingBundle::compositor_acquire(
-    unsigned long frameno)
+    void const* user_id)
 {
     std::unique_lock<std::mutex> lock(guard);
     int compositor;
 
-    if (!nready || frameno == last_consumed)
+    // Multi-monitor acquires close to each other get the same frame:
+    bool same_frame = !users.empty() && users.find(user_id) == users.end();
+
+    int avail = nfree();
+    bool can_recycle = ncompositors || avail;
+
+    if (!nready || (same_frame && can_recycle))
     {
-        compositor = last_compositor();
+        if (ncompositors)
+        {
+            compositor = last_compositor();
+        }
+        else if (avail)
+        {
+            first_compositor = prev(first_compositor);
+            compositor = first_compositor;
+            ncompositors++;
+        }
+        else
+        {
+            BOOST_THROW_EXCEPTION(std::logic_error(
+                "compositor_acquire would block; probably too many clients."));
+        }
     }
     else
     {
@@ -274,14 +330,11 @@ std::shared_ptr<mg::Buffer> mc::SwitchingBundle::compositor_acquire(
         first_ready = next(first_ready);
         nready--;
         ncompositors++;
-        last_consumed = frameno;
 
-        while (ncompositors > 1 && !ring[first_compositor].users)
-        {
-            first_compositor = next(first_compositor);
-            ncompositors--;
-        }
+        // Fresh frame! Ensure all users get it at most once...
+        users.clear();
     }
+    users.insert(user_id);
 
     overlapping_compositors = (ncompositors > 1);
 
@@ -303,7 +356,7 @@ void mc::SwitchingBundle::compositor_release(std::shared_ptr<mg::Buffer> const&
         }
     }
 
-    if (compositor < 0 || ring[compositor].users <= 0)
+    if (compositor < 0)
     {
         BOOST_THROW_EXCEPTION(std::logic_error(
             "compositor_release given a non-compositor buffer"));
@@ -312,12 +365,14 @@ void mc::SwitchingBundle::compositor_release(std::shared_ptr<mg::Buffer> const&
     ring[compositor].users--;
     if (compositor == first_compositor)
     {
-        while (ncompositors > 1 && !ring[first_compositor].users)
+        while (!ring[first_compositor].users && ncompositors)
         {
             first_compositor = next(first_compositor);
             ncompositors--;
         }
-        cond.notify_all();
+
+        if (client_buffers_available(lock) && client_acquire_todo)
+            complete_client_acquire(std::move(lock));
     }
 }
 
@@ -370,22 +425,56 @@ void mc::SwitchingBundle::snapshot_release(std::shared_ptr<mg::Buffer> const& re
 void mc::SwitchingBundle::force_requests_to_complete()
 {
     std::unique_lock<std::mutex> lock(guard);
-    drop_frames(nready);
-    force_drop = nbuffers + 1;
-    cond.notify_all();
+    if (client_acquire_todo)
+    {
+        drop_frames(nready);
+        force_drop = nbuffers + 1;
+        complete_client_acquire(std::move(lock));
+    }
 }
 
 void mc::SwitchingBundle::allow_framedropping(bool allow_dropping)
 {
+    std::unique_lock<std::mutex> lock(guard);
     framedropping = allow_dropping;
 }
 
 bool mc::SwitchingBundle::framedropping_allowed() const
 {
+    std::unique_lock<std::mutex> lock(guard);
     return framedropping;
 }
 
 mg::BufferProperties mc::SwitchingBundle::properties() const
 {
+    std::unique_lock<std::mutex> lock(guard);
     return bundle_properties;
 }
+
+void mc::SwitchingBundle::resize(const geometry::Size &newsize)
+{
+    std::unique_lock<std::mutex> lock(guard);
+    bundle_properties.size = newsize;
+}
+
+int mc::SwitchingBundle::buffers_ready_for_compositor() const
+{
+    std::unique_lock<std::mutex> lock(guard);
+    return nready;
+}
+
+std::ostream& mc::operator<<(std::ostream& os, const mc::SwitchingBundle& bundle)
+{
+    os << "("
+        << (void*)(&bundle)
+        << ",nbuffers=" << bundle.nbuffers
+        << ",first_compositor=" << bundle.first_compositor
+        << ",ncompositors=" << bundle.ncompositors
+        << ",first_ready=" << bundle.first_ready
+        << ",nready=" << bundle.nready
+        << ",first_client=" << bundle.first_client
+        << ",nclients=" << bundle.nclients
+        << ")";
+
+    return os;
+}
