@@ -24,6 +24,8 @@
 #include <condition_variable>
 #include <mutex>
 #include <memory>
+#include <iosfwd>
+#include <unordered_set>
 
 namespace mir
 {
@@ -35,19 +37,23 @@ class GraphicBufferAllocator;
 namespace compositor
 {
 
-class SwitchingBundle : public BufferBundle 
+class SwitchingBundle : public BufferBundle
 {
 public:
+    enum {min_buffers = 1, max_buffers = 5};
+
     SwitchingBundle(int nbuffers,
                     const std::shared_ptr<graphics::GraphicBufferAllocator> &,
                     const graphics::BufferProperties &);
 
+    ~SwitchingBundle() noexcept;
+
     graphics::BufferProperties properties() const;
 
-    std::shared_ptr<graphics::Buffer> client_acquire();
-    void client_release(std::shared_ptr<graphics::Buffer> const&);
+    void client_acquire(std::function<void(graphics::Buffer* buffer)> complete) override;
+    void client_release(graphics::Buffer* buffer);
     std::shared_ptr<graphics::Buffer>
-        compositor_acquire(unsigned long frameno) override;
+        compositor_acquire(void const* user_id) override;
     void compositor_release(std::shared_ptr<graphics::Buffer> const& released_buffer);
     std::shared_ptr<graphics::Buffer> snapshot_acquire();
     void snapshot_release(std::shared_ptr<graphics::Buffer> const& released_buffer);
@@ -55,6 +61,15 @@ public:
     void allow_framedropping(bool dropping_allowed);
     bool framedropping_allowed() const;
 
+    /**
+     * Change the dimensions of the buffers contained in the bundle. For
+     * client_acquire, the change is guaranteed to be immediate. For
+     * compositors and snapshotters however, the change may be delayed by
+     * nbuffers frames while old frames of the old size are consumed.
+     */
+    void resize(const geometry::Size &newsize) override;
+    int buffers_ready_for_compositor() const override;
+
 private:
     graphics::BufferProperties bundle_properties;
     std::shared_ptr<graphics::GraphicBufferAllocator> gralloc;
@@ -67,14 +82,14 @@ private:
     int last_compositor() const;
 
     const std::shared_ptr<graphics::Buffer> &alloc_buffer(int slot);
-
-    enum {MAX_NBUFFERS = 5};
+    void complete_client_acquire(std::unique_lock<std::mutex> lock);
+    bool client_buffers_available(std::unique_lock<std::mutex> const& lock);
     struct SharedBuffer
     {
         std::shared_ptr<graphics::Buffer> buf;
         int users = 0; // presently just a count of compositors sharing the buf
     };
-    SharedBuffer ring[MAX_NBUFFERS];
+    SharedBuffer ring[max_buffers];
 
     const int nbuffers;
     int first_compositor;
@@ -86,17 +101,24 @@ private:
     int snapshot;
     int nsnapshotters;
 
-    std::mutex guard;
+    mutable std::mutex guard;
     std::condition_variable cond;
 
-    unsigned long last_consumed;
+    std::unordered_set<void const*> users;
 
     bool overlapping_compositors;
 
     bool framedropping;
     int force_drop;
+
+    std::function<void(graphics::Buffer* buffer)> client_acquire_todo;
+
+    friend std::ostream& operator<<(std::ostream& os, const SwitchingBundle& bundle);
 };
 
+// for use when debugging. e.g "std::cout << *this << std::endl;"
+std::ostream& operator<<(std::ostream& os, const SwitchingBundle& bundle);
+
 }
 }
 
