@@ -28,21 +28,9 @@ mc::TemporaryBuffer::TemporaryBuffer(std::shared_ptr<mg::Buffer> const& real_buf
 {
 }
 
-mc::TemporaryClientBuffer::TemporaryClientBuffer(std::shared_ptr<BufferBundle> const& buffer_swapper)
-    : TemporaryBuffer(buffer_swapper->client_acquire()),
-      allocating_swapper(buffer_swapper)
-{
-}
-
-mc::TemporaryClientBuffer::~TemporaryClientBuffer()
-{
-    if (auto swapper = allocating_swapper.lock())
-        swapper->client_release(buffer);
-}
-
 mc::TemporaryCompositorBuffer::TemporaryCompositorBuffer(
-    std::shared_ptr<BufferBundle> const& bun, unsigned long frameno)
-    : TemporaryBuffer(bun->compositor_acquire(frameno)),
+    std::shared_ptr<BufferBundle> const& bun, void const* user_id)
+    : TemporaryBuffer(bun->compositor_acquire(user_id)),
       bundle(bun)
 {
 }
@@ -74,7 +62,7 @@ geom::Stride mc::TemporaryBuffer::stride() const
     return buffer->stride();
 }
 
-geom::PixelFormat mc::TemporaryBuffer::pixel_format() const
+MirPixelFormat mc::TemporaryBuffer::pixel_format() const
 {
     return buffer->pixel_format();
 }
