@@ -37,7 +37,7 @@ class TemporaryBuffer : public mg::Buffer
 public:
     geometry::Size size() const;
     geometry::Stride stride() const;
-    geometry::PixelFormat pixel_format() const;
+    MirPixelFormat pixel_format() const;
     mg::BufferID id() const;
     void bind_to_texture();
     std::shared_ptr<mg::NativeBuffer> native_buffer_handle() const;
@@ -48,21 +48,11 @@ protected:
     std::shared_ptr<mg::Buffer> const buffer;
 };
 
-class TemporaryClientBuffer : public TemporaryBuffer
-{
-public:
-    explicit TemporaryClientBuffer(std::shared_ptr<BufferBundle> const& buffer_swapper);
-    ~TemporaryClientBuffer();
-
-private:
-    std::weak_ptr<BufferBundle> const allocating_swapper;
-};
-
 class TemporaryCompositorBuffer : public TemporaryBuffer
 {
 public:
     explicit TemporaryCompositorBuffer(
-        std::shared_ptr<BufferBundle> const& bun, unsigned long frameno);
+        std::shared_ptr<BufferBundle> const& bun, void const* user_id);
     ~TemporaryCompositorBuffer();
 
 private:
