@@ -21,12 +21,13 @@
 #include "mir/display_server.h"
 #include "mir/server_configuration.h"
 #include "mir/main_loop.h"
-#include "mir/pause_resume_listener.h"
+#include "mir/server_status_listener.h"
 #include "mir/display_changer.h"
 
 #include "mir/compositor/compositor.h"
 #include "mir/frontend/connector.h"
 #include "mir/graphics/display.h"
+#include "mir/graphics/display_configuration.h"
 #include "mir/input/input_manager.h"
 
 #include <stdexcept>
@@ -75,7 +76,7 @@ struct mir::DisplayServer::Private
           connector{config.the_connector()},
           input_manager{config.the_input_manager()},
           main_loop{config.the_main_loop()},
-          pause_resume_listener{config.the_pause_resume_listener()},
+          server_status_listener{config.the_server_status_listener()},
           display_changer{config.the_display_changer()},
           paused{false},
           configure_display_on_resume{false}
@@ -115,7 +116,7 @@ struct mir::DisplayServer::Private
             return false;
         }
 
-        pause_resume_listener->paused();
+        server_status_listener->paused();
 
         return true;
     }
@@ -134,7 +135,8 @@ struct mir::DisplayServer::Private
 
             if (configure_display_on_resume)
             {
-                auto conf = display->configuration();
+                std::shared_ptr<graphics::DisplayConfiguration> conf =
+                    display->configuration();
                 display_changer->configure_for_hardware_change(
                     conf, DisplayChanger::RetainSystemState);
                 configure_display_on_resume = false;
@@ -153,7 +155,7 @@ struct mir::DisplayServer::Private
             return false;
         }
 
-        pause_resume_listener->resumed();
+        server_status_listener->resumed();
 
         return true;
     }
@@ -162,7 +164,8 @@ struct mir::DisplayServer::Private
     {
         if (!paused)
         {
-            auto conf = display->configuration();
+            std::shared_ptr<graphics::DisplayConfiguration> conf =
+                display->configuration();
             display_changer->configure_for_hardware_change(
                 conf, DisplayChanger::PauseResumeSystem);
         }
@@ -179,7 +182,7 @@ struct mir::DisplayServer::Private
     std::shared_ptr<mf::Connector> const connector;
     std::shared_ptr<mi::InputManager> const input_manager;
     std::shared_ptr<mir::MainLoop> const main_loop;
-    std::shared_ptr<mir::PauseResumeListener> const pause_resume_listener;
+    std::shared_ptr<mir::ServerStatusListener> const server_status_listener;
     std::shared_ptr<mir::DisplayChanger> const display_changer;
     bool paused;
     bool configure_display_on_resume;
@@ -205,6 +208,8 @@ void mir::DisplayServer::run()
     p->compositor->start();
     p->input_manager->start();
 
+    p->server_status_listener->started();
+
     p->main_loop->run();
 
     p->input_manager->stop();
