@@ -18,10 +18,9 @@
 #ifndef MIR_FRONTEND_MESSAGE_SENDER_H_
 #define MIR_FRONTEND_MESSAGE_SENDER_H_
 
-#include "fd_sets.h"
+#include "mir/frontend/fd_sets.h"
 
-#include <vector>
-#include <boost/asio.hpp>
+#include <sys/types.h>
 
 namespace mir
 {
@@ -32,8 +31,7 @@ namespace detail
 class MessageSender
 {
 public:
-    virtual void send(std::string const& body) = 0;
-    virtual void send(std::string const& body, FdSets const& fds) = 0;
+    virtual void send(char const* data, size_t length, FdSets const& fds) = 0;
 
 protected:
     MessageSender() = default;
