@@ -17,9 +17,11 @@
  */
 
 #include "socket_session.h"
-#include "message_processor.h"
 #include "message_sender.h"
 #include "message_receiver.h"
+#include "mir/frontend/message_processor.h"
+
+#include "mir_protobuf_wire.pb.h"
 
 #include <boost/signals2.hpp>
 #include <boost/throw_exception.hpp>
@@ -53,10 +55,9 @@ mfd::SocketSession::~SocketSession() noexcept
 
 void mfd::SocketSession::read_next_message()
 {
-    size_t const header_size = 2;
     auto callback = std::bind(&mfd::SocketSession::on_read_size,
                         this, std::placeholders::_1);
-    socket_receiver->async_receive_msg(callback, message, header_size);
+    socket_receiver->async_receive_msg(callback, ba::buffer(header, header_size));
 }
 
 void mfd::SocketSession::on_read_size(const boost::system::error_code& error)
@@ -66,27 +67,40 @@ void mfd::SocketSession::on_read_size(const boost::system::error_code& error)
         connected_sessions->remove(id());
         BOOST_THROW_EXCEPTION(std::runtime_error(error.message()));
     }
-  
-    unsigned char high_byte = message.sbumpc();
-    unsigned char low_byte = message.sbumpc();
+
+    unsigned char const high_byte = header[0];
+    unsigned char const low_byte = header[1];
     size_t const body_size = (high_byte << 8) + low_byte;
 
-    auto callback = std::bind(&mfd::SocketSession::on_new_message,
-                        this, std::placeholders::_1);
-    socket_receiver->async_receive_msg(callback, message, body_size);
+    body.resize(body_size);
+
+    if (socket_receiver->available_bytes() >= body_size)
+    {
+        on_new_message(socket_receiver->receive_msg(ba::buffer(body)));
+    }
+    else
+    {
+        auto callback = std::bind(&mfd::SocketSession::on_new_message,
+                                  this, std::placeholders::_1);
+        socket_receiver->async_receive_msg(callback, ba::buffer(body));
+    }
 }
 
 void mfd::SocketSession::on_new_message(const boost::system::error_code& error)
+try
 {
     if (error)
     {
-        connected_sessions->remove(id());
         BOOST_THROW_EXCEPTION(std::runtime_error(error.message()));
     }
 
-    std::istream msg(&message);
+    mir::protobuf::wire::Invocation invocation;
+    invocation.ParseFromArray(body.data(), body.size());
 
-    if (processor->process_message(msg))
+    if (!invocation.has_protocol_version() || invocation.protocol_version() != 1)
+        BOOST_THROW_EXCEPTION(std::runtime_error("Unsupported protocol version"));
+
+    if (processor->dispatch(invocation))
     {
         read_next_message();
     }
@@ -95,6 +109,11 @@ void mfd::SocketSession::on_new_message(const boost::system::error_code& error)
         connected_sessions->remove(id());
     }
 }
+catch (...)
+{
+    connected_sessions->remove(id());
+    throw;
+}
 
 void mfd::SocketSession::on_response_sent(bs::error_code const& error, std::size_t)
 {
