@@ -20,8 +20,7 @@
 #ifndef MIR_FRONTEND_DETAIL_SOCKET_SESSION_H_
 #define MIR_FRONTEND_DETAIL_SOCKET_SESSION_H_
 
-#include "message_processor.h"
-#include "connected_sessions.h"
+#include "mir/frontend/connected_sessions.h"
 
 #include <boost/asio.hpp>
 
@@ -33,7 +32,7 @@ namespace frontend
 {
 namespace detail
 {
-
+class MessageProcessor;
 class MessageReceiver;
 
 struct SocketSession
@@ -60,8 +59,9 @@ private:
     std::shared_ptr<ConnectedSessions<SocketSession>> const connected_sessions;
     std::shared_ptr<MessageProcessor> processor;
 
-    boost::asio::streambuf header;
-    boost::asio::streambuf message;
+    static size_t const header_size = 2;
+    char header[header_size];
+    std::vector<char> body;
 };
 
 }
