@@ -16,13 +16,13 @@
  * Authored by: Eleni Maria Stea <elenimaria.stea@canonical.com>
  */
 
-#include "mir/graphics/nested/host_connection.h"
+#include "host_connection.h"
 #include "mir_toolkit/mir_client_library.h"
 
 namespace mgn = mir::graphics::nested;
 
-mgn::HostConnection::HostConnection(std::string const& host_socket, std::string const& nested_socket)
-    : connection{mir_connect_sync(host_socket.c_str(), ("nested-mir@:"+nested_socket).c_str())}
+mgn::HostConnection::HostConnection(std::string const& host_socket, std::string const& name)
+    : connection{mir_connect_sync(host_socket.c_str(), name.c_str())}
 {
 }
 
