@@ -25,7 +25,7 @@ namespace geom = mir::geometry;
 
 msh::SurfaceCreationParameters::SurfaceCreationParameters()
     : name(), size(), top_left(), buffer_usage(mg::BufferUsage::undefined),
-      pixel_format(geom::PixelFormat::invalid),
+      pixel_format(mir_pixel_format_invalid),
       depth{0}, input_mode(mi::InputReceptionMode::normal)
 {
 }
@@ -55,7 +55,7 @@ msh::SurfaceCreationParameters& msh::SurfaceCreationParameters::of_size(
 msh::SurfaceCreationParameters& msh::SurfaceCreationParameters::of_position(geometry::Point const& new_top_left)
 {
     top_left = new_top_left;
-    
+
     return *this;
 }
 
@@ -68,7 +68,7 @@ msh::SurfaceCreationParameters& msh::SurfaceCreationParameters::of_buffer_usage(
 }
 
 msh::SurfaceCreationParameters& msh::SurfaceCreationParameters::of_pixel_format(
-    geom::PixelFormat new_pixel_format)
+    MirPixelFormat new_pixel_format)
 {
     pixel_format = new_pixel_format;
 
@@ -76,17 +76,17 @@ msh::SurfaceCreationParameters& msh::SurfaceCreationParameters::of_pixel_format(
 }
 
 msh::SurfaceCreationParameters& msh::SurfaceCreationParameters::of_depth(
-    surfaces::DepthId const& new_depth)
+    scene::DepthId const& new_depth)
 {
     depth = new_depth;
-    
+
     return *this;
 }
 
 msh::SurfaceCreationParameters& msh::SurfaceCreationParameters::with_input_mode(input::InputReceptionMode const& new_mode)
 {
     input_mode = new_mode;
-    
+
     return *this;
 }
 
@@ -102,7 +102,7 @@ bool msh::operator==(
     const SurfaceCreationParameters& lhs,
     const msh::SurfaceCreationParameters& rhs)
 {
-    return lhs.name == rhs.name && 
+    return lhs.name == rhs.name &&
         lhs.size == rhs.size &&
         lhs.top_left == rhs.top_left &&
         lhs.buffer_usage == rhs.buffer_usage &&
