@@ -69,10 +69,8 @@ int perform_static(ANativeWindow* window, int key, ...)
 int dequeueBuffer_deprecated_static (struct ANativeWindow* window,
                           struct ANativeWindowBuffer** buffer)
 {
-    int fence_fd = -1;
     auto self = static_cast<mga::MirNativeWindow*>(window);
-    //todo: we have to close the fence
-    return self->dequeueBuffer(buffer, &fence_fd);
+    return self->dequeueBufferAndWait(buffer);
 }
 
 int dequeueBuffer_static (struct ANativeWindow* window,
@@ -110,16 +108,17 @@ int lockBuffer_static(struct ANativeWindow* /*window*/,
     return 0;
 }
 
-int cancelBuffer_deprecated_static(struct ANativeWindow* /*window*/,
-                        struct ANativeWindowBuffer* /*buffer*/)
+int cancelBuffer_deprecated_static(struct ANativeWindow* window,
+                        struct ANativeWindowBuffer* buffer)
 {
-    return 0;
+    return cancelBuffer_static(window, buffer, -1);
 }
 
-int cancelBuffer_static(struct ANativeWindow* /*window*/,
-                        struct ANativeWindowBuffer* /*buffer*/, int /*fence_fd*/)
+int cancelBuffer_static(struct ANativeWindow* window,
+                        struct ANativeWindowBuffer* buffer, int fence_fd)
 {
-    return 0;
+    auto self = static_cast<mga::MirNativeWindow*>(window);
+    return self->cancelBuffer(buffer, fence_fd);
 }
 
 }
@@ -151,7 +150,7 @@ int mga::MirNativeWindow::setSwapInterval(int interval)
     {
         driver_interpreter->sync_to_display(false);
     }
-    else 
+    else
     {
         driver_interpreter->sync_to_display(true);
     }
@@ -168,12 +167,26 @@ int mga::MirNativeWindow::dequeueBuffer(struct ANativeWindowBuffer** buffer_to_d
     return 0;
 }
 
+int mga::MirNativeWindow::dequeueBufferAndWait(struct ANativeWindowBuffer** buffer_to_driver)
+{
+    auto buffer = driver_interpreter->driver_requests_buffer();
+    *buffer_to_driver = buffer->anwb();
+    buffer->wait_for_content();
+    return 0;
+}
+
 int mga::MirNativeWindow::queueBuffer(struct ANativeWindowBuffer* buffer, int fence)
 {
     driver_interpreter->driver_returns_buffer(buffer, fence);
     return 0;
 }
 
+int mga::MirNativeWindow::cancelBuffer(struct ANativeWindowBuffer* buffer, int fence)
+{
+    driver_interpreter->driver_returns_buffer(buffer, fence);
+    return 0;
+}
+
 int mga::MirNativeWindow::query(int key, int* value) const
 {
     *value = driver_interpreter->driver_requests_info(key);
