@@ -18,9 +18,8 @@
  */
 
 #include "mir/frontend/session_authorizer.h"
-#include "mir/graphics/graphic_buffer_allocator.h"
 #include "mir/graphics/event_handler_register.h"
-#include "mir/frontend/global_event_sender.h"
+#include "src/server/scene/global_event_sender.h"
 
 #include "mir_test_framework/display_server_test_fixture.h"
 #include "mir_test_framework/cross_process_sync.h"
@@ -31,6 +30,8 @@
 #include "mir_test_doubles/null_platform.h"
 #include "mir_test/display_config_matchers.h"
 #include "mir_test_doubles/stub_display_configuration.h"
+#include "mir_test_doubles/stub_buffer_allocator.h"
+#include "mir_test_doubles/stub_session_authorizer.h"
 #include "mir_test/fake_shared.h"
 #include "mir_test/pipe.h"
 #include "mir_test/cross_process_action.h"
@@ -87,9 +88,11 @@ public:
         f(display_buffer);
     }
 
-    std::shared_ptr<mg::DisplayConfiguration> configuration()
+    std::unique_ptr<mg::DisplayConfiguration> configuration() const override
     {
-        return config;
+        return std::unique_ptr<mg::DisplayConfiguration>(
+            new mtd::StubDisplayConfig(*config)
+        );
     }
 
     void register_configuration_change_handler(
@@ -112,7 +115,7 @@ public:
     MOCK_METHOD1(configure, void(mg::DisplayConfiguration const&));
 
     void emit_configuration_change_event(
-        std::shared_ptr<mg::DisplayConfiguration> const& new_config)
+        std::shared_ptr<mtd::StubDisplayConfig> const& new_config)
     {
         config = new_config;
         if (write(p.write_fd(), "a", 1)) {}
@@ -125,37 +128,24 @@ public:
     }
 
 private:
-    std::shared_ptr<mg::DisplayConfiguration> config;
+    std::shared_ptr<mtd::StubDisplayConfig> config;
     mtd::NullDisplayBuffer display_buffer;
     mt::Pipe p;
     std::atomic<bool> handler_called;
 };
 
-class StubGraphicBufferAllocator : public mg::GraphicBufferAllocator
-{
-public:
-    std::shared_ptr<mg::Buffer> alloc_buffer(mg::BufferProperties const&)
-    {
-        return {};
-    }
-
-    std::vector<geom::PixelFormat> supported_pixel_formats()
-    {
-        return {};
-    }
-};
-
 class StubPlatform : public mtd::NullPlatform
 {
 public:
     std::shared_ptr<mg::GraphicBufferAllocator> create_buffer_allocator(
             std::shared_ptr<mg::BufferInitializer> const& /*buffer_initializer*/) override
     {
-        return std::make_shared<StubGraphicBufferAllocator>();
+        return std::make_shared<mtd::StubBufferAllocator>();
     }
 
     std::shared_ptr<mg::Display> create_display(
-        std::shared_ptr<mg::DisplayConfigurationPolicy> const&) override
+        std::shared_ptr<mg::DisplayConfigurationPolicy> const&,
+        std::shared_ptr<mg::GLConfig> const&) override
     {
         return mt::fake_shared(mock_display);
     }
@@ -348,10 +338,9 @@ TEST_F(DisplayConfigurationTest, display_change_request_for_unauthorized_client_
     {
         std::shared_ptr<mf::SessionAuthorizer> the_session_authorizer() override
         {
-            class StubAuthorizer : public mf::SessionAuthorizer
+            class StubAuthorizer : public mtd::StubSessionAuthorizer
             {
-                bool connection_is_allowed(pid_t) { return true; }
-                bool configure_display_is_allowed(pid_t) { return false; }
+                bool configure_display_is_allowed(pid_t) override { return false; }
             };
 
             if (!authorizer)
