@@ -18,11 +18,10 @@
 
 #include "mir_toolkit/mir_client_library.h"
 
-#include "mir/shell/session_container.h"
-#include "mir/shell/registration_order_focus_sequence.h"
-#include "mir/shell/consuming_placement_strategy.h"
-#include "mir/shell/organising_surface_factory.h"
-#include "mir/shell/session_manager.h"
+#include "src/server/scene/session_container.h"
+#include "src/server/shell/consuming_placement_strategy.h"
+#include "src/server/shell/organising_surface_factory.h"
+#include "src/server/scene/session_manager.h"
 #include "mir/graphics/display.h"
 #include "mir/shell/input_targeter.h"
 
@@ -49,60 +48,13 @@ namespace
 namespace
 {
 
-struct ClientConfigCommon : TestingClientConfiguration
-{
-    ClientConfigCommon() :
-        connection(0),
-        surface(0)
-    {
-    }
-
-    static void connection_callback(MirConnection* connection, void* context)
-    {
-        ClientConfigCommon* config = reinterpret_cast<ClientConfigCommon *>(context);
-        config->connection = connection;
-    }
-
-    static void create_surface_callback(MirSurface* surface, void* context)
-    {
-        ClientConfigCommon* config = reinterpret_cast<ClientConfigCommon *>(context);
-        config->surface_created(surface);
-    }
-
-    static void release_surface_callback(MirSurface* surface, void* context)
-    {
-        ClientConfigCommon* config = reinterpret_cast<ClientConfigCommon *>(context);
-        config->surface_released(surface);
-    }
-
-    virtual void connected(MirConnection* new_connection)
-    {
-        connection = new_connection;
-    }
-
-    virtual void surface_created(MirSurface* new_surface)
-    {
-        surface = new_surface;
-    }
-
-    virtual void surface_released(MirSurface* /*released_surface*/)
-    {
-        surface = NULL;
-    }
-
-    MirConnection* connection;
-    MirSurface* surface;
-};
-
-struct SurfaceCreatingClient : ClientConfigCommon
+struct SurfaceCreatingClient : mtf::TestingClientConfiguration
 {
     void exec()
     {
-        mir_wait_for(mir_connect(
+        connection = mir_connect_sync(
             mir_test_socket,
-            __PRETTY_FUNCTION__,
-            connection_callback,
-            this));
+            __PRETTY_FUNCTION__);
          ASSERT_TRUE(connection != NULL);
          MirSurfaceParameters const request_params =
          {
@@ -112,9 +64,12 @@ struct SurfaceCreatingClient : ClientConfigCommon
             mir_buffer_usage_hardware,
             mir_display_output_id_invalid
          };
-         mir_wait_for(mir_connection_create_surface(connection, &request_params, create_surface_callback, this));
+         surface = mir_connection_create_surface_sync(connection, &request_params);
          mir_connection_release(connection);
     }
+
+    MirConnection* connection;
+    MirSurface* surface;
 };
 
 }
@@ -181,7 +136,7 @@ TEST_F(BespokeDisplayServerTestFixture, surfaces_receive_input_focus_when_create
 
             if (!expected)
             {
-                
+
                 EXPECT_CALL(*targeter, focus_cleared()).Times(AtLeast(0));
 
                 {
