@@ -23,6 +23,8 @@
 
 #include "mir_test_framework/display_server_test_fixture.h"
 #include "mir_test/fake_event_hub_input_configuration.h"
+#include "mir_test_framework/cross_process_sync.h"
+#include "mir_test_doubles/stub_renderer.h"
 
 #include <gtest/gtest.h>
 
@@ -36,7 +38,7 @@ namespace mi = mir::input;
 namespace mia = mir::input::android;
 namespace mtf = mir_test_framework;
 namespace mtd = mir::test::doubles;
-namespace ms = mir::surfaces;
+namespace ms = mir::scene;
 namespace geom = mir::geometry;
 
 namespace
@@ -44,30 +46,12 @@ namespace
 
 char const* const mir_test_socket = mtf::test_socket_file().c_str();
 
-class NullRenderer : public mc::Renderer
-{
-public:
-    virtual void render(std::function<void(std::shared_ptr<void> const&)>,
-                                   mc::CompositingCriteria const&, ms::BufferStream&)
-    {
-        /* 
-         * Do nothing, so that the Renderable's buffers are not consumed
-         * by the server, thus causing the client to block when asking for
-         * the second buffer (assuming double-buffering).
-         */
-        std::this_thread::yield();
-    }
-
-    void clear(unsigned long) override {}
-};
-
-
-class NullRendererFactory : public mc::RendererFactory
+class StubRendererFactory : public mc::RendererFactory
 {
 public:
     std::unique_ptr<mc::Renderer> create_renderer_for(geom::Rectangle const&)
     {
-        return std::unique_ptr<mc::Renderer>(new NullRenderer());
+        return std::unique_ptr<mc::Renderer>(new mtd::StubRenderer());
     }
 };
 
@@ -125,7 +109,7 @@ TEST_F(ServerShutdown, server_can_shut_down_when_clients_are_blocked)
     {
         std::shared_ptr<mc::RendererFactory> the_renderer_factory() override
         {
-            return renderer_factory([] { return std::make_shared<NullRendererFactory>(); });
+            return renderer_factory([] { return std::make_shared<StubRendererFactory>(); });
         }
     } server_config;
 
@@ -165,7 +149,7 @@ TEST_F(ServerShutdown, server_can_shut_down_when_clients_are_blocked)
             next_buffer_done.set();
             server_done.wait();
 
-            /* 
+            /*
              * TODO: Releasing the connection to a shut down server blocks
              * the client. We should handle unexpected server shutdown more
              * gracefully on the client side.
@@ -237,7 +221,7 @@ TEST_F(ServerShutdown, server_releases_resources_on_shutdown_with_connected_clie
         {
             return DefaultServerConfiguration::the_input_targeter();
         }
-        std::shared_ptr<mir::surfaces::InputRegistrar> the_input_registrar() override
+        std::shared_ptr<mir::scene::InputRegistrar> the_input_registrar() override
         {
             return DefaultServerConfiguration::the_input_registrar();
         }
@@ -373,10 +357,13 @@ TEST_F(ServerShutdown, server_removes_endpoint_on_abort)
 {
     struct ServerConfig : TestingServerConfiguration
     {
-        void exec() override
+        void on_start() override
         {
+            sync.wait_for_signal_ready_for();
             abort();
         }
+
+        mtf::CrossProcessSync sync;
     };
 
     ServerConfig server_config;
@@ -384,13 +371,16 @@ TEST_F(ServerShutdown, server_removes_endpoint_on_abort)
 
     run_in_test_process([&]
     {
-        using std::chrono::steady_clock;
-        std::chrono::seconds const limit(2);
-
         ASSERT_TRUE(file_exists(server_config.the_socket_file()));
 
-        // shutdown should fail as the server aborted
-        ASSERT_FALSE(shutdown_server_process());
+        server_config.sync.signal_ready();
+
+        auto result = wait_for_shutdown_server_process();
+        EXPECT_EQ(mtf::TerminationReason::child_terminated_by_signal, result.reason);
+        // Under valgrind the server process is reported as being terminated
+        // by SIGKILL because of multithreading madness.
+        // TODO: Investigate if we can do better than this workaround
+        EXPECT_TRUE(result.signal == SIGABRT || result.signal == SIGKILL);
 
         EXPECT_FALSE(file_exists(server_config.the_socket_file()));
     });
@@ -402,13 +392,16 @@ TEST_P(OnSignal, removes_endpoint_on_signal)
 {
     struct ServerConfig : TestingServerConfiguration
     {
-        void exec() override
+        void on_start() override
         {
+            sync.wait_for_signal_ready_for();
             raise(sig);
         }
 
         ServerConfig(int sig) : sig(sig) {}
+
         int const sig;
+        mtf::CrossProcessSync sync;
     };
 
     ServerConfig server_config(GetParam());
@@ -416,13 +409,16 @@ TEST_P(OnSignal, removes_endpoint_on_signal)
 
     run_in_test_process([&]
     {
-        using std::chrono::steady_clock;
-        std::chrono::seconds const limit(2);
-
         ASSERT_TRUE(file_exists(server_config.the_socket_file()));
 
-        // shutdown should fail as the server faulted
-        ASSERT_FALSE(shutdown_server_process());
+        server_config.sync.signal_ready();
+
+        auto result = wait_for_shutdown_server_process();
+        EXPECT_EQ(mtf::TerminationReason::child_terminated_by_signal, result.reason);
+        // Under valgrind the server process is reported as being terminated
+        // by SIGKILL because of multithreading madness
+        // TODO: Investigate if we can do better than this workaround
+        EXPECT_TRUE(result.signal == GetParam() || result.signal == SIGKILL);
 
         EXPECT_FALSE(file_exists(server_config.the_socket_file()));
     });
