@@ -16,7 +16,7 @@
  * Authored by: Alan Griffiths <alan@octopull.co.uk>
  */
 
-#include "mir/geometry/pixel_format.h"
+#include "mir_toolkit/common.h"
 #include "mir/geometry/size.h"
 
 #include "mir_toolkit/mir_client_library.h"
@@ -41,7 +41,6 @@ namespace
 char const* const mir_test_socket = mtf::test_socket_file().c_str();
 
 geom::Size const size{640, 480};
-geom::PixelFormat const format{geom::PixelFormat::abgr_8888};
 }
 
 namespace mir
