@@ -20,13 +20,15 @@
 #include "multithread_harness.h"
 
 #include "src/server/compositor/switching_bundle.h"
-#include "mir/compositor/buffer_stream_surfaces.h"
+#include "src/server/compositor/buffer_stream_surfaces.h"
 #include "mir/graphics/graphic_buffer_allocator.h"
 
 #include <gmock/gmock.h>
 #include <future>
 #include <thread>
 #include <chrono>
+#include <mutex>
+#include <atomic>
 
 namespace mc = mir::compositor;
 namespace mg = mir::graphics;
@@ -43,39 +45,63 @@ struct SwapperSwappingStress : public ::testing::Test
     {
         auto allocator = std::make_shared<mtd::StubBufferAllocator>();
         auto properties = mg::BufferProperties{geom::Size{380, 210},
-                                          geom::PixelFormat::abgr_8888,
+                                          mir_pixel_format_abgr_8888,
                                           mg::BufferUsage::hardware};
         switching_bundle = std::make_shared<mc::SwitchingBundle>(3, allocator, properties);
     }
 
     std::shared_ptr<mc::SwitchingBundle> switching_bundle;
-    std::atomic<bool> client_thread_done;
+    std::mutex acquire_mutex;  // must live longer than our callback/lambda
+
+    mg::Buffer* client_acquire_blocking(
+        std::shared_ptr<mc::SwitchingBundle> const& switching_bundle)
+    {
+        std::condition_variable cv;
+        bool acquired = false;
+    
+        mg::Buffer* result;
+        switching_bundle->client_acquire(
+            [&](mg::Buffer* new_buffer)
+             {
+                std::unique_lock<decltype(acquire_mutex)> lock(acquire_mutex);
+    
+                result = new_buffer;
+                acquired = true;
+                cv.notify_one();
+             });
+    
+        std::unique_lock<decltype(acquire_mutex)> lock(acquire_mutex);
+    
+        cv.wait(lock, [&]{ return acquired; });
+    
+        return result;
+    }
 };
-}
+
+} // namespace
 
 TEST_F(SwapperSwappingStress, swapper)
 {
-    client_thread_done = false;
+    std::atomic_bool done(false);
 
     auto f = std::async(std::launch::async,
-                [this]
+                [&]
                 {
                     for(auto i=0u; i < 400; i++)
                     {
-                        auto b = switching_bundle->client_acquire();
+                        auto b = client_acquire_blocking(switching_bundle);
                         std::this_thread::yield();
                         switching_bundle->client_release(b);
                     }
-                    client_thread_done = true;
+                    done = true;
                 });
 
     auto g = std::async(std::launch::async,
-                [this]
+                [&]
                 {
-                    unsigned long count = 0;
-                    while(!client_thread_done)
+                    while (!done)
                     {
-                        auto b = switching_bundle->compositor_acquire(++count);
+                        auto b = switching_bundle->compositor_acquire(0);
                         std::this_thread::yield();
                         switching_bundle->compositor_release(b);
                     }
@@ -90,7 +116,7 @@ TEST_F(SwapperSwappingStress, swapper)
                         std::this_thread::yield();
                         switching_bundle->allow_framedropping(false);
                         std::this_thread::yield();
-                    } 
+                    }
                 });
 
     f.wait();
@@ -100,27 +126,26 @@ TEST_F(SwapperSwappingStress, swapper)
 
 TEST_F(SwapperSwappingStress, different_swapper_types)
 {
-    client_thread_done = false;
+    std::atomic_bool done(false);
 
     auto f = std::async(std::launch::async,
-                [this]
+                [&]
                 {
                     for(auto i=0u; i < 400; i++)
                     {
-                        auto b = switching_bundle->client_acquire();
+                        auto b = client_acquire_blocking(switching_bundle);
                         std::this_thread::yield();
                         switching_bundle->client_release(b);
                     }
-                    client_thread_done = true;
+                    done = true;
                 });
 
     auto g = std::async(std::launch::async,
-                [this]
+                [&]
                 {
-                    unsigned long count = 0;
-                    while(!client_thread_done)
+                    while (!done)
                     {
-                        auto b = switching_bundle->compositor_acquire(++count);
+                        auto b = switching_bundle->compositor_acquire(0);
                         std::this_thread::yield();
                         switching_bundle->compositor_release(b);
                     }
@@ -135,7 +160,7 @@ TEST_F(SwapperSwappingStress, different_swapper_types)
                         std::this_thread::yield();
                         switching_bundle->allow_framedropping(false);
                         std::this_thread::yield();
-                    } 
+                    }
                 });
 
     f.wait();
