@@ -16,15 +16,15 @@
  * Authored by: Kevin DuBois <kevin.dubois@canonical.com>
  */
 
-#include "src/server/graphics/android/android_graphic_buffer_allocator.h"
+#include "src/platform/graphics/android/android_graphic_buffer_allocator.h"
 #include "src/server/compositor/switching_bundle.h"
 #include "mir/graphics/buffer_initializer.h"
-#include "mir/graphics/null_display_report.h"
+#include "src/server/report/null_report_factory.h"
 #include "mir/graphics/android/native_buffer.h"
 #include "mir/graphics/buffer_properties.h"
 
-#include "mir_test/draw/android_graphics.h"
-#include "mir_test/draw/patterns.h"
+#include "testdraw/graphics_region_factory.h"
+#include "testdraw/patterns.h"
 
 #include <gtest/gtest.h>
 
@@ -43,18 +43,43 @@ protected:
     virtual void SetUp()
     {
         size = geom::Size{334, 122};
-        pf  = geom::PixelFormat::abgr_8888;
+        pf  = mir_pixel_format_abgr_8888;
         buffer_properties = mg::BufferProperties{size, pf, mg::BufferUsage::software};
         null_buffer_initializer = std::make_shared<mg::NullBufferInitializer>();
+        graphics_region_factory = mtd::create_graphics_region_factory();
     }
 
     std::shared_ptr<mg::BufferInitializer> null_buffer_initializer;
     geom::Size size;
-    geom::PixelFormat pf;
+    MirPixelFormat pf;
     mg::BufferProperties buffer_properties;
-    mtd::TestGrallocMapper sw_renderer;
+    std::shared_ptr<mtd::GraphicsRegionFactory> graphics_region_factory;
 };
 
+auto client_acquire_blocking(mc::SwitchingBundle& switching_bundle)
+-> mg::Buffer*
+{
+    std::mutex mutex;
+    std::condition_variable cv;
+    bool done = false;
+
+    mg::Buffer* result;
+    switching_bundle.client_acquire(
+        [&](mg::Buffer* new_buffer)
+         {
+            std::unique_lock<decltype(mutex)> lock(mutex);
+
+            result = new_buffer;
+            done = true;
+            cv.notify_one();
+         });
+
+    std::unique_lock<decltype(mutex)> lock(mutex);
+
+    cv.wait(lock, [&]{ return done; });
+
+    return result;
+}
 }
 
 TEST_F(AndroidBufferIntegration, allocator_can_create_sw_buffer)
@@ -66,10 +91,11 @@ TEST_F(AndroidBufferIntegration, allocator_can_create_sw_buffer)
     mg::BufferProperties sw_properties{size, pf, mg::BufferUsage::software};
     auto test_buffer = allocator->alloc_buffer(sw_properties);
 
-    auto region = sw_renderer.graphic_region_from_handle(test_buffer->native_buffer_handle()->anwb());
+    auto region = graphics_region_factory->graphic_region_from_handle(
+        *test_buffer->native_buffer_handle());
     mtd::DrawPatternSolid red_pattern(0xFF0000FF);
-    red_pattern.draw(region);
-    EXPECT_TRUE(red_pattern.check(region));
+    red_pattern.draw(*region);
+    EXPECT_TRUE(red_pattern.check(*region));
 }
 
 TEST_F(AndroidBufferIntegration, allocator_can_create_hw_buffer)
@@ -92,7 +118,7 @@ TEST_F(AndroidBufferIntegration, swapper_creation_is_sane)
 
     mc::SwitchingBundle swapper(2, allocator, buffer_properties);
 
-    auto returned_buffer = swapper.client_acquire();
+    auto returned_buffer = client_acquire_blocking(swapper);
 
     EXPECT_NE(nullptr, returned_buffer);
 }
