@@ -16,21 +16,24 @@
  * Authored by: Kevin DuBois <kevin.dubois@canonical.com>
  */
 
-#include "src/server/graphics/android/android_graphic_buffer_allocator.h"
-#include "src/server/graphics/android/internal_client_window.h"
-#include "src/server/graphics/android/interpreter_cache.h"
-#include "mir/compositor/buffer_stream_factory.h"
+#include "src/platform/graphics/android/android_graphic_buffer_allocator.h"
+#include "src/platform/graphics/android/internal_client_window.h"
+#include "src/platform/graphics/android/interpreter_cache.h"
+#include "src/platform/graphics/android/internal_client.h"
+#include "src/server/compositor/buffer_stream_factory.h"
+#include "src/server/report/null_report_factory.h"
 #include "mir/graphics/buffer_initializer.h"
-#include "mir/graphics/null_display_report.h"
+#include "src/server/report/null_report_factory.h"
 #include "mir/graphics/android/mir_native_window.h"
 #include "mir/graphics/platform.h"
 #include "mir/graphics/internal_client.h"
 #include "mir/graphics/internal_surface.h"
-#include "mir/surfaces/surface_stack.h"
-#include "mir/surfaces/surface_controller.h"
-#include "mir/surfaces/surface_allocator.h"
-#include "mir/shell/surface_source.h"
-#include "mir/shell/surface.h"
+#include "src/server/scene/surface_stack.h"
+#include "src/server/scene/surface_controller.h"
+#include "mir/scene/scene_report.h"
+#include "src/server/scene/surface_allocator.h"
+#include "mir/scene/surface.h"
+#include "mir/scene/surface_event_source.h"
 #include "mir/shell/surface_creation_parameters.h"
 #include "mir/frontend/surface_id.h"
 #include "mir/input/input_channel_factory.h"
@@ -49,11 +52,12 @@ namespace mg=mir::graphics;
 namespace mga=mir::graphics::android;
 namespace mc=mir::compositor;
 namespace geom=mir::geometry;
-namespace ms=mir::surfaces;
+namespace ms=mir::scene;
 namespace msh=mir::shell;
 namespace mf=mir::frontend;
 namespace mi=mir::input;
 namespace mtd=mir::test::doubles;
+namespace mr = mir::report;
 namespace mo=mir::options;
 
 namespace
@@ -66,7 +70,7 @@ protected:
     }
 };
 
-struct StubInputFactory : public mi::InputChannelFactory 
+struct StubInputFactory : public mi::InputChannelFactory
 {
     std::shared_ptr<mi::InputChannel> make_input_channel()
     {
@@ -78,10 +82,10 @@ struct StubInputFactory : public mi::InputChannelFactory
 TEST_F(AndroidInternalClient, internal_client_creation_and_use)
 {
     auto size = geom::Size{334, 122};
-    auto pf  = geom::PixelFormat::abgr_8888;
+    auto pf  = mir_pixel_format_abgr_8888;
     msh::SurfaceCreationParameters params;
     params.name = std::string("test");
-    params.size = size; 
+    params.size = size;
     params.pixel_format = pf;
     params.buffer_usage = mg::BufferUsage::hardware;
     auto id = mf::SurfaceId{4458};
@@ -91,17 +95,18 @@ TEST_F(AndroidInternalClient, internal_client_creation_and_use)
     auto null_buffer_initializer = std::make_shared<mg::NullBufferInitializer>();
     auto allocator = std::make_shared<mga::AndroidGraphicBufferAllocator>(null_buffer_initializer);
     auto buffer_stream_factory = std::make_shared<mc::BufferStreamFactory>(allocator);
-    auto surface_allocator = std::make_shared<ms::SurfaceAllocator>(buffer_stream_factory, stub_input_factory);
-    auto ss = std::make_shared<ms::SurfaceStack>(surface_allocator, stub_input_registrar);
-    auto surface_controller = std::make_shared<ms::SurfaceController>(ss);
-    auto surface_source = std::make_shared<msh::SurfaceSource>(surface_controller, std::make_shared<mtd::NullSurfaceConfigurator>());
-    auto mir_surface = as_internal_surface(
-        surface_source->create_surface(nullptr, params, id, std::shared_ptr<mf::EventSink>()));
+    auto scene_report = mr::null_scene_report();
+    auto surface_allocator = std::make_shared<ms::SurfaceAllocator>(buffer_stream_factory, stub_input_factory, std::make_shared<mtd::NullSurfaceConfigurator>(), scene_report);
+    auto ss = std::make_shared<ms::SurfaceStack>(stub_input_registrar, scene_report);
+    auto surface_controller = std::make_shared<ms::SurfaceController>(surface_allocator, ss);
+    auto const observer = std::make_shared<ms::SurfaceEventSource>(id, std::shared_ptr<mf::EventSink>());
+    auto surface = surface_controller->add_surface(params, observer);
+    surface->allow_framedropping(true);
+    auto mir_surface = as_internal_surface(surface);
 
-    auto options = std::shared_ptr<mo::ProgramOption>(); 
-    auto report = std::shared_ptr<mg::NullDisplayReport>(); 
-    auto platform = mg::create_platform(options, report);
-    auto internal_client = platform->create_internal_client();
+    auto options = std::shared_ptr<mo::ProgramOption>();
+    auto report = mr::null_display_report();
+    auto internal_client = std::make_shared<mga::InternalClient>();
 
     int major, minor, n;
     EGLContext egl_context;
@@ -137,4 +142,9 @@ TEST_F(AndroidInternalClient, internal_client_creation_and_use)
     glClear(GL_COLOR_BUFFER_BIT);
     rc = eglSwapBuffers(egl_display, egl_surface);
     EXPECT_EQ(EGL_TRUE, rc);
+
+    eglMakeCurrent(egl_display, EGL_NO_SURFACE, EGL_NO_SURFACE, EGL_NO_CONTEXT);
+    eglDestroySurface(egl_display, egl_surface);
+    eglDestroyContext(egl_display, egl_context);
+    eglTerminate(egl_display);
 }
