@@ -21,10 +21,10 @@
 #include "mir/input/input_targets.h"
 #include "mir/input/input_region.h"
 #include "mir/shell/surface_creation_parameters.h"
-#include "mir/input/null_input_report.h"
 #include "mir/geometry/point.h"
 #include "mir/geometry/rectangle.h"
 
+#include "src/server/report/null_report_factory.h"
 #include "src/server/input/android/android_input_manager.h"
 #include "src/server/input/android/android_input_targeter.h"
 #include "src/server/input/android/android_input_registrar.h"
@@ -53,11 +53,12 @@
 namespace mi = mir::input;
 namespace mia = mir::input::android;
 namespace mis = mir::input::synthesis;
-namespace ms = mir::surfaces;
+namespace ms = mir::scene;
 namespace msh = mir::shell;
 namespace geom = mir::geometry;
 namespace mt = mir::test;
 namespace mtd = mir::test::doubles;
+namespace mr = mir::report;
 
 using mtd::MockEventFilter;
 
@@ -97,10 +98,10 @@ public:
                 event_filter,
                 mt::fake_shared(input_region),
                 null_cursor_listener,
-                std::make_shared<mi::NullInputReport>());
+                mr::null_input_report());
 
         fake_event_hub = configuration->the_fake_event_hub();
-        
+
         input_manager = configuration->the_input_manager();
 
         stub_targets = std::make_shared<StubInputTargets>();
@@ -269,11 +270,11 @@ struct AndroidInputManagerDispatcherInterceptSetup : public testing::Test
         event_filter = std::make_shared<MockEventFilter>();
         configuration = std::make_shared<TestingInputConfiguration>(
             event_filter,
-            mt::fake_shared(input_region), null_cursor_listener, std::make_shared<mi::NullInputReport>());
+            mt::fake_shared(input_region), null_cursor_listener, mr::null_input_report());
         fake_event_hub = configuration->the_fake_event_hub();
 
         input_manager = configuration->the_input_manager();
-        
+
         input_registrar = configuration->the_input_registrar();
         input_targeter = configuration->the_input_targeter();
 
@@ -295,7 +296,7 @@ struct AndroidInputManagerDispatcherInterceptSetup : public testing::Test
     {
         input_manager->start();
     }
-    
+
     int test_fd()
     {
         int fds[2];
@@ -397,4 +398,4 @@ TEST_F(AndroidInputManagerDispatcherInterceptSetup, changing_focus_changes_event
     fake_event_hub->synthesize_event(mis::a_key_down_event()
                                 .of_scancode(KEY_3));
     wait3.wait_for_at_most_seconds(5);
-} 
+}
