@@ -19,15 +19,13 @@
 #include "mir/graphics/display.h"
 #include "mir/graphics/buffer.h"
 #include "mir/frontend/session_authorizer.h"
-#include "mir/graphics/graphic_buffer_allocator.h"
-#include "mir/frontend/protobuf_ipc_factory.h"
-#include "mir/frontend/resource_cache.h"
-#include "mir/frontend/session_mediator.h"
-#include "mir/frontend/global_event_sender.h"
+#include "src/server/frontend/protobuf_ipc_factory.h"
+#include "src/server/frontend/resource_cache.h"
+#include "src/server/frontend/session_mediator.h"
 
 #include "mir_test_framework/display_server_test_fixture.h"
 #include "mir_test_framework/cross_process_sync.h"
-#include "mir_test_doubles/stub_buffer.h"
+#include "mir_test_doubles/stub_buffer_allocator.h"
 #include "mir_test_doubles/null_display.h"
 #include "mir_test_doubles/null_event_sink.h"
 #include "mir_test_doubles/null_display_changer.h"
@@ -85,30 +83,28 @@ private:
     mtd::NullDisplayBuffer display_buffer;
 };
 
-mtd::StubDisplayConfig StubChanger::stub_display_config;
+mtd::StubDisplayConfig StubChanger::stub_display_config{
+    2,
+    { mir_pixel_format_xrgb_8888 }
+};
 
 char const* const mir_test_socket = mtf::test_socket_file().c_str();
 
-class StubGraphicBufferAllocator : public mg::GraphicBufferAllocator
+class StubGraphicBufferAllocator : public mtd::StubBufferAllocator
 {
 public:
-    std::shared_ptr<mg::Buffer> alloc_buffer(mg::BufferProperties const&)
-    {
-        return std::shared_ptr<mg::Buffer>(new mtd::StubBuffer());
-    }
-
-    std::vector<geom::PixelFormat> supported_pixel_formats()
+    std::vector<MirPixelFormat> supported_pixel_formats() override
     {
         return pixel_formats;
     }
 
-    static std::vector<geom::PixelFormat> const pixel_formats;
+    static std::vector<MirPixelFormat> const pixel_formats;
 };
 
-std::vector<geom::PixelFormat> const StubGraphicBufferAllocator::pixel_formats{
-    geom::PixelFormat::bgr_888,
-    geom::PixelFormat::abgr_8888,
-    geom::PixelFormat::xbgr_8888
+std::vector<MirPixelFormat> const StubGraphicBufferAllocator::pixel_formats{
+    mir_pixel_format_argb_8888,
+    mir_pixel_format_xbgr_8888,
+    mir_pixel_format_bgr_888
 };
 
 class StubPlatform : public mtd::NullPlatform
@@ -121,7 +117,8 @@ public:
     }
 
     std::shared_ptr<mg::Display> create_display(
-        std::shared_ptr<mg::DisplayConfigurationPolicy> const&) override
+        std::shared_ptr<mg::DisplayConfigurationPolicy> const&,
+        std::shared_ptr<mg::GLConfig> const&) override
     {
         if (!display)
             display = std::make_shared<StubDisplay>();
@@ -133,9 +130,9 @@ public:
 
 }
 
-/* TODO: this test currently checks the same format list against both the surface formats
-         and display formats. Improve test to return different format lists for both concepts */ 
-TEST_F(BespokeDisplayServerTestFixture, display_surface_pfs_reaches_client)
+using AvailableSurfaceFormatsTest = BespokeDisplayServerTestFixture;
+
+TEST_F(AvailableSurfaceFormatsTest, surface_pixel_formats_reach_client)
 {
     struct ServerConfig : TestingServerConfiguration
     {
@@ -153,7 +150,7 @@ TEST_F(BespokeDisplayServerTestFixture, display_surface_pfs_reaches_client)
         {
             if (!changer)
                 changer = std::make_shared<StubChanger>();
-            return changer; 
+            return changer;
         }
 
         std::shared_ptr<StubChanger> changer;
@@ -167,18 +164,19 @@ TEST_F(BespokeDisplayServerTestFixture, display_surface_pfs_reaches_client)
         void exec()
         {
             MirConnection* connection = mir_connect_sync(mir_test_socket, __PRETTY_FUNCTION__);
+            ASSERT_TRUE(mir_connection_is_valid(connection));
 
             unsigned int const format_storage_size = 4;
-            MirPixelFormat formats[format_storage_size]; 
+            MirPixelFormat formats[format_storage_size];
             unsigned int returned_format_size = 0;
             mir_connection_get_available_surface_formats(connection,
                 formats, format_storage_size, &returned_format_size);
 
-            ASSERT_EQ(returned_format_size, StubGraphicBufferAllocator::pixel_formats.size());
+            ASSERT_EQ(StubGraphicBufferAllocator::pixel_formats.size(), returned_format_size);
             for (auto i=0u; i < returned_format_size; ++i)
             {
                 EXPECT_EQ(StubGraphicBufferAllocator::pixel_formats[i],
-                          static_cast<geom::PixelFormat>(formats[i]));
+                          formats[i]) << "i=" << i;
             }
 
             mir_connection_release(connection);
