@@ -16,7 +16,6 @@
  * Authored by: Alan Griffiths <alan@octopull.co.uk>
  */
 
-#include "mir/graphics/graphic_buffer_allocator.h"
 #include "src/server/compositor/switching_bundle.h"
 #include "mir/graphics/buffer_properties.h"
 #include "mir/graphics/buffer_id.h"
@@ -27,6 +26,7 @@
 
 #include "mir_test_framework/display_server_test_fixture.h"
 #include "mir_test_doubles/stub_buffer.h"
+#include "mir_test_doubles/stub_buffer_allocator.h"
 #include "mir_test_doubles/null_platform.h"
 #include "mir_test_doubles/null_display.h"
 #include "mir_test_doubles/stub_display_buffer.h"
@@ -49,12 +49,12 @@ namespace
 char const* const mir_test_socket = mtf::test_socket_file().c_str();
 
 geom::Size const size{640, 480};
-geom::PixelFormat const format{geom::PixelFormat::abgr_8888};
+MirPixelFormat const format{mir_pixel_format_abgr_8888};
 mg::BufferUsage const usage{mg::BufferUsage::hardware};
 mg::BufferProperties const buffer_properties{size, format, usage};
 
 
-class MockGraphicBufferAllocator : public mg::GraphicBufferAllocator
+class MockGraphicBufferAllocator : public mtd::StubBufferAllocator
 {
  public:
     MockGraphicBufferAllocator()
@@ -69,14 +69,9 @@ class MockGraphicBufferAllocator : public mg::GraphicBufferAllocator
         std::shared_ptr<mg::Buffer> (mg::BufferProperties const&));
 
 
-    std::vector<geom::PixelFormat> supported_pixel_formats()
+    std::shared_ptr<mg::Buffer> on_create_swapper(mg::BufferProperties const&)
     {
-        return std::vector<geom::PixelFormat>();
-    }
-
-    std::unique_ptr<mg::Buffer> on_create_swapper(mg::BufferProperties const&)
-    {
-        return std::unique_ptr<mg::Buffer>(new mtd::StubBuffer(::buffer_properties));
+        return std::make_shared<mtd::StubBuffer>(::buffer_properties);
     }
 
     ~MockGraphicBufferAllocator() noexcept {}
@@ -149,34 +144,6 @@ struct SurfaceSync
 
 struct ClientConfigCommon : TestingClientConfiguration
 {
-    ClientConfigCommon()
-        : connection(NULL)
-    {
-    }
-
-    static void connection_callback(MirConnection * connection, void * context)
-    {
-        ClientConfigCommon * config = reinterpret_cast<ClientConfigCommon *>(context);
-        config->connected(connection);
-    }
-
-    void connected(MirConnection * new_connection)
-    {
-        std::unique_lock<std::mutex> lock(guard);
-        connection = new_connection;
-        wait_condition.notify_all();
-    }
-
-    void wait_for_connect()
-    {
-        std::unique_lock<std::mutex> lock(guard);
-        while (!connection)
-            wait_condition.wait(lock);
-    }
-
-    std::mutex guard;
-    std::condition_variable wait_condition;
-    MirConnection * connection;
     static const int max_surface_count = 5;
     SurfaceSync ssync[max_surface_count];
 };
@@ -185,6 +152,7 @@ const int ClientConfigCommon::max_surface_count;
 }
 
 using SurfaceLoop = BespokeDisplayServerTestFixture;
+using SurfaceLoopDefault = DefaultDisplayServerTestFixture;
 using mir::SurfaceSync;
 using mir::ClientConfigCommon;
 using mir::StubDisplay;
@@ -214,19 +182,13 @@ void wait_for_surface_release(SurfaceSync* context)
 }
 }
 
-TEST_F(SurfaceLoop, creating_a_client_surface_allocates_buffer_swapper_on_server)
+TEST_F(SurfaceLoopDefault, creating_a_client_surface_gets_surface_of_requested_size)
 {
-    TestingServerConfiguration server_config;
-
-    launch_server_process(server_config);
-
-    struct ClientConfig : ClientConfigCommon
+    struct ClientConfig : TestingClientConfiguration
     {
         void exec()
         {
-            mir_connect(mir_test_socket, __PRETTY_FUNCTION__, connection_callback, this);
-
-            wait_for_connect();
+            auto const connection = mir_connect_sync(mir_test_socket, __PRETTY_FUNCTION__);
 
             ASSERT_TRUE(connection != NULL);
             EXPECT_TRUE(mir_connection_is_valid(connection));
@@ -241,28 +203,20 @@ TEST_F(SurfaceLoop, creating_a_client_surface_allocates_buffer_swapper_on_server
                 mir_display_output_id_invalid
             };
 
-            mir_connection_create_surface(connection, &request_params, create_surface_callback, ssync);
+            auto const surface = mir_connection_create_surface_sync(connection, &request_params);
 
-            wait_for_surface_create(ssync);
-
-            ASSERT_TRUE(ssync->surface != NULL);
-            EXPECT_TRUE(mir_surface_is_valid(ssync->surface));
-            EXPECT_STREQ(mir_surface_get_error_message(ssync->surface), "");
+            ASSERT_TRUE(surface != NULL);
+            EXPECT_TRUE(mir_surface_is_valid(surface));
+            EXPECT_STREQ(mir_surface_get_error_message(surface), "");
 
             MirSurfaceParameters response_params;
-            mir_surface_get_parameters(ssync->surface, &response_params);
+            mir_surface_get_parameters(surface, &response_params);
             EXPECT_EQ(request_params.width, response_params.width);
             EXPECT_EQ(request_params.height, response_params.height);
             EXPECT_EQ(request_params.pixel_format, response_params.pixel_format);
             EXPECT_EQ(request_params.buffer_usage, response_params.buffer_usage);
 
-
-            mir_surface_release(ssync->surface, release_surface_callback, ssync);
-
-            wait_for_surface_release(ssync);
-
-            ASSERT_TRUE(ssync->surface == NULL);
-
+            mir_surface_release_sync(surface);
             mir_connection_release(connection);
         }
     } client_config;
@@ -294,7 +248,8 @@ struct ServerConfigAllocatesBuffersOnServer : TestingServerConfiguration
         }
 
         std::shared_ptr<mg::Display> create_display(
-            std::shared_ptr<mg::DisplayConfigurationPolicy> const&) override
+            std::shared_ptr<mg::DisplayConfigurationPolicy> const&,
+            std::shared_ptr<mg::GLConfig> const&) override
         {
             return std::make_shared<StubDisplay>();
         }
@@ -324,9 +279,7 @@ TEST_F(SurfaceLoop, creating_a_client_surface_allocates_buffers_on_server)
     {
         void exec()
         {
-            mir_connect(mir_test_socket, __PRETTY_FUNCTION__, connection_callback, this);
-
-            wait_for_connect();
+            auto connection = mir_connect_sync(mir_test_socket, __PRETTY_FUNCTION__);
 
             ASSERT_TRUE(connection != NULL);
             EXPECT_TRUE(mir_connection_is_valid(connection));
@@ -392,18 +345,12 @@ struct BufferCounterConfig : TestingServerConfiguration
         static std::atomic<int> buffers_destroyed;
     };
 
-    class StubGraphicBufferAllocator : public mg::GraphicBufferAllocator
+    class StubGraphicBufferAllocator : public mtd::StubBufferAllocator
     {
      public:
-        virtual std::shared_ptr<mg::Buffer> alloc_buffer(
-            mg::BufferProperties const&)
+        std::shared_ptr<mg::Buffer> alloc_buffer(mg::BufferProperties const&) override
         {
-            return std::unique_ptr<mg::Buffer>(new CountingStubBuffer());
-        }
-
-        std::vector<geom::PixelFormat> supported_pixel_formats()
-        {
-            return std::vector<geom::PixelFormat>();
+            return std::make_shared<CountingStubBuffer>();
         }
     };
 
@@ -417,7 +364,8 @@ struct BufferCounterConfig : TestingServerConfiguration
         }
 
         std::shared_ptr<mg::Display> create_display(
-            std::shared_ptr<mg::DisplayConfigurationPolicy> const&) override
+            std::shared_ptr<mg::DisplayConfigurationPolicy> const&,
+            std::shared_ptr<mg::GLConfig> const&) override
         {
             return std::make_shared<StubDisplay>();
         }
@@ -457,9 +405,7 @@ TEST_F(SurfaceLoop, all_created_buffers_are_destoyed)
     {
         void exec() override
         {
-            mir_connect(mir_test_socket, __PRETTY_FUNCTION__, connection_callback, this);
-
-            wait_for_connect();
+            auto connection = mir_connect_sync(mir_test_socket, __PRETTY_FUNCTION__);
 
             MirSurfaceParameters const request_params =
             {
@@ -507,9 +453,7 @@ TEST_F(SurfaceLoop, all_created_buffers_are_destoyed_if_client_disconnects_witho
     {
         void exec() override
         {
-            mir_connect(mir_test_socket, __PRETTY_FUNCTION__, connection_callback, this);
-
-            wait_for_connect();
+            auto connection = mir_connect_sync(mir_test_socket, __PRETTY_FUNCTION__);
 
             MirSurfaceParameters const request_params =
             {
