@@ -20,12 +20,15 @@
 #include "mir_test_doubles/stub_ipc_factory.h"
 #include "mir_test_doubles/stub_session_authorizer.h"
 #include "mir/frontend/connector_report.h"
+#include "mir/frontend/protobuf_session_creator.h"
 #include "src/server/frontend/published_socket_connector.h"
-#include "src/server/frontend/protobuf_session_creator.h"
+#include "src/server/report/null_report_factory.h"
+#include "src/server/report/null_report_factory.h"
 
 namespace mt = mir::test;
 namespace mtd = mir::test::doubles;
 namespace mf = mir::frontend;
+namespace mr = mir::report;
 
 namespace
 {
@@ -36,9 +39,11 @@ std::shared_ptr<mf::Connector> make_connector(
 {
     return std::make_shared<mf::PublishedSocketConnector>(
         socket_name,
-        std::make_shared<mf::ProtobufSessionCreator>(factory, std::make_shared<mtd::StubSessionAuthorizer>()),
+        std::make_shared<mf::ProtobufSessionCreator>(
+            factory,
+            std::make_shared<mtd::StubSessionAuthorizer>(),
+            mr::null_message_processor_report()),
         10,
-        []{},
         report);
 }
 }
@@ -46,7 +51,7 @@ std::shared_ptr<mf::Connector> make_connector(
 mt::TestProtobufServer::TestProtobufServer(
     std::string const& socket_name,
     const std::shared_ptr<protobuf::DisplayServer>& tool) :
-    TestProtobufServer(socket_name, tool, std::make_shared<mf::NullConnectorReport>())
+    TestProtobufServer(socket_name, tool, mr::null_connector_report())
 {
 }
 
