@@ -19,7 +19,7 @@
 #include "mir_toolkit/client_types.h"
 #include "mir_test_framework/testing_process_manager.h"
 #include "mir_test_framework/detect_server.h"
-#include "mir_test_framework/stub_client_connection_configuration.h"
+#include "mir_test_framework/using_stub_client_platform.h"
 #include "src/client/mir_connection.h"
 #include "mir/run_mir.h"
 
@@ -32,15 +32,6 @@ namespace mo = mir::options;
 namespace mc = mir::compositor;
 namespace mtf = mir_test_framework;
 
-namespace mir_test_framework
-{
-void startup_pause()
-{
-    if (!detect_server(test_socket_file(), std::chrono::minutes(2)))
-        throw std::runtime_error("Failed to find server");
-}
-}
-
 mtf::TestingProcessManager::TestingProcessManager() :
     is_test_process(true),
     server_process_was_started(false)
@@ -77,42 +68,11 @@ void mtf::TestingProcessManager::launch_server_process(TestingServerConfiguratio
     else
     {
         server_process = std::shared_ptr<Process>(new Process(pid));
-        startup_pause();
+        config.wait_for_server_start();
         server_process_was_started = true;
     }
 }
 
-/* if set before any calls to the api functions, assigning to this pointer will allow user to
- * override calls to mir_connect() and mir_connection_release(). This is mostly useful in test scenarios
- */
-extern MirWaitHandle* (*mir_connect_impl)(
-    char const *server,
-    char const *app_name,
-    mir_connected_callback callback,
-    void *context);
-extern void (*mir_connection_release_impl) (MirConnection *connection);
-
-namespace
-{
-MirWaitHandle* mir_connect_test_override(
-    char const *socket_file,
-    char const *app_name,
-    mir_connected_callback callback,
-    void *context)
-{
-    mtf::StubConnectionConfiguration conf(socket_file);
-    auto connection = new MirConnection(conf);
-    return connection->connect(app_name, callback, context);
-}
-
-void mir_connection_release_override(MirConnection *connection)
-{
-    auto wait_handle = connection->disconnect();
-    wait_handle->wait_for_all();
-    delete connection;
-}
-}
-
 void mtf::TestingProcessManager::launch_client_process(TestingClientConfiguration& config, mo::Option const& test_options)
 {
     if (!is_test_process)
@@ -147,10 +107,14 @@ void mtf::TestingProcessManager::launch_client_process(TestingClientConfiguratio
         SCOPED_TRACE("Client");
         if (!config.use_real_graphics(test_options))
         {
-            mir_connect_impl = mir_connect_test_override;
-            mir_connection_release_impl = mir_connection_release_override;
+            mtf::UsingStubClientPlatform p;
+            config.exec();
         }
-        config.exec();
+        else
+        {
+            config.exec();
+        }
+
         exit(::testing::Test::HasFailure() ? EXIT_FAILURE : EXIT_SUCCESS);
     }
     else
@@ -201,6 +165,25 @@ mtf::Result mtf::TestingProcessManager::shutdown_server_process()
     return result;
 }
 
+mtf::Result mtf::TestingProcessManager::wait_for_shutdown_server_process()
+{
+    Result result;
+
+    if (server_process)
+    {
+        result = server_process->wait_for_termination();
+        server_process.reset();
+        return result;
+    }
+    else
+    {
+        result.reason = TerminationReason::child_terminated_normally;
+        result.exit_code = EXIT_SUCCESS;
+    }
+
+    return result;
+}
+
 void mtf::TestingProcessManager::terminate_client_processes()
 {
     if (is_test_process)
