@@ -48,7 +48,7 @@ struct MockClientBuffer : public mcl::ClientBuffer
     MOCK_METHOD0(secure_for_cpu_write, std::shared_ptr<mcl::MemoryRegion>());
     MOCK_CONST_METHOD0(size, geom::Size());
     MOCK_CONST_METHOD0(stride, geom::Stride());
-    MOCK_CONST_METHOD0(pixel_format, geom::PixelFormat());
+    MOCK_CONST_METHOD0(pixel_format, MirPixelFormat());
 
     MOCK_CONST_METHOD0(age, uint32_t());
     MOCK_METHOD0(mark_as_submitted, void());
@@ -75,8 +75,8 @@ struct MockMirSurface : public mcl::ClientSurface
 
     MOCK_CONST_METHOD0(get_parameters, MirSurfaceParameters());
     MOCK_METHOD0(get_current_buffer, std::shared_ptr<mcl::ClientBuffer>());
-    MOCK_METHOD2(next_buffer, MirWaitHandle*(mir_surface_callback callback, void * context));
-    MOCK_METHOD2(configure, MirWaitHandle*(MirSurfaceAttrib, int));
+    MOCK_METHOD0(request_and_wait_for_next_buffer, void());
+    MOCK_METHOD2(request_and_wait_for_configure, void(MirSurfaceAttrib, int));
     MirSurfaceParameters params;
 };
 
@@ -137,7 +137,7 @@ TEST_F(AndroidInterpreterTest, native_window_queue_advances_buffer)
     testing::NiceMock<MockMirSurface> mock_surface{surf_params};
     mcla::ClientSurfaceInterpreter interpreter(mock_surface);
 
-    EXPECT_CALL(mock_surface, next_buffer(_,_))
+    EXPECT_CALL(mock_surface, request_and_wait_for_next_buffer())
         .Times(1);
 
     interpreter.driver_returns_buffer(&buffer, -1);
@@ -207,3 +207,19 @@ TEST_F(AndroidInterpreterTest, native_window_height_query_hook)
 
     EXPECT_EQ(surf_params.height, height);
 }
+
+/* this is query key is a bit confusing from the system/window.h description.
+   what it means is the minimum number of buffers that the server reserves for its own use in steady
+   state. The drivers consider 'steady state' to begin after the first call to queueBuffer.
+   So, for instance, if a driver requires 3 buffers to run at steady state, and the server needs
+   to keep 2 buffers on hand at all time, the driver might dequeue 5 buffers, then cancel those 5 buffers.
+   After the first call to queueBuffer however, the client may never own more than the number it has
+   reserved (in this case, 3 buffers) */
+TEST_F(AndroidInterpreterTest, native_window_minimum_undequeued_query_hook)
+{
+    testing::NiceMock<MockMirSurface> mock_surface{surf_params};
+    mcla::ClientSurfaceInterpreter interpreter(mock_surface);
+
+    auto num_buffers = interpreter.driver_requests_info(NATIVE_WINDOW_MIN_UNDEQUEUED_BUFFERS);
+    EXPECT_EQ(2, num_buffers);
+}
