@@ -29,7 +29,7 @@
 #include "src/client/rpc/make_rpc_channel.h"
 #include "src/client/rpc/mir_basic_rpc_channel.h"
 
-#include "mir/frontend/resource_cache.h"
+#include "src/server/frontend/resource_cache.h"
 #include "mir/frontend/connector.h"
 #include "mir/input/input_platform.h"
 #include "mir/input/input_receiver_thread.h"
@@ -61,7 +61,7 @@ namespace test
 struct MockServerPackageGenerator : public StubServerTool
 {
     MockServerPackageGenerator()
-     : global_buffer_id(0)
+        : server_package(), global_buffer_id(0)
     {
         width_sent  = 891;
         height_sent = 458;
@@ -74,7 +74,7 @@ struct MockServerPackageGenerator : public StubServerTool
     {
         close(input_fd);
         for (int i = 0; i < server_package.fd_items; i++)
-            close(server_package.fd[0]);
+            close(server_package.fd[i]);
     }
 
     void create_surface(google::protobuf::RpcController*,
@@ -102,11 +102,12 @@ struct MockServerPackageGenerator : public StubServerTool
     {
         global_buffer_id++;
 
+        for (int i = 0; i < server_package.fd_items; i++)
+            close(server_package.fd[i]);
+
         int num_fd = 2, num_data = 8;
         for (auto i=0; i<num_fd; i++)
         {
-            if (server_package.fd[i])
-                close(server_package.fd[i]);
             server_package.fd[i] = open("/dev/null", O_APPEND);
         }
         server_package.fd_items = num_fd;
@@ -116,6 +117,8 @@ struct MockServerPackageGenerator : public StubServerTool
             server_package.data[i] = (global_buffer_id + i) * 2;
         }
         server_package.stride = stride_sent;
+        server_package.width = width_sent;
+        server_package.height = height_sent;
     }
 
     MirBufferPackage server_package;
@@ -124,7 +127,7 @@ struct MockServerPackageGenerator : public StubServerTool
     int height_sent;
     int pf_sent;
     int stride_sent;
-    
+
     int input_fd;
 
     private:
@@ -148,6 +151,8 @@ struct MockServerPackageGenerator : public StubServerTool
         }
 
         response->set_stride(server_package.stride);
+        response->set_width(server_package.width);
+        response->set_height(server_package.height);
     }
 
     void create_surface_response(mir::protobuf::Surface* response)
@@ -176,7 +181,7 @@ struct MockBuffer : public mcl::ClientBuffer
     MOCK_METHOD0(secure_for_cpu_write, std::shared_ptr<mcl::MemoryRegion>());
     MOCK_CONST_METHOD0(size, geom::Size());
     MOCK_CONST_METHOD0(stride, geom::Stride());
-    MOCK_CONST_METHOD0(pixel_format, geom::PixelFormat());
+    MOCK_CONST_METHOD0(pixel_format, MirPixelFormat());
     MOCK_CONST_METHOD0(age, uint32_t());
     MOCK_METHOD0(increment_age, void());
     MOCK_METHOD0(mark_as_submitted, void());
@@ -199,7 +204,7 @@ struct MockClientBufferFactory : public mcl::ClientBufferFactory
 
     MOCK_METHOD3(create_buffer,
                  std::shared_ptr<mcl::ClientBuffer>(std::shared_ptr<MirBufferPackage> const&,
-                                                    geom::Size, geom::PixelFormat));
+                                                    geom::Size, MirPixelFormat));
 
     std::shared_ptr<MirBufferPackage> current_package;
     std::shared_ptr<mcl::ClientBuffer> current_buffer;
@@ -210,8 +215,8 @@ struct StubClientPlatform : public mcl::ClientPlatform
 {
     MirPlatformType platform_type() const
     {
-        return mir_platform_type_android; 
-    } 
+        return mir_platform_type_android;
+    }
     std::shared_ptr<mcl::ClientBufferFactory> create_buffer_factory()
     {
         return std::shared_ptr<MockClientBufferFactory>();
@@ -306,7 +311,7 @@ struct MirClientSurfaceTest : public testing::Test
 
         test_server->comm->start();
 
-        mock_buffer_factory = std::make_shared<mt::MockClientBufferFactory>();
+        mock_buffer_factory = std::make_shared<testing::NiceMock<mt::MockClientBufferFactory>>();
 
         input_platform = std::make_shared<mt::StubClientInputPlatform>();
 
@@ -465,7 +470,7 @@ TEST_F(MirClientSurfaceTest, message_pf_used_in_buffer_creation )
 {
     using namespace testing;
 
-    geom::PixelFormat pf;
+    MirPixelFormat pf;
     std::shared_ptr<MirBufferPackage> submitted_package;
 
     EXPECT_CALL(*mock_buffer_factory, create_buffer(_,_,_))
@@ -478,7 +483,7 @@ TEST_F(MirClientSurfaceTest, message_pf_used_in_buffer_creation )
     auto wait_handle = surface->get_create_wait_handle();
     wait_handle->wait_for_all();
 
-    EXPECT_EQ(pf, geom::PixelFormat::abgr_8888);
+    EXPECT_EQ(pf, mir_pixel_format_abgr_8888);
 }
 
 
@@ -493,7 +498,7 @@ static void null_event_callback(MirSurface*, MirEvent const*, void*)
 TEST_F(MirClientSurfaceTest, input_fd_used_to_create_input_thread_when_delegate_specified)
 {
     using namespace ::testing;
-    
+
     auto mock_input_platform = std::make_shared<mt::MockClientInputPlatform>();
     auto mock_input_thread = std::make_shared<NiceMock<mt::MockInputReceiverThread>>();
     MirEventDelegate delegate = {null_event_callback, nullptr};
@@ -547,6 +552,49 @@ TEST_F(MirClientSurfaceTest, get_buffer_returns_last_received_buffer_package)
     Mock::VerifyAndClearExpectations(mock_buffer_factory.get());
 }
 
+TEST_F(MirClientSurfaceTest, surface_resizes_with_latest_buffer)
+{
+    using namespace testing;
+
+    EXPECT_CALL(*mock_buffer_factory, create_buffer(_,_,_))
+        .Times(1);
+
+    auto surface = std::make_shared<MirSurface> (connection.get(),
+                                                 *client_comm_channel,
+                                                 mock_buffer_factory,
+                                                 input_platform,
+                                                 params,
+                                                 &empty_callback,
+                                                 nullptr);
+    auto wait_handle = surface->get_create_wait_handle();
+    wait_handle->wait_for_all();
+    Mock::VerifyAndClearExpectations(mock_buffer_factory.get());
+
+    EXPECT_CALL(*mock_buffer_factory, create_buffer(_,_,_))
+        .Times(2);
+
+    auto buffer_wait_handle = surface->next_buffer(&empty_surface_callback,
+                                                   nullptr);
+    buffer_wait_handle->wait_for_all();
+
+    int new_width = mock_server_tool->width_sent += 12;
+    int new_height = mock_server_tool->height_sent -= 34;
+
+    auto const& before = surface->get_parameters();
+    EXPECT_NE(new_width, before.width);
+    EXPECT_NE(new_height, before.height);
+
+    buffer_wait_handle = surface->next_buffer(&empty_surface_callback,
+                                              nullptr);
+    buffer_wait_handle->wait_for_all();
+
+    auto const& after = surface->get_parameters();
+    EXPECT_EQ(new_width, after.width);
+    EXPECT_EQ(new_height, after.height);
+
+    Mock::VerifyAndClearExpectations(mock_buffer_factory.get());
+}
+
 TEST_F(MirClientSurfaceTest, default_surface_type)
 {
     using namespace testing;
@@ -590,7 +638,7 @@ namespace
 
 struct StubBuffer : public mcl::ClientBuffer
 {
-    StubBuffer(geom::Size size, geom::Stride stride, geom::PixelFormat pf)
+    StubBuffer(geom::Size size, geom::Stride stride, MirPixelFormat pf)
         : size_{size}, stride_{stride}, pf_{pf}
     {
     }
@@ -608,7 +656,7 @@ struct StubBuffer : public mcl::ClientBuffer
 
     geom::Size size() const { return size_; }
     geom::Stride stride() const { return stride_; }
-    geom::PixelFormat pixel_format() const { return pf_; }
+    MirPixelFormat pixel_format() const { return pf_; }
     uint32_t age() const { return 0; }
     void increment_age() {}
     void mark_as_submitted() {}
@@ -620,14 +668,14 @@ struct StubBuffer : public mcl::ClientBuffer
 
     geom::Size size_;
     geom::Stride stride_;
-    geom::PixelFormat pf_;
+    MirPixelFormat pf_;
 };
 
 struct StubClientBufferFactory : public mcl::ClientBufferFactory
 {
     std::shared_ptr<mcl::ClientBuffer> create_buffer(
         std::shared_ptr<MirBufferPackage> const& package,
-        geom::Size size, geom::PixelFormat pf)
+        geom::Size size, MirPixelFormat pf)
     {
         return std::make_shared<StubBuffer>(size,
                                             geom::Stride{package->stride},
