@@ -26,7 +26,7 @@
 #include "src/client/mir_surface.h"
 #include "src/client/client_buffer_factory.h"
 
-#include "mir/frontend/resource_cache.h" /* needed by test_server.h */
+#include "src/server/frontend/resource_cache.h" /* needed by test_server.h */
 #include "mir_test/test_protobuf_server.h"
 #include "mir_test/stub_server_tool.h"
 
@@ -78,7 +78,7 @@ struct MockRpcChannel : public mir::client::rpc::MirBasicRpcChannel
 struct StubClientBufferFactory : public mcl::ClientBufferFactory
 {
     std::shared_ptr<mcl::ClientBuffer> create_buffer(std::shared_ptr<MirBufferPackage> const& /* package */,
-                                                     geom::Size /*size*/, geom::PixelFormat /*pf*/) override
+                                                     geom::Size /*size*/, MirPixelFormat /*pf*/) override
     {
         return std::shared_ptr<mcl::ClientBuffer>();
     }
@@ -147,7 +147,7 @@ public:
     {
     }
 
-    std::shared_ptr<mcl::rpc::MirBasicRpcChannel> the_rpc_channel() override
+    std::shared_ptr<::google::protobuf::RpcChannel> the_rpc_channel() override
     {
         return channel;
     }
@@ -267,6 +267,17 @@ void fill_display_configuration(mp::ConnectParameters const*, mp::Connection* re
     }
 }
 
+std::vector<MirPixelFormat> const supported_surface_formats{
+    mir_pixel_format_argb_8888,
+    mir_pixel_format_bgr_888
+};
+
+void fill_surface_pixel_formats(mp::ConnectParameters const*, mp::Connection* response)
+{
+    for (auto pf : supported_surface_formats)
+        response->add_surface_pixel_format(static_cast<uint32_t>(pf));
+}
+
 }
 
 TEST_F(MirConnectionTest, populates_display_output_correctly_on_startup)
@@ -416,7 +427,7 @@ TEST_F(MirConnectionTest, populates_pfs_correctly)
     using namespace testing;
 
     EXPECT_CALL(*mock_channel, connect(_,_))
-        .WillOnce(Invoke(fill_display_configuration));
+        .WillOnce(Invoke(fill_surface_pixel_formats));
     MirWaitHandle* wait_handle = connection->connect("MirClientSurfaceTest",
                                                      connected_callback, 0);
     wait_handle->wait_for_all();
@@ -425,12 +436,12 @@ TEST_F(MirConnectionTest, populates_pfs_correctly)
     unsigned int valid_formats = 0;
     MirPixelFormat formats[formats_size];
 
-    connection->possible_pixel_formats(&formats[0], formats_size, valid_formats);
+    connection->available_surface_formats(&formats[0], formats_size, valid_formats);
 
-    ASSERT_EQ(2u, valid_formats);
+    ASSERT_EQ(supported_surface_formats.size(), valid_formats);
     for (auto i=0u; i < valid_formats; i++)
     {
-        EXPECT_EQ(supported_output_formats[i], formats[i]);
+        EXPECT_EQ(supported_surface_formats[i], formats[i]) << "i=" << i;
     }
 }
 
@@ -444,6 +455,7 @@ TEST_F(MirConnectionTest, valid_display_configure_sent)
     MirDisplayOutput output;
     output.output_id = 0;
     output.current_mode = 0;
+    output.current_format = mir_pixel_format_xbgr_8888;
     output.used = 0;
     output.position_x = 4;
     output.position_y = 6;
@@ -455,10 +467,17 @@ TEST_F(MirConnectionTest, valid_display_configure_sent)
         ASSERT_NE(nullptr, config);
         ASSERT_EQ(1, config->display_output_size());
         auto const& disp1 = config->display_output(0);
+        EXPECT_TRUE(disp1.has_output_id());
         EXPECT_EQ(output.output_id, disp1.output_id());
+        EXPECT_TRUE(disp1.has_used());
         EXPECT_EQ(output.used, disp1.used());
+        EXPECT_TRUE(disp1.has_current_mode());
         EXPECT_EQ(output.current_mode, disp1.current_mode());
+        EXPECT_TRUE(disp1.has_current_format());
+        EXPECT_EQ(output.current_format, disp1.current_format());
+        EXPECT_TRUE(disp1.has_position_x());
         EXPECT_EQ(output.position_x, disp1.position_x());
+        EXPECT_TRUE(disp1.has_position_y());
         EXPECT_EQ(output.position_y, disp1.position_y());
     };
 
@@ -499,7 +518,7 @@ TEST_F(MirConnectionTest, focused_window_synthesises_unfocus_event_on_release)
     MirEventDelegate const event_delegate = {
         &surface_event_callback,
         nullptr
-    };  
+    };
 
     unfocused_received = false;
 
@@ -521,6 +540,9 @@ TEST_F(MirConnectionTest, focused_window_synthesises_unfocus_event_on_release)
     wait_handle = connection->release_surface(surface, &surface_callback, nullptr);
     wait_handle->wait_for_all();
 
+    wait_handle = connection->disconnect();
+    wait_handle->wait_for_all();
+
     EXPECT_TRUE(unfocused_received);
 }
 
@@ -534,7 +556,7 @@ TEST_F(MirConnectionTest, unfocused_window_does_not_synthesise_unfocus_event_on_
     MirEventDelegate const event_delegate = {
         &surface_event_callback,
         nullptr
-    };  
+    };
 
     unfocused_received = false;
 
@@ -556,5 +578,55 @@ TEST_F(MirConnectionTest, unfocused_window_does_not_synthesise_unfocus_event_on_
     wait_handle = connection->release_surface(surface, &surface_callback, nullptr);
     wait_handle->wait_for_all();
 
+    wait_handle = connection->disconnect();
+    wait_handle->wait_for_all();
+
     EXPECT_FALSE(unfocused_received);
 }
+
+namespace
+{
+
+ACTION_P(FillPlatformDataWith, sample_data)
+{
+    for (auto d : sample_data)
+        arg1->mutable_platform()->add_data(d);
+}
+
+}
+
+TEST_F(MirConnectionTest, sets_extra_platform_data)
+{
+    using namespace testing;
+    std::vector<int> const initial_data{0x66, 0x67, 0x68};
+    std::vector<int> const extra_data{0x11, 0x12, 0x13};
+
+    EXPECT_CALL(*mock_channel, connect(_,_))
+        .WillOnce(FillPlatformDataWith(initial_data));
+
+    MirWaitHandle *wait_handle =
+        connection->connect("MirClientSurfaceTest", &connected_callback, nullptr);
+    wait_handle->wait_for_all();
+
+    MirPlatformPackage pkg;
+
+    /* Check initial data */
+    connection->populate(pkg);
+
+    EXPECT_EQ(initial_data.size(), static_cast<size_t>(pkg.data_items));
+    for (size_t i = 0; i < initial_data.size(); i++)
+        EXPECT_EQ(initial_data[i], pkg.data[i]) << " i=" << i;
+
+    /* Check initial data plus extra data*/
+    connection->set_extra_platform_data(extra_data);
+    connection->populate(pkg);
+
+    EXPECT_EQ(initial_data.size() + extra_data.size(),
+              static_cast<size_t>(pkg.data_items));
+
+    for (size_t i = 0; i < initial_data.size(); i++)
+        EXPECT_EQ(initial_data[i], pkg.data[i]) << " i=" << i;
+
+    for (size_t i = 0; i < extra_data.size(); i++)
+        EXPECT_EQ(extra_data[i], pkg.data[i + initial_data.size()]) << " i=" << i;
+}
