@@ -16,7 +16,7 @@
  * Authored by: Kevin DuBois <kevin.dubois@canonical.com>
  */
 
-#include "mir/compositor/buffer_stream_surfaces.h"
+#include "src/server/compositor/buffer_stream_surfaces.h"
 
 #include "mir_test_doubles/stub_buffer.h"
 #include "mir_test_doubles/mock_buffer_bundle.h"
@@ -25,11 +25,12 @@
 #include <gmock/gmock.h>
 #include <gtest/gtest.h>
 
+#include <condition_variable>
+
 namespace mc = mir::compositor;
 namespace mg = mir::graphics;
 namespace geom = mir::geometry;
 namespace mtd = mir::test::doubles;
-namespace ms = mir::surfaces;
 
 class BufferStreamTest : public ::testing::Test
 {
@@ -51,7 +52,7 @@ protected:
 TEST_F(BufferStreamTest, size_query)
 {
     geom::Size size{4, 5};
-    mg::BufferProperties properties {size, geom::PixelFormat::abgr_8888, mg::BufferUsage::hardware};
+    mg::BufferProperties properties {size, mir_pixel_format_abgr_8888, mg::BufferUsage::hardware};
     EXPECT_CALL(*mock_bundle, properties())
         .Times(1)
         .WillOnce(testing::Return(properties));
@@ -63,7 +64,7 @@ TEST_F(BufferStreamTest, size_query)
 
 TEST_F(BufferStreamTest, pixel_format_query)
 {
-    geom::PixelFormat format{geom::PixelFormat::abgr_8888};
+    MirPixelFormat format{mir_pixel_format_abgr_8888};
     mg::BufferProperties properties {geom::Size{4, 5}, format, mg::BufferUsage::hardware};
     EXPECT_CALL(*mock_bundle, properties())
         .Times(1)
@@ -123,19 +124,53 @@ TEST_F(BufferStreamTest, get_buffer_for_compositor_can_lock)
 
 TEST_F(BufferStreamTest, get_buffer_for_client_releases_resources)
 {
-    using namespace testing;
+    std::mutex mutex;
+    std::condition_variable cv;
+    mg::Buffer* buffer{nullptr};
+    bool done = false;
 
-    EXPECT_CALL(*mock_bundle, client_acquire())
-        .Times(1)
-        .WillOnce(Return(mock_buffer));
-    EXPECT_CALL(*mock_bundle, client_release(_))
-        .Times(1);
+    auto const callback =
+        [&](mg::Buffer* new_buffer)
+        {
+           std::unique_lock<decltype(mutex)> lock(mutex);
+           buffer = new_buffer;
+           done = true;
+           cv.notify_one();
+        };
+
+    using namespace testing;
     mc::BufferStreamSurfaces buffer_stream(mock_bundle);
 
-    buffer_stream.secure_client_buffer();
+    InSequence seq;
+    EXPECT_CALL(*mock_bundle, client_acquire(_))
+        .Times(1)
+        .WillOnce(InvokeArgument<0>(mock_buffer.get()));
+    EXPECT_CALL(*mock_bundle, client_release(_))
+        .Times(1);
+    EXPECT_CALL(*mock_bundle, client_acquire(_))
+        .Times(1)
+        .WillOnce(InvokeArgument<0>(mock_buffer.get()));
+
+    buffer_stream.swap_client_buffers(buffer, callback);
+
+    {
+        std::unique_lock<decltype(mutex)> lock(mutex);
+
+        cv.wait(lock, [&]{ return done; });
+    }
+
+    done = false;
+
+    buffer_stream.swap_client_buffers(buffer, callback);
+
+    {
+        std::unique_lock<decltype(mutex)> lock(mutex);
+
+        cv.wait(lock, [&]{ return done; });
+    }
 }
 
-TEST_F(BufferStreamTest, allow_framedropping_command)
+TEST_F(BufferStreamTest, allow_framedropping_device)
 {
     EXPECT_CALL(*mock_bundle, allow_framedropping(true))
         .Times(1);
@@ -143,3 +178,15 @@ TEST_F(BufferStreamTest, allow_framedropping_command)
     mc::BufferStreamSurfaces buffer_stream(mock_bundle);
     buffer_stream.allow_framedropping(true);
 }
+
+TEST_F(BufferStreamTest, resizes_bundle)
+{
+    geom::Size const new_size{66, 77};
+
+    EXPECT_CALL(*mock_bundle, resize(new_size))
+        .Times(1);
+
+    mc::BufferStreamSurfaces buffer_stream(mock_bundle);
+    buffer_stream.resize(new_size);
+}
+
