@@ -23,19 +23,22 @@
 #include <gtest/gtest.h>
 #include <gmock/gmock.h>
 #include <mir/geometry/rectangle.h>
-#include <mir/compositor/renderer.h>
-#include <mir/compositor/gl_renderer_factory.h>
+#include "mir/compositor/renderer.h"
+#include "src/server/compositor/gl_renderer_factory.h"
 #include <mir_test/fake_shared.h>
 #include <mir_test_doubles/mock_buffer.h>
-#include <mir_test_doubles/mock_compositing_criteria.h>
+#include <mir_test_doubles/mock_renderable.h>
 #include <mir_test_doubles/mock_buffer_stream.h>
-#include <mir/surfaces/buffer_stream.h>
+#include <mir/compositor/buffer_stream.h>
 #include <mir_test_doubles/mock_gl.h>
 
 using testing::SetArgPointee;
 using testing::InSequence;
 using testing::Return;
 using testing::ReturnRef;
+using testing::Pointee;
+using testing::AnyNumber;
+using testing::AtLeast;
 using testing::_;
 
 namespace mt=mir::test;
@@ -46,22 +49,20 @@ namespace mg=mir::graphics;
 namespace
 {
 
-const GLint stub_bad_shader = 0;
-const GLint stub_bad_program = 0;
 const GLint stub_v_shader = 1;
 const GLint stub_f_shader = 2;
 const GLint stub_program = 1;
-const GLint stub_vbo = 1;
-const GLint stub_texture = 1;
+const GLuint stub_texture = 1;
 const GLint transform_uniform_location = 1;
 const GLint alpha_uniform_location = 2;
 const GLint position_attr_location = 3;
 const GLint texcoord_attr_location = 4;
 const GLint screen_to_gl_coords_uniform_location = 5;
 const GLint tex_uniform_location = 6;
+const GLint display_transform_uniform_location = 7;
+const GLint centre_uniform_location = 8;
 const std::string stub_info_log = "something failed!";
 const size_t stub_info_log_length = stub_info_log.size();
-const size_t stub_info_log_buffer_length = stub_info_log_length + 1;
 
 void ExpectShaderCompileFailure(const GLint shader, mtd::MockGL &mock_gl)
 {
@@ -123,10 +124,10 @@ void SetUpMockProgramData(mtd::MockGL &mock_gl)
     /* Uniforms and Attributes */
     EXPECT_CALL(mock_gl, glUseProgram(stub_program));
 
-    EXPECT_CALL(mock_gl, glGetUniformLocation(stub_program, _))
-        .WillOnce(Return(screen_to_gl_coords_uniform_location));
     EXPECT_CALL(mock_gl, glGetUniformLocation(stub_program, _))
         .WillOnce(Return(tex_uniform_location));
+    EXPECT_CALL(mock_gl, glGetUniformLocation(stub_program, _))
+        .WillOnce(Return(display_transform_uniform_location));
     EXPECT_CALL(mock_gl, glGetUniformLocation(stub_program, _))
         .WillOnce(Return(transform_uniform_location));
     EXPECT_CALL(mock_gl, glGetUniformLocation(stub_program, _))
@@ -135,33 +136,8 @@ void SetUpMockProgramData(mtd::MockGL &mock_gl)
         .WillOnce(Return(position_attr_location));
     EXPECT_CALL(mock_gl, glGetAttribLocation(stub_program, _))
         .WillOnce(Return(texcoord_attr_location));
-
-    EXPECT_CALL(mock_gl, glUniformMatrix4fv(screen_to_gl_coords_uniform_location, 1, GL_FALSE, _));
-}
-
-void SetUpMockRenderTexture(mtd::MockGL &mock_gl)
-{
-    /* Set up the render texture */
-    EXPECT_CALL(mock_gl, glGenTextures(1, _))
-        .WillOnce(SetArgPointee<1>(stub_texture));
-    EXPECT_CALL(mock_gl, glBindTexture(GL_TEXTURE_2D, stub_texture));
-    EXPECT_CALL(mock_gl, glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE));
-    EXPECT_CALL(mock_gl, glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE));
-    EXPECT_CALL(mock_gl, glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR));
-    EXPECT_CALL(mock_gl, glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR));
-}
-
-void FillMockVertexBuffer(mtd::MockGL &mock_gl)
-{
-    /* Set up VBO */
-    EXPECT_CALL(mock_gl, glGenBuffers(1, _))
-        .WillOnce(SetArgPointee<1>(stub_vbo));
-    EXPECT_CALL(mock_gl, glBindBuffer(GL_ARRAY_BUFFER, stub_vbo));
-    EXPECT_CALL(mock_gl, glBufferData(GL_ARRAY_BUFFER, _, _, GL_STATIC_DRAW));
-
-    /* These should go away */
-    EXPECT_CALL(mock_gl, glBindBuffer(GL_ARRAY_BUFFER, 0));
-    EXPECT_CALL(mock_gl, glUseProgram(0));
+    EXPECT_CALL(mock_gl, glGetUniformLocation(stub_program, _))
+        .WillOnce(Return(centre_uniform_location));
 }
 
 class GLRendererSetupProcess :
@@ -262,79 +238,243 @@ public:
     {
         using namespace std::placeholders;
 
+        // Silence warnings about "uninteresting" calls that we truly aren't
+        // interested in (for most test cases)...
+        EXPECT_CALL(mock_gl, glClear(_)).Times(AnyNumber());
+        EXPECT_CALL(mock_gl, glUseProgram(_)).Times(AnyNumber());
+        EXPECT_CALL(mock_gl, glActiveTexture(_)).Times(AnyNumber());
+        EXPECT_CALL(mock_gl, glUniformMatrix4fv(_, _, GL_FALSE, _))
+            .Times(AtLeast(1));
+        EXPECT_CALL(mock_gl, glUniform1f(_, _)).Times(AnyNumber());
+        EXPECT_CALL(mock_gl, glUniform2f(_, _, _)).Times(AnyNumber());
+        EXPECT_CALL(mock_gl, glBindBuffer(_, _)).Times(AnyNumber());
+        EXPECT_CALL(mock_gl, glVertexAttribPointer(_, _, _, _, _, _))
+            .Times(AnyNumber());
+        EXPECT_CALL(mock_gl, glEnableVertexAttribArray(_)).Times(AnyNumber());
+        EXPECT_CALL(mock_gl, glDrawArrays(_, _, _)).Times(AnyNumber());
+        EXPECT_CALL(mock_gl, glDisableVertexAttribArray(_)).Times(AnyNumber());
+
+        EXPECT_CALL(renderable, shaped()).WillRepeatedly(Return(false));
+        EXPECT_CALL(renderable, alpha()).WillRepeatedly(Return(1.0f));
+        EXPECT_CALL(renderable, transformation()).WillRepeatedly(Return(trans));
+        EXPECT_CALL(renderable, screen_position())
+            .WillRepeatedly(Return(mir::geometry::Rectangle{{1,2},{3,4}}));
+        EXPECT_CALL(mock_gl, glDisable(_)).Times(AnyNumber());
+
         InSequence s;
 
         SetUpMockVertexShader(mock_gl, std::bind(ExpectShaderCompileSuccess, _1, _2));
         SetUpMockFragmentShader(mock_gl, std::bind(ExpectShaderCompileSuccess, _1, _2));
         SetUpMockGraphicsProgram(mock_gl, std::bind(ExpectProgramLinkSuccess, _1,_2));
         SetUpMockProgramData(mock_gl);
-        SetUpMockRenderTexture(mock_gl);
         EXPECT_CALL(mock_gl, glUniform1i(tex_uniform_location, 0));
-        FillMockVertexBuffer(mock_gl);
+
+        EXPECT_CALL(mock_gl, glGetUniformLocation(stub_program, _))
+            .WillOnce(Return(screen_to_gl_coords_uniform_location));
 
         mc::GLRendererFactory gl_renderer_factory;
+        display_area = {{1, 2}, {3, 4}};
         renderer = gl_renderer_factory.create_renderer_for(display_area);
+
+        EXPECT_CALL(mock_gl, glDeleteShader(stub_v_shader));
+        EXPECT_CALL(mock_gl, glDeleteShader(stub_f_shader));
+        EXPECT_CALL(mock_gl, glDeleteProgram(stub_program));
     }
 
     mtd::MockGL         mock_gl;
     mir::geometry::Rectangle display_area;
     std::unique_ptr<mc::Renderer> renderer;
     glm::mat4           trans;
+    mtd::MockRenderable renderable;
 };
 
 }
 
-TEST_F(GLRenderer, TestSetUpRenderContextBeforeRenderingRenderable)
+TEST_F(GLRenderer, TestSetUpRenderContextBeforeRendering)
 {
     using namespace std::placeholders;
 
-    mtd::MockBufferStream stream;
-    mtd::MockCompositingCriteria criteria;
-    mtd::MockBuffer gr;
-
-    int save_count = 0;
-    std::vector<std::shared_ptr<void>> saved_resources;
-    auto saving_lambda = [&] (std::shared_ptr<void> const& saved_resource)
-    {
-        save_count++;
-        saved_resources.push_back(saved_resource);
-    };
+    mtd::MockBuffer mock_buffer;
 
     InSequence seq;
 
+    EXPECT_CALL(mock_gl, glClear(_));
     EXPECT_CALL(mock_gl, glUseProgram(stub_program));
+    EXPECT_CALL(renderable, shaped())
+        .WillOnce(Return(true));
     EXPECT_CALL(mock_gl, glEnable(GL_BLEND));
     EXPECT_CALL(mock_gl, glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA));
     EXPECT_CALL(mock_gl, glActiveTexture(GL_TEXTURE0));
 
-    EXPECT_CALL(criteria, transformation())
-        .WillOnce(ReturnRef(trans));
+    EXPECT_CALL(mock_gl, glUniform2f(centre_uniform_location, _, _));
+    EXPECT_CALL(renderable, transformation())
+        .WillOnce(Return(trans));
     EXPECT_CALL(mock_gl, glUniformMatrix4fv(transform_uniform_location, 1, GL_FALSE, _));
-    EXPECT_CALL(criteria, alpha())
+    EXPECT_CALL(renderable, alpha())
         .WillOnce(Return(0.0f));
     EXPECT_CALL(mock_gl, glUniform1f(alpha_uniform_location, _));
-    EXPECT_CALL(mock_gl, glBindBuffer(GL_ARRAY_BUFFER, stub_vbo));
-    EXPECT_CALL(mock_gl, glVertexAttribPointer(position_attr_location, 3, GL_FLOAT, GL_FALSE, _, _));
-    EXPECT_CALL(mock_gl, glVertexAttribPointer(texcoord_attr_location, 2, GL_FLOAT, GL_FALSE, _, _));
 
+    EXPECT_CALL(mock_buffer, id())
+        .WillOnce(Return(mg::BufferID(123)));
+    EXPECT_CALL(mock_gl, glGenTextures(1, _))
+        .WillOnce(SetArgPointee<1>(stub_texture));
     EXPECT_CALL(mock_gl, glBindTexture(GL_TEXTURE_2D, stub_texture));
+    EXPECT_CALL(mock_gl, glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, _));
+    EXPECT_CALL(mock_gl, glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, _));
+    EXPECT_CALL(mock_gl, glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, _));
+    EXPECT_CALL(mock_gl, glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, _));
 
-    EXPECT_CALL(stream, lock_compositor_buffer(_))
-        .Times(1)
-        .WillOnce(Return(mt::fake_shared(gr)));
-    EXPECT_CALL(gr, bind_to_texture());
+    EXPECT_CALL(mock_buffer, bind_to_texture());
 
     EXPECT_CALL(mock_gl, glEnableVertexAttribArray(position_attr_location));
     EXPECT_CALL(mock_gl, glEnableVertexAttribArray(texcoord_attr_location));
 
+    EXPECT_CALL(mock_buffer, size())
+        .WillOnce(Return(mir::geometry::Size{123, 456}));
+
+    EXPECT_CALL(mock_gl, glBindTexture(GL_TEXTURE_2D, stub_texture));
+    EXPECT_CALL(mock_gl, glVertexAttribPointer(position_attr_location, 3,
+                                               GL_FLOAT, GL_FALSE, _, _));
+    EXPECT_CALL(mock_gl, glVertexAttribPointer(texcoord_attr_location, 2,
+                                               GL_FLOAT, GL_FALSE, _, _));
+
     EXPECT_CALL(mock_gl, glDrawArrays(GL_TRIANGLE_STRIP, 0, 4));
 
     EXPECT_CALL(mock_gl, glDisableVertexAttribArray(texcoord_attr_location));
     EXPECT_CALL(mock_gl, glDisableVertexAttribArray(position_attr_location));
 
-    renderer->render(saving_lambda, criteria, stream);
+    EXPECT_CALL(mock_gl, glClear(_));
+    EXPECT_CALL(mock_gl, glDeleteTextures(1, Pointee(stub_texture)));
 
-    EXPECT_EQ(1, save_count);
-    auto result = std::find(saved_resources.begin(), saved_resources.end(), mt::fake_shared(gr));
-    EXPECT_NE(saved_resources.end(), result);
+    renderer->begin();
+    renderer->render(renderable, mock_buffer);
+    renderer->end();
+
+    // Clear the cache to ensure tests are not sensitive to execution order
+    renderer->begin();
+    renderer->end();
+}
+
+TEST_F(GLRenderer, disables_blending_for_rgbx_surfaces)
+{
+    mtd::MockBuffer mock_buffer;
+
+    InSequence seq;
+    EXPECT_CALL(renderable, shaped())
+        .WillOnce(Return(false));
+    EXPECT_CALL(mock_gl, glDisable(GL_BLEND));
+
+    EXPECT_CALL(mock_buffer, id())
+        .WillOnce(Return(mg::BufferID(123)));
+    EXPECT_CALL(mock_gl, glGenTextures(1, _))
+        .WillOnce(SetArgPointee<1>(stub_texture));
+    EXPECT_CALL(mock_gl, glBindTexture(GL_TEXTURE_2D, stub_texture));
+    EXPECT_CALL(mock_gl, glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, _));
+    EXPECT_CALL(mock_gl, glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, _));
+    EXPECT_CALL(mock_gl, glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, _));
+    EXPECT_CALL(mock_gl, glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, _));
+
+    EXPECT_CALL(mock_buffer, bind_to_texture());
+    EXPECT_CALL(mock_buffer, size())
+        .WillOnce(Return(mir::geometry::Size{123, 456}));
+
+    EXPECT_CALL(mock_gl, glBindTexture(GL_TEXTURE_2D, stub_texture));
+    EXPECT_CALL(mock_gl, glDeleteTextures(1, Pointee(stub_texture)));
+
+    renderer->begin();
+    renderer->render(renderable, mock_buffer);
+    renderer->end();
+
+    // Clear the cache to ensure tests are not sensitive to execution order
+    renderer->begin();
+    renderer->end();
+}
+
+TEST_F(GLRenderer, caches_and_uploads_texture_only_on_buffer_changes)
+{
+    mtd::MockBuffer mock_buffer;
+
+    EXPECT_CALL(mock_buffer, size())
+        .WillRepeatedly(Return(mir::geometry::Size{123, 456}));
+
+    InSequence seq;
+
+    // First render() - texture generated and uploaded
+    EXPECT_CALL(mock_buffer, id())
+        .WillOnce(Return(mg::BufferID(123)));
+    EXPECT_CALL(mock_gl, glGenTextures(1, _))
+        .WillOnce(SetArgPointee<1>(stub_texture));
+    EXPECT_CALL(mock_gl, glBindTexture(GL_TEXTURE_2D, stub_texture));
+    EXPECT_CALL(mock_gl, glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, _));
+    EXPECT_CALL(mock_gl, glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, _));
+    EXPECT_CALL(mock_gl, glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER,
+                                         _));
+    EXPECT_CALL(mock_gl, glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER,
+                                         _));
+    EXPECT_CALL(mock_buffer, bind_to_texture());
+    EXPECT_CALL(mock_gl, glBindTexture(GL_TEXTURE_2D, stub_texture));
+    EXPECT_CALL(mock_gl, glDeleteTextures(_, _))
+        .Times(0);
+
+    // Second render() - texture found in cache and not re-uploaded
+    EXPECT_CALL(mock_buffer, id())
+        .WillOnce(Return(mg::BufferID(123)));
+    EXPECT_CALL(mock_gl, glBindTexture(GL_TEXTURE_2D, stub_texture));
+    EXPECT_CALL(mock_gl, glBindTexture(GL_TEXTURE_2D, stub_texture));
+    EXPECT_CALL(mock_gl, glDeleteTextures(_, _))
+        .Times(0);
+
+    // Third render() - texture found in cache but refreshed with new buffer
+    EXPECT_CALL(mock_buffer, id())
+        .WillOnce(Return(mg::BufferID(456)));
+    EXPECT_CALL(mock_gl, glBindTexture(GL_TEXTURE_2D, stub_texture));
+    EXPECT_CALL(mock_buffer, bind_to_texture());
+    EXPECT_CALL(mock_gl, glBindTexture(GL_TEXTURE_2D, stub_texture));
+    EXPECT_CALL(mock_gl, glDeleteTextures(1, Pointee(stub_texture)))
+        .Times(0);
+
+    // Forth render() - stale texture reuploaded following bypass
+    EXPECT_CALL(mock_buffer, id())
+        .WillOnce(Return(mg::BufferID(456)));
+    EXPECT_CALL(mock_gl, glBindTexture(GL_TEXTURE_2D, stub_texture));
+    EXPECT_CALL(mock_buffer, bind_to_texture());
+    EXPECT_CALL(mock_gl, glBindTexture(GL_TEXTURE_2D, stub_texture));
+    EXPECT_CALL(mock_gl, glDeleteTextures(1, Pointee(stub_texture)))
+        .Times(0);
+
+    // Fifth render() - texture found in cache and not re-uploaded
+    EXPECT_CALL(mock_buffer, id())
+        .WillOnce(Return(mg::BufferID(456)));
+    EXPECT_CALL(mock_gl, glBindTexture(GL_TEXTURE_2D, stub_texture));
+    EXPECT_CALL(mock_gl, glBindTexture(GL_TEXTURE_2D, stub_texture));
+    EXPECT_CALL(mock_gl, glDeleteTextures(_, _))
+        .Times(0);
+
+    EXPECT_CALL(mock_gl, glDeleteTextures(1, Pointee(stub_texture)));
+
+    renderer->begin();
+    renderer->render(renderable, mock_buffer);
+    renderer->end();
+
+    renderer->begin();
+    renderer->render(renderable, mock_buffer);
+    renderer->end();
+
+    renderer->begin();
+    renderer->render(renderable, mock_buffer);
+    renderer->end();
+
+    renderer->suspend();
+
+    renderer->begin();
+    renderer->render(renderable, mock_buffer);
+    renderer->end();
+
+    renderer->begin();
+    renderer->render(renderable, mock_buffer);
+    renderer->end();
+
+    // Clear the cache to ensure tests are not sensitive to execution order
+    renderer->begin();
+    renderer->end();
 }
