@@ -24,6 +24,7 @@
 
 #include <atomic>
 #include <thread>
+#include <mutex>
 #include <chrono>
 
 namespace geom=mir::geometry;
@@ -33,6 +34,8 @@ namespace mg = mir::graphics;
 
 using namespace testing;
 
+namespace
+{
 struct SwitchingBundleTest : public ::testing::Test
 {
     void SetUp()
@@ -41,7 +44,7 @@ struct SwitchingBundleTest : public ::testing::Test
         basic_properties =
         {
             geom::Size{3, 4},
-            geom::PixelFormat::abgr_8888,
+            mir_pixel_format_abgr_8888,
             mg::BufferUsage::hardware
         };
     }
@@ -51,13 +54,41 @@ struct SwitchingBundleTest : public ::testing::Test
     mg::BufferProperties basic_properties;
 };
 
+auto client_acquire_blocking(mc::SwitchingBundle& switching_bundle)
+-> mg::Buffer*
+{
+    std::mutex mutex;
+    std::condition_variable cv;
+    bool done = false;
+
+    mg::Buffer* result;
+    switching_bundle.client_acquire(
+        [&](mg::Buffer* new_buffer)
+         {
+            std::unique_lock<decltype(mutex)> lock(mutex);
+
+            result = new_buffer;
+            done = true;
+            cv.notify_one();
+         });
+
+    std::unique_lock<decltype(mutex)> lock(mutex);
+
+    cv.wait(lock, [&]{ return done; });
+
+    return result;
+}
+}
+
 TEST_F(SwitchingBundleTest, sync_swapper_by_default)
 {
     mg::BufferProperties properties{geom::Size{7, 8},
-                                    geom::PixelFormat::argb_8888,
+                                    mir_pixel_format_argb_8888,
                                     mg::BufferUsage::software};
 
-    for (int nbuffers = 2; nbuffers <= 5; nbuffers++)
+    for (int nbuffers = mc::SwitchingBundle::min_buffers;
+         nbuffers <= mc::SwitchingBundle::max_buffers;
+         ++nbuffers)
     {
         mc::SwitchingBundle bundle(nbuffers, allocator, properties);
 
@@ -91,11 +122,13 @@ TEST_F(SwitchingBundleTest, invalid_nbuffers)
 
 TEST_F(SwitchingBundleTest, client_acquire_basic)
 {
-    for (int nbuffers = 2; nbuffers <= 5; nbuffers++)
+    for (int nbuffers = mc::SwitchingBundle::min_buffers;
+         nbuffers <= mc::SwitchingBundle::max_buffers;
+         ++nbuffers)
     {
         mc::SwitchingBundle bundle(nbuffers, allocator, basic_properties);
 
-        auto buffer = bundle.client_acquire();
+        auto buffer = client_acquire_blocking(bundle);
         bundle.client_release(buffer);
     }
 }
@@ -103,11 +136,9 @@ TEST_F(SwitchingBundleTest, client_acquire_basic)
 namespace
 {
     void composite_thread(mc::SwitchingBundle &bundle,
-                          unsigned long &frameno,
                           mg::BufferID &composited)
     {
-        frameno++;
-        auto buffer = bundle.compositor_acquire(frameno);
+        auto buffer = bundle.compositor_acquire(nullptr);
         composited = buffer->id();
         bundle.compositor_release(buffer);
     }
@@ -115,23 +146,23 @@ namespace
 
 TEST_F(SwitchingBundleTest, is_really_synchronous)
 {
-    for (int nbuffers = 2; nbuffers <= 5; nbuffers++)
+    for (int nbuffers = mc::SwitchingBundle::min_buffers;
+         nbuffers <= mc::SwitchingBundle::max_buffers;
+         ++nbuffers)
     {
         mc::SwitchingBundle bundle(nbuffers, allocator, basic_properties);
         mg::BufferID prev_id, prev_prev_id;
-        unsigned long frameno = 0;
 
         ASSERT_FALSE(bundle.framedropping_allowed());
 
         for (int i = 0; i < 20; i++)
         {
-            auto client1 = bundle.client_acquire();
+            auto client1 = client_acquire_blocking(bundle);
             mg::BufferID expect_id = client1->id(), composited_id;
             bundle.client_release(client1);
 
             std::thread compositor(composite_thread,
                                    std::ref(bundle),
-                                   std::ref(frameno),
                                    std::ref(composited_id));
 
             compositor.join();
@@ -143,7 +174,7 @@ TEST_F(SwitchingBundleTest, is_really_synchronous)
             prev_prev_id = prev_id;
             prev_id = composited_id;
 
-            auto second_monitor = bundle.compositor_acquire(frameno);
+            auto second_monitor = bundle.compositor_acquire(this);
             ASSERT_EQ(composited_id, second_monitor->id());
             bundle.compositor_release(second_monitor);
         }
@@ -152,10 +183,11 @@ TEST_F(SwitchingBundleTest, is_really_synchronous)
 
 TEST_F(SwitchingBundleTest, framedropping_clients_never_block)
 {
-    for (int nbuffers = 2; nbuffers <= 5; nbuffers++)
+    for (int nbuffers = 2;
+         nbuffers <= mc::SwitchingBundle::max_buffers;
+         ++nbuffers)
     {
         mc::SwitchingBundle bundle(nbuffers, allocator, basic_properties);
-        unsigned int frameno = 0;
 
         bundle.allow_framedropping(true);
         mg::BufferID last_client_id;
@@ -164,7 +196,7 @@ TEST_F(SwitchingBundleTest, framedropping_clients_never_block)
         {
             for (int j = 0; j < 100; j++)
             {
-                auto client = bundle.client_acquire();
+                auto client = client_acquire_blocking(bundle);
                 last_client_id = client->id();
                 bundle.client_release(client);
             }
@@ -172,12 +204,10 @@ TEST_F(SwitchingBundleTest, framedropping_clients_never_block)
             // Flush the pipeline of previously ready buffers
             for (int k = 0; k < nbuffers-1; k++)
             {
-                frameno++;
-                bundle.compositor_release(bundle.compositor_acquire(frameno));
+                bundle.compositor_release(bundle.compositor_acquire(nullptr));
             }
 
-            frameno++;
-            auto compositor = bundle.compositor_acquire(frameno);
+            auto compositor = bundle.compositor_acquire(nullptr);
             ASSERT_EQ(last_client_id, compositor->id());
             bundle.compositor_release(compositor);
         }
@@ -188,28 +218,28 @@ TEST_F(SwitchingBundleTest, clients_dont_recycle_startup_buffer)
 {  // Regression test for LP: #1210042
     mc::SwitchingBundle bundle(3, allocator, basic_properties);
 
-    auto client1 = bundle.client_acquire();
+    auto client1 = client_acquire_blocking(bundle);
     auto client1_id = client1->id();
     bundle.client_release(client1);
-    client1.reset();
 
-    auto client2 = bundle.client_acquire();
+    auto client2 = client_acquire_blocking(bundle);
     bundle.client_release(client2);
-    client2.reset();
 
-    auto compositor = bundle.compositor_acquire(1);
+    auto compositor = bundle.compositor_acquire(nullptr);
     EXPECT_EQ(client1_id, compositor->id());
     bundle.compositor_release(compositor);
 }
 
 TEST_F(SwitchingBundleTest, out_of_order_client_release)
 {
-    for (int nbuffers = 3; nbuffers <= 5; nbuffers++)
+    for (int nbuffers = 2;
+         nbuffers <= mc::SwitchingBundle::max_buffers;
+         ++nbuffers)
     {
         mc::SwitchingBundle bundle(nbuffers, allocator, basic_properties);
 
-        auto client1 = bundle.client_acquire();
-        auto client2 = bundle.client_acquire();
+        auto client1 = client_acquire_blocking(bundle);
+        auto client2 = client_acquire_blocking(bundle);
         EXPECT_THROW(
             bundle.client_release(client2),
             std::logic_error
@@ -225,38 +255,81 @@ TEST_F(SwitchingBundleTest, out_of_order_client_release)
 
 TEST_F(SwitchingBundleTest, compositor_acquire_basic)
 {
-    for (int nbuffers = 2; nbuffers <= 5; nbuffers++)
+    for (int nbuffers = mc::SwitchingBundle::min_buffers;
+         nbuffers <= mc::SwitchingBundle::max_buffers;
+         ++nbuffers)
     {
         mc::SwitchingBundle bundle(nbuffers, allocator, basic_properties);
-        unsigned long frameno = 0;
 
-        auto client = bundle.client_acquire();
+        auto client = client_acquire_blocking(bundle);
+        auto client_id = client->id();
+        bundle.client_release(client);
+
+        auto compositor = bundle.compositor_acquire(nullptr);
+        ASSERT_EQ(client_id, compositor->id());
+        bundle.compositor_release(compositor);
+    }
+}
+
+TEST_F(SwitchingBundleTest, multimonitor_frame_sync)
+{
+    for (int nbuffers = mc::SwitchingBundle::min_buffers;
+         nbuffers <= mc::SwitchingBundle::max_buffers;
+         ++nbuffers)
+    {
+        mc::SwitchingBundle bundle(nbuffers, allocator, basic_properties);
+
+        auto client = client_acquire_blocking(bundle);
         auto client_id = client->id();
         bundle.client_release(client);
 
         for (int monitor = 0; monitor < 10; monitor++)
         {
-            frameno++;
-            auto compositor = bundle.compositor_acquire(frameno);
+            void const* user_id = reinterpret_cast<void const*>(monitor);
+            auto compositor = bundle.compositor_acquire(user_id);
             ASSERT_EQ(client_id, compositor->id());
             bundle.compositor_release(compositor);
         }
     }
 }
 
+TEST_F(SwitchingBundleTest, frames_in_order)
+{
+    int const nbuffers = 3;
+    mc::SwitchingBundle bundle(nbuffers, allocator, basic_properties);
+
+    mg::Buffer* clients[nbuffers];
+    for (auto& client : clients)
+    {
+        client = client_acquire_blocking(bundle);
+        bundle.client_release(client);
+    }
+
+    for (int frame = 0; frame < nbuffers; ++frame)
+    {
+        if (frame > 0)
+            ASSERT_NE(clients[frame-1]->id(), clients[frame]->id());
+
+        auto compositor = bundle.compositor_acquire(nullptr);
+        ASSERT_EQ(clients[frame]->id(), compositor->id());
+        bundle.compositor_release(compositor);
+    }
+}
+
 TEST_F(SwitchingBundleTest, compositor_acquire_never_blocks)
 {
-    for (int nbuffers = 2; nbuffers <= 5; nbuffers++)
+    for (int nbuffers = mc::SwitchingBundle::min_buffers;
+         nbuffers <= mc::SwitchingBundle::max_buffers;
+         ++nbuffers)
     {
         mc::SwitchingBundle bundle(nbuffers, allocator, basic_properties);
-        unsigned long frameno = 0;
         const int N = 100;
 
         bundle.force_requests_to_complete();
 
         std::shared_ptr<mg::Buffer> buf[N];
         for (int i = 0; i < N; i++)
-            buf[i] = bundle.compositor_acquire(++frameno);
+            buf[i] = bundle.compositor_acquire(nullptr);
 
         for (int i = 0; i < N; i++)
             bundle.compositor_release(buf[i]);
@@ -265,10 +338,11 @@ TEST_F(SwitchingBundleTest, compositor_acquire_never_blocks)
 
 TEST_F(SwitchingBundleTest, compositor_acquire_recycles_latest_ready_buffer)
 {
-    for (int nbuffers = 2; nbuffers <= 5; nbuffers++)
+    for (int nbuffers = mc::SwitchingBundle::min_buffers;
+         nbuffers <= mc::SwitchingBundle::max_buffers;
+         ++nbuffers)
     {
         mc::SwitchingBundle bundle(nbuffers, allocator, basic_properties);
-        unsigned long frameno = 1;
 
         mg::BufferID client_id;
 
@@ -276,39 +350,35 @@ TEST_F(SwitchingBundleTest, compositor_acquire_recycles_latest_ready_buffer)
         {
             if (i % 10 == 0)
             {
-                auto client = bundle.client_acquire();
+                auto client = client_acquire_blocking(bundle);
                 client_id = client->id();
                 bundle.client_release(client);
             }
 
             for (int monitor_id = 0; monitor_id < 10; monitor_id++)
             {
-                auto compositor = bundle.compositor_acquire(frameno);
+                void const* user_id =
+                    reinterpret_cast<void const*>(monitor_id);
+                auto compositor = bundle.compositor_acquire(user_id);
                 ASSERT_EQ(client_id, compositor->id());
                 bundle.compositor_release(compositor);
             }
-
-            frameno++;
         }
     }
 }
 
 TEST_F(SwitchingBundleTest, compositor_release_verifies_parameter)
 {
-    for (int nbuffers = 2; nbuffers <= 5; nbuffers++)
+    for (int nbuffers = 2;
+         nbuffers <= mc::SwitchingBundle::max_buffers;
+         ++nbuffers)
     {
         mc::SwitchingBundle bundle(nbuffers, allocator, basic_properties);
-        unsigned long frameno = 0;
 
-        auto client = bundle.client_acquire();
-
-        EXPECT_THROW(
-            bundle.compositor_release(client),
-            std::logic_error
-        );
+        auto client = client_acquire_blocking(bundle);
         bundle.client_release(client);
 
-        auto compositor1 = bundle.compositor_acquire(++frameno);
+        auto compositor1 = bundle.compositor_acquire(nullptr);
         bundle.compositor_release(compositor1);
         EXPECT_THROW(
             bundle.compositor_release(compositor1),
@@ -317,22 +387,52 @@ TEST_F(SwitchingBundleTest, compositor_release_verifies_parameter)
     }
 }
 
+/*
+ Regression test for LP#1270964
+ In the original bug, SwitchingBundle::last_consumed would be used without ever being set
+ in the compositor_acquire() call, thus its initial value of zero would wrongly be used
+ and lead to the wrong buffer being given to the compositor
+ */
+TEST_F(SwitchingBundleTest, compositor_client_interleaved)
+{
+    int nbuffers = 3;
+    mc::SwitchingBundle bundle(nbuffers, allocator, basic_properties);
+    mg::Buffer* client_buffer = nullptr;
+    std::shared_ptr<mg::Buffer> compositor_buffer = nullptr;
+
+    client_buffer = client_acquire_blocking(bundle);
+    mg::BufferID first_ready_buffer_id = client_buffer->id();
+    bundle.client_release(client_buffer);
+
+    client_buffer = client_acquire_blocking(bundle);
+
+    // in the original bug, compositor would be given the wrong buffer here
+    compositor_buffer = bundle.compositor_acquire(0);
+
+    ASSERT_EQ(first_ready_buffer_id, compositor_buffer->id());
+
+    // Clean up
+    bundle.client_release(client_buffer);
+    bundle.compositor_release(compositor_buffer);
+    compositor_buffer.reset();
+}
+
 TEST_F(SwitchingBundleTest, overlapping_compositors_get_different_frames)
 {
     // This test simulates bypass behaviour
-    for (int nbuffers = 2; nbuffers <= 5; nbuffers++)
+    for (int nbuffers = 2;
+         nbuffers <= mc::SwitchingBundle::max_buffers;
+         ++nbuffers)
     {
         mc::SwitchingBundle bundle(nbuffers, allocator, basic_properties);
-        unsigned long frameno = 1;
 
         std::shared_ptr<mg::Buffer> compositor[2];
 
-        bundle.client_release(bundle.client_acquire());
-        compositor[0] = bundle.compositor_acquire(frameno);
+        bundle.client_release(client_acquire_blocking(bundle));
+        compositor[0] = bundle.compositor_acquire(nullptr);
 
-        frameno++;
-        bundle.client_release(bundle.client_acquire());
-        compositor[1] = bundle.compositor_acquire(frameno);
+        bundle.client_release(client_acquire_blocking(bundle));
+        compositor[1] = bundle.compositor_acquire(nullptr);
 
         for (int i = 0; i < 20; i++)
         {
@@ -342,9 +442,8 @@ TEST_F(SwitchingBundleTest, overlapping_compositors_get_different_frames)
             // One of the compositors (the oldest one) gets a new buffer...
             int oldest = i & 1;
             bundle.compositor_release(compositor[oldest]);
-            bundle.client_release(bundle.client_acquire());
-            frameno++;
-            compositor[oldest] = bundle.compositor_acquire(frameno);
+            bundle.client_release(client_acquire_blocking(bundle));
+            compositor[oldest] = bundle.compositor_acquire(nullptr);
         }
 
         bundle.compositor_release(compositor[0]);
@@ -354,11 +453,13 @@ TEST_F(SwitchingBundleTest, overlapping_compositors_get_different_frames)
 
 TEST_F(SwitchingBundleTest, snapshot_acquire_basic)
 {
-    for (int nbuffers = 2; nbuffers <= 5; nbuffers++)
+    for (int nbuffers = mc::SwitchingBundle::min_buffers;
+         nbuffers <= mc::SwitchingBundle::max_buffers;
+         ++nbuffers)
     {
         mc::SwitchingBundle bundle(nbuffers, allocator, basic_properties);
 
-        auto compositor = bundle.compositor_acquire(1);
+        auto compositor = bundle.compositor_acquire(nullptr);
         auto snapshot = bundle.snapshot_acquire();
         EXPECT_EQ(snapshot->id(), compositor->id());
         bundle.compositor_release(compositor);
@@ -368,7 +469,9 @@ TEST_F(SwitchingBundleTest, snapshot_acquire_basic)
 
 TEST_F(SwitchingBundleTest, snapshot_acquire_never_blocks)
 {
-    for (int nbuffers = 2; nbuffers <= 5; nbuffers++)
+    for (int nbuffers = mc::SwitchingBundle::min_buffers;
+         nbuffers <= mc::SwitchingBundle::max_buffers;
+         ++nbuffers)
     {
         mc::SwitchingBundle bundle(nbuffers, allocator, basic_properties);
         const int N = 100;
@@ -384,29 +487,26 @@ TEST_F(SwitchingBundleTest, snapshot_acquire_never_blocks)
 
 TEST_F(SwitchingBundleTest, snapshot_release_verifies_parameter)
 {
-    for (int nbuffers = 2; nbuffers <= 5; nbuffers++)
+    for (int nbuffers = 2;
+         nbuffers <= mc::SwitchingBundle::max_buffers;
+         ++nbuffers)
     {
         mc::SwitchingBundle bundle(nbuffers, allocator, basic_properties);
 
-        auto compositor = bundle.compositor_acquire(1);
+        auto compositor = bundle.compositor_acquire(nullptr);
 
         EXPECT_THROW(
             bundle.snapshot_release(compositor),
             std::logic_error
         );
 
-        auto client = bundle.client_acquire();
+        auto client = client_acquire_blocking(bundle);
         auto snapshot = bundle.snapshot_acquire();
 
         EXPECT_EQ(compositor->id(), snapshot->id());
 
         EXPECT_NE(client->id(), snapshot->id());
 
-        EXPECT_THROW(
-            bundle.snapshot_release(client),
-            std::logic_error
-        );
-
         bundle.snapshot_release(snapshot);
 
         EXPECT_THROW(
@@ -421,10 +521,9 @@ namespace
     void compositor_thread(mc::SwitchingBundle &bundle,
                            std::atomic<bool> &done)
     {
-        unsigned long frameno = 0;
         while (!done)
         {
-            bundle.compositor_release(bundle.compositor_acquire(++frameno));
+            bundle.compositor_release(bundle.compositor_acquire(nullptr));
             std::this_thread::yield();
         }
     }
@@ -443,7 +542,7 @@ namespace
     {
         for (int i = 0; i < nframes; i++)
         {
-            bundle.client_release(bundle.client_acquire());
+            bundle.client_release(client_acquire_blocking(bundle));
             std::this_thread::yield();
         }
     }
@@ -454,12 +553,12 @@ namespace
         {
             bundle.allow_framedropping(false);
             for (int j = 0; j < 5; j++)
-                bundle.client_release(bundle.client_acquire());
+                bundle.client_release(client_acquire_blocking(bundle));
             std::this_thread::yield();
 
             bundle.allow_framedropping(true);
             for (int j = 0; j < 5; j++)
-                bundle.client_release(bundle.client_acquire());
+                bundle.client_release(client_acquire_blocking(bundle));
             std::this_thread::yield();
         }
     }
@@ -467,7 +566,9 @@ namespace
 
 TEST_F(SwitchingBundleTest, stress)
 {
-    for (int nbuffers = 2; nbuffers <= 5; nbuffers++)
+    for (int nbuffers = 2;
+         nbuffers <= mc::SwitchingBundle::max_buffers;
+         ++nbuffers)
     {
         mc::SwitchingBundle bundle(nbuffers, allocator, basic_properties);
 
@@ -511,10 +612,11 @@ TEST_F(SwitchingBundleTest, DISABLED_synchronous_clients_only_get_two_real_buffe
      * unique ones while it makes sense to do so. Buffers are big things and
      * should be allocated sparingly...
      */
-    for (int nbuffers = 2; nbuffers <= 5; nbuffers++)
+    for (int nbuffers = mc::SwitchingBundle::min_buffers;
+         nbuffers <= mc::SwitchingBundle::max_buffers;
+         ++nbuffers)
     {
         mc::SwitchingBundle bundle(nbuffers, allocator, basic_properties);
-        unsigned long frameno = 0;
 
         bundle.allow_framedropping(false);
 
@@ -525,9 +627,7 @@ TEST_F(SwitchingBundleTest, DISABLED_synchronous_clients_only_get_two_real_buffe
 
         for (int frame = 0; frame < nframes; frame++)
         {
-            frameno++;
-
-            auto compositor = bundle.compositor_acquire(frameno);
+            auto compositor = bundle.compositor_acquire(nullptr);
             auto compositor_id = compositor->id();
             bundle.compositor_release(compositor);
 
@@ -544,26 +644,26 @@ TEST_F(SwitchingBundleTest, DISABLED_synchronous_clients_only_get_two_real_buffe
 
 TEST_F(SwitchingBundleTest, bypass_clients_get_more_than_two_buffers)
 {
-    for (int nbuffers = 3; nbuffers <= 5; nbuffers++)
+    for (int nbuffers = 3;
+         nbuffers <= mc::SwitchingBundle::max_buffers;
+         ++nbuffers)
     {
         mc::SwitchingBundle bundle(nbuffers, allocator, basic_properties);
-        unsigned long frameno = 1;
 
         std::shared_ptr<mg::Buffer> compositor[2];
 
-        bundle.client_release(bundle.client_acquire());
-        compositor[0] = bundle.compositor_acquire(frameno);
+        bundle.client_release(client_acquire_blocking(bundle));
+        compositor[0] = bundle.compositor_acquire(nullptr);
 
-        frameno++;
-        bundle.client_release(bundle.client_acquire());
-        compositor[1] = bundle.compositor_acquire(frameno);
+        bundle.client_release(client_acquire_blocking(bundle));
+        compositor[1] = bundle.compositor_acquire(nullptr);
 
         for (int i = 0; i < 20; i++)
         {
             // Two compositors acquired, and they're always different...
             ASSERT_NE(compositor[0]->id(), compositor[1]->id());
 
-            auto client = bundle.client_acquire();
+            auto client = client_acquire_blocking(bundle);
             ASSERT_NE(compositor[0]->id(), client->id());
             ASSERT_NE(compositor[1]->id(), client->id());
             bundle.client_release(client);
@@ -572,8 +672,7 @@ TEST_F(SwitchingBundleTest, bypass_clients_get_more_than_two_buffers)
             int oldest = i & 1;
             bundle.compositor_release(compositor[oldest]);
 
-            frameno++;
-            compositor[oldest] = bundle.compositor_acquire(frameno);
+            compositor[oldest] = bundle.compositor_acquire(nullptr);
         }
 
         bundle.compositor_release(compositor[0]);
@@ -581,35 +680,36 @@ TEST_F(SwitchingBundleTest, bypass_clients_get_more_than_two_buffers)
     }
 }
 
-TEST_F(SwitchingBundleTest, framedropping_clients_get_all_but_one_buffers)
+TEST_F(SwitchingBundleTest, framedropping_clients_get_all_buffers)
 {
-    const int max_nbuffers = 5;
-    for (int nbuffers = 2; nbuffers <= max_nbuffers; nbuffers++)
+    for (int nbuffers = 2;
+         nbuffers <= mc::SwitchingBundle::max_buffers;
+         ++nbuffers)
     {
         mc::SwitchingBundle bundle(nbuffers, allocator, basic_properties);
 
         bundle.allow_framedropping(true);
 
         const int nframes = 100;
-        mg::BufferID expect[max_nbuffers];
-        std::shared_ptr<mg::Buffer> buf[max_nbuffers];
+        mg::BufferID expect[mc::SwitchingBundle::max_buffers];
+        mg::Buffer* buf[mc::SwitchingBundle::max_buffers];
 
-        for (int b = 0; b < nbuffers - 1; b++)
+        for (int b = 0; b < nbuffers; b++)
         {
-            buf[b] = bundle.client_acquire();
+            buf[b] = client_acquire_blocking(bundle);
             expect[b] = buf[b]->id();
 
             for (int p = 0; p < b; p++)
                 ASSERT_NE(expect[p], expect[b]);
         }
 
-        for (int b = 0; b < nbuffers - 1; b++)
+        for (int b = 0; b < nbuffers; b++)
             bundle.client_release(buf[b]);
 
         for (int frame = 0; frame < nframes; frame++)
         {
-            auto client = bundle.client_acquire();
-            ASSERT_EQ(expect[frame % (nbuffers - 1)], client->id());
+            auto client = client_acquire_blocking(bundle);
+            ASSERT_EQ(expect[frame % nbuffers], client->id());
             bundle.client_release(client);
         }
     }
@@ -617,7 +717,9 @@ TEST_F(SwitchingBundleTest, framedropping_clients_get_all_but_one_buffers)
 
 TEST_F(SwitchingBundleTest, waiting_clients_unblock_on_shutdown)
 {
-    for (int nbuffers = 2; nbuffers <= 5; nbuffers++)
+    for (int nbuffers = 2;
+         nbuffers <= mc::SwitchingBundle::max_buffers;
+         ++nbuffers)
     {
         mc::SwitchingBundle bundle(nbuffers, allocator, basic_properties);
 
@@ -638,7 +740,9 @@ TEST_F(SwitchingBundleTest, waiting_clients_unblock_on_shutdown)
 
 TEST_F(SwitchingBundleTest, waiting_clients_unblock_on_vt_switch_not_permanent)
 {   // Regression test for LP: #1207226
-    for (int nbuffers = 2; nbuffers <= 5; nbuffers++)
+    for (int nbuffers = 2;
+         nbuffers <= mc::SwitchingBundle::max_buffers;
+         ++nbuffers)
     {
         mc::SwitchingBundle bundle(nbuffers, allocator, basic_properties);
 
@@ -670,7 +774,7 @@ TEST_F(SwitchingBundleTest, client_framerate_matches_compositor)
             {
                 std::this_thread::sleep_for(std::chrono::milliseconds(10));
 
-                auto buf = bundle.compositor_acquire(frame);
+                auto buf = bundle.compositor_acquire(this);
                 bundle.compositor_release(buf);
 
                 if (frame == compose_frames)
@@ -683,11 +787,11 @@ TEST_F(SwitchingBundleTest, client_framerate_matches_compositor)
             }
         });
 
-        bundle.client_release(bundle.client_acquire());
+        bundle.client_release(client_acquire_blocking(bundle));
 
         while (!done.load())
         {
-            bundle.client_release(bundle.client_acquire());
+            bundle.client_release(client_acquire_blocking(bundle));
             client_frames++;
         }
 
@@ -699,3 +803,144 @@ TEST_F(SwitchingBundleTest, client_framerate_matches_compositor)
     }
 }
 
+TEST_F(SwitchingBundleTest, slow_client_framerate_matches_compositor)
+{  // Regression test LP: #1241369 / LP: #1241371
+    for (int nbuffers = 2; nbuffers <= 3; nbuffers++)
+    {
+        mc::SwitchingBundle bundle(nbuffers, allocator, basic_properties);
+        unsigned long client_frames = 0;
+        const unsigned long compose_frames = 100;
+        const auto frame_time = std::chrono::milliseconds(16);
+
+        bundle.allow_framedropping(false);
+
+        std::atomic<bool> done(false);
+        std::mutex sync;
+
+        std::thread monitor1([&]
+        {
+            for (unsigned long frame = 0; frame != compose_frames+3; frame++)
+            {
+                std::this_thread::sleep_for(frame_time);
+                sync.lock();
+                auto buf = bundle.compositor_acquire(this);
+                bundle.compositor_release(buf);
+                sync.unlock();
+
+                if (frame == compose_frames)
+                {
+                    // Tell the "client" to stop after compose_frames, but
+                    // don't stop rendering immediately to avoid blocking
+                    // if we rendered any twice
+                    done.store(true);
+                }
+            }
+        });
+
+        bundle.client_release(client_acquire_blocking(bundle));
+
+        while (!done.load())
+        {
+            sync.lock();
+            sync.unlock();
+            auto buf = client_acquire_blocking(bundle);
+            std::this_thread::sleep_for(frame_time);
+            bundle.client_release(buf);
+            client_frames++;
+        }
+
+        monitor1.join();
+
+        // Roughly compose_frames == client_frames within 20%
+        ASSERT_GT(client_frames, compose_frames * 0.8f);
+        ASSERT_LT(client_frames, compose_frames * 1.2f);
+    }
+}
+
+TEST_F(SwitchingBundleTest, resize_affects_client_acquires_immediately)
+{
+    for (int nbuffers = mc::SwitchingBundle::min_buffers;
+         nbuffers <= mc::SwitchingBundle::max_buffers;
+         ++nbuffers)
+    {
+        mc::SwitchingBundle bundle(nbuffers, allocator, basic_properties);
+
+        for (int width = 1; width < 100; ++width)
+        {
+            const geom::Size expect_size{width, width * 2};
+
+            for (int subframe = 0; subframe < 3; ++subframe)
+            {
+                bundle.resize(expect_size);
+                auto client = client_acquire_blocking(bundle);
+                ASSERT_EQ(expect_size, client->size());
+                bundle.client_release(client);
+
+                auto compositor = bundle.compositor_acquire(nullptr);
+                ASSERT_EQ(expect_size, compositor->size());
+                bundle.compositor_release(compositor);
+            }
+        }
+    }
+}
+
+TEST_F(SwitchingBundleTest, compositor_acquires_resized_frames)
+{
+    for (int nbuffers = mc::SwitchingBundle::min_buffers;
+         nbuffers <= mc::SwitchingBundle::max_buffers;
+         ++nbuffers)
+    {
+        mc::SwitchingBundle bundle(nbuffers, allocator, basic_properties);
+        mg::BufferID history[5];
+
+        const int width0 = 123;
+        const int height0 = 456;
+        const int dx = 2;
+        const int dy = -3;
+        int width = width0;
+        int height = height0;
+
+        for (int produce = 0; produce < nbuffers; ++produce)
+        {
+            geom::Size new_size{width, height};
+            width += dx;
+            height += dy;
+
+            bundle.resize(new_size);
+            auto client = client_acquire_blocking(bundle);
+            history[produce] = client->id();
+            ASSERT_EQ(new_size, client->size());
+            bundle.client_release(client);
+        }
+
+        width = width0;
+        height = height0;
+
+        for (int consume = 0; consume < nbuffers; ++consume)
+        {
+            geom::Size expect_size{width, height};
+            width += dx;
+            height += dy;
+
+            auto compositor = bundle.compositor_acquire(nullptr);
+
+            // Verify the compositor gets resized buffers, eventually
+            ASSERT_EQ(expect_size, compositor->size());
+
+            // Verify the compositor gets buffers with *contents*, ie. that
+            // they have not been resized prematurely and are empty.
+            ASSERT_EQ(history[consume], compositor->id());
+
+            bundle.compositor_release(compositor);
+        }
+
+        // Verify the final buffer size sticks
+        const geom::Size final_size{width - dx, height - dy};
+        for (int unchanging = 0; unchanging < 100; ++unchanging)
+        {
+            auto compositor = bundle.compositor_acquire(nullptr);
+            ASSERT_EQ(final_size, compositor->size());
+            bundle.compositor_release(compositor);
+        }
+    }
+}
