@@ -17,7 +17,7 @@
  */
 
 #include "mir/frontend/connector.h"
-#include "mir/frontend/resource_cache.h"
+#include "src/server/frontend/resource_cache.h"
 
 #include "mir_protobuf.pb.h"
 
