@@ -1,5 +1,5 @@
 /*
- * Copyright © 2012 Canonical Ltd.
+ * Copyright © 2012-2014 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 3 as
@@ -16,17 +16,16 @@
  * Authored by: Alexandros Frantzis <alexandros.frantzis@canonical.com>
  */
 
-#include "mir/surfaces/buffer_stream.h"
-#include "mir/graphics/graphic_buffer_allocator.h"
-#include "mir/frontend/session_mediator_report.h"
-#include "mir/frontend/session_mediator.h"
-#include "mir/frontend/resource_cache.h"
-#include "mir/shell/application_session.h"
+#include "mir/compositor/buffer_stream.h"
+#include "src/server/frontend/session_mediator.h"
+#include "src/server/report/null_report_factory.h"
+#include "src/server/frontend/resource_cache.h"
+#include "src/server/scene/application_session.h"
 #include "mir/graphics/display.h"
 #include "mir/graphics/display_configuration.h"
 #include "mir/graphics/platform.h"
 #include "mir/graphics/platform_ipc_package.h"
-#include "mir/surfaces/surface.h"
+#include "src/server/scene/basic_surface.h"
 #include "mir_test_doubles/mock_display.h"
 #include "mir_test_doubles/mock_display_changer.h"
 #include "mir_test_doubles/null_display.h"
@@ -37,13 +36,15 @@
 #include "mir_test_doubles/mock_frontend_surface.h"
 #include "mir_test_doubles/mock_buffer.h"
 #include "mir_test_doubles/stub_session.h"
-#include "mir_test_doubles/stub_surface_builder.h"
 #include "mir_test_doubles/stub_display_configuration.h"
+#include "mir_test_doubles/stub_buffer_allocator.h"
+#include "mir_test_doubles/null_screencast.h"
 #include "mir_test/display_config_matchers.h"
 #include "mir_test/fake_shared.h"
 #include "mir/frontend/event_sink.h"
 #include "mir/shell/surface.h"
 
+#include "gmock_set_arg.h"
 #include <gtest/gtest.h>
 #include <gmock/gmock.h>
 
@@ -52,12 +53,13 @@
 namespace mf = mir::frontend;
 namespace mg = mir::graphics;
 namespace mc = mir::compositor;
-namespace ms = mir::surfaces;
+namespace ms = mir::scene;
 namespace geom = mir::geometry;
 namespace mp = mir::protobuf;
 namespace msh = mir::shell;
 namespace mt = mir::test;
 namespace mtd = mt::doubles;
+namespace mr = mir::report;
 
 namespace
 {
@@ -82,7 +84,7 @@ struct MockConfig : public mg::DisplayConfiguration
 {
     MOCK_CONST_METHOD1(for_each_card, void(std::function<void(mg::DisplayConfigurationCard const&)>));
     MOCK_CONST_METHOD1(for_each_output, void(std::function<void(mg::DisplayConfigurationOutput const&)>));
-    MOCK_METHOD5(configure_output, void(mg::DisplayConfigurationOutputId, bool, geom::Point, size_t, MirPowerMode));
+    MOCK_METHOD1(for_each_output, void(std::function<void(mg::UserDisplayConfigurationOutput&)>));
 };
 
 }
@@ -98,11 +100,12 @@ public:
 
         mock_surface = std::make_shared<mtd::MockFrontendSurface>();
         mock_surfaces[mf::SurfaceId{1}] = mock_surface;
-        mock_buffer = std::make_shared<NiceMock<mtd::MockBuffer>>(geom::Size(), geom::Stride(), geom::PixelFormat());
+        mock_buffer = std::make_shared<NiceMock<mtd::MockBuffer>>(geom::Size(), geom::Stride(), MirPixelFormat());
 
         EXPECT_CALL(*mock_surface, size()).Times(AnyNumber()).WillRepeatedly(Return(geom::Size()));
-        EXPECT_CALL(*mock_surface, pixel_format()).Times(AnyNumber()).WillRepeatedly(Return(geom::PixelFormat()));
-        EXPECT_CALL(*mock_surface, advance_client_buffer()).Times(AnyNumber()).WillRepeatedly(Return(mock_buffer));
+        EXPECT_CALL(*mock_surface, pixel_format()).Times(AnyNumber()).WillRepeatedly(Return(MirPixelFormat()));
+        EXPECT_CALL(*mock_surface, swap_buffers(_, _)).Times(AnyNumber())
+            .WillRepeatedly(InvokeArgument<1>(mock_buffer.get()));
 
         EXPECT_CALL(*mock_surface, supports_input()).Times(AnyNumber()).WillRepeatedly(Return(true));
         EXPECT_CALL(*mock_surface, client_input_fd()).Times(AnyNumber()).WillRepeatedly(Return(testing_client_input_fd));
@@ -121,8 +124,9 @@ public:
             mock_surfaces[id] = std::make_shared<mtd::MockFrontendSurface>();
 
             EXPECT_CALL(*mock_surfaces[id], size()).Times(AnyNumber()).WillRepeatedly(Return(geom::Size()));
-            EXPECT_CALL(*mock_surfaces[id], pixel_format()).Times(AnyNumber()).WillRepeatedly(Return(geom::PixelFormat()));
-            EXPECT_CALL(*mock_surfaces[id], advance_client_buffer()).Times(AnyNumber()).WillRepeatedly(Return(mock_buffer));
+            EXPECT_CALL(*mock_surfaces[id], pixel_format()).Times(AnyNumber()).WillRepeatedly(Return(MirPixelFormat()));
+            EXPECT_CALL(*mock_surfaces[id], swap_buffers(_, _)).Times(AnyNumber())
+                .WillRepeatedly(InvokeArgument<1>(mock_buffer.get()));
 
             EXPECT_CALL(*mock_surfaces[id], supports_input()).Times(AnyNumber()).WillRepeatedly(Return(true));
             EXPECT_CALL(*mock_surfaces[id], client_input_fd()).Times(AnyNumber()).WillRepeatedly(Return(testing_client_input_fd));
@@ -136,7 +140,6 @@ public:
         mock_surfaces.erase(surface);
     }
 
-    mtd::StubSurfaceBuilder surface_builder;
     std::shared_ptr<mtd::MockFrontendSurface> mock_surface;
     std::map<mf::SurfaceId, std::shared_ptr<mtd::MockFrontendSurface>> mock_surfaces;
     std::shared_ptr<mtd::MockBuffer> mock_buffer;
@@ -146,22 +149,16 @@ public:
 
 int const StubbedSession::testing_client_input_fd{11};
 
-class MockGraphicBufferAllocator : public mg::GraphicBufferAllocator
+class MockGraphicBufferAllocator : public mtd::StubBufferAllocator
 {
 public:
     MockGraphicBufferAllocator()
     {
         ON_CALL(*this, supported_pixel_formats())
-            .WillByDefault(testing::Return(std::vector<geom::PixelFormat>()));
+            .WillByDefault(testing::Return(std::vector<MirPixelFormat>()));
     }
 
-    std::shared_ptr<mg::Buffer> alloc_buffer(mg::BufferProperties const&)
-    {
-        return std::shared_ptr<mg::Buffer>();
-    }
-
-    MOCK_METHOD0(supported_pixel_formats, std::vector<geom::PixelFormat>());
-    ~MockGraphicBufferAllocator() noexcept {}
+    MOCK_METHOD0(supported_pixel_formats, std::vector<MirPixelFormat>());
 };
 
 class MockPlatform : public mg::Platform
@@ -172,20 +169,31 @@ class MockPlatform : public mg::Platform
         using namespace testing;
         ON_CALL(*this, create_buffer_allocator(_))
             .WillByDefault(Return(std::shared_ptr<mg::GraphicBufferAllocator>()));
-        ON_CALL(*this, create_display(_))
+        ON_CALL(*this, create_display(_,_))
             .WillByDefault(Return(std::make_shared<mtd::NullDisplay>()));
         ON_CALL(*this, get_ipc_package())
             .WillByDefault(Return(std::make_shared<mg::PlatformIPCPackage>()));
     }
 
     MOCK_METHOD1(create_buffer_allocator, std::shared_ptr<mg::GraphicBufferAllocator>(std::shared_ptr<mg::BufferInitializer> const&));
-    MOCK_METHOD1(create_display,
+    MOCK_METHOD2(create_display,
                  std::shared_ptr<mg::Display>(
-                     std::shared_ptr<mg::DisplayConfigurationPolicy> const&));
+                     std::shared_ptr<mg::DisplayConfigurationPolicy> const&,
+                     std::shared_ptr<mg::GLConfig> const&));
     MOCK_METHOD0(get_ipc_package, std::shared_ptr<mg::PlatformIPCPackage>());
     MOCK_METHOD0(create_internal_client, std::shared_ptr<mg::InternalClient>());
-    MOCK_CONST_METHOD2(fill_ipc_package, void(std::shared_ptr<mg::BufferIPCPacker> const&,
-                                              std::shared_ptr<mg::Buffer> const&));
+    MOCK_CONST_METHOD2(fill_ipc_package, void(mg::BufferIPCPacker*, mg::Buffer const*));
+    MOCK_CONST_METHOD0(egl_native_display, EGLNativeDisplayType());
+};
+
+struct StubScreencast : mtd::NullScreencast
+{
+    std::shared_ptr<mg::Buffer> capture(mf::ScreencastSessionId)
+    {
+        return mt::fake_shared(stub_buffer);
+    }
+
+    mtd::StubBuffer stub_buffer;
 };
 
 struct SessionMediatorTest : public ::testing::Test
@@ -194,19 +202,20 @@ struct SessionMediatorTest : public ::testing::Test
         : shell{std::make_shared<testing::NiceMock<mtd::MockShell>>()},
           graphics_platform{std::make_shared<testing::NiceMock<MockPlatform>>()},
           graphics_changer{std::make_shared<mtd::NullDisplayChanger>()},
-          buffer_allocator{std::make_shared<testing::NiceMock<MockGraphicBufferAllocator>>()},
-          report{std::make_shared<mf::NullSessionMediatorReport>()},
+          surface_pixel_formats{mir_pixel_format_argb_8888, mir_pixel_format_xrgb_8888},
+          report{mr::null_session_mediator_report()},
           resource_cache{std::make_shared<mf::ResourceCache>()},
-          mediator{shell, graphics_platform, graphics_changer,
-                   buffer_allocator, report, 
+          stub_screencast{std::make_shared<StubScreencast>()},
+          mediator{__LINE__, shell, graphics_platform, graphics_changer,
+                   surface_pixel_formats, report,
                    std::make_shared<mtd::NullEventSink>(),
-                   resource_cache},
+                   resource_cache, stub_screencast},
           stubbed_session{std::make_shared<StubbedSession>()},
           null_callback{google::protobuf::NewPermanentCallback(google::protobuf::DoNothing)}
     {
         using namespace ::testing;
 
-        ON_CALL(*shell, open_session(_, _)).WillByDefault(Return(stubbed_session));
+        ON_CALL(*shell, open_session(_, _, _)).WillByDefault(Return(stubbed_session));
         ON_CALL(*shell, create_surface_for(_, _))
             .WillByDefault(WithArg<1>(Invoke(stubbed_session.get(), &StubbedSession::create_surface)));
     }
@@ -214,9 +223,10 @@ struct SessionMediatorTest : public ::testing::Test
     std::shared_ptr<testing::NiceMock<mtd::MockShell>> const shell;
     std::shared_ptr<MockPlatform> const graphics_platform;
     std::shared_ptr<mf::DisplayChanger> const graphics_changer;
-    std::shared_ptr<testing::NiceMock<MockGraphicBufferAllocator>> const buffer_allocator;
+    std::vector<MirPixelFormat> const surface_pixel_formats;
     std::shared_ptr<mf::SessionMediatorReport> const report;
     std::shared_ptr<mf::ResourceCache> const resource_cache;
+    std::shared_ptr<StubScreencast> const stub_screencast;
     mf::SessionMediator mediator;
     std::shared_ptr<StubbedSession> const stubbed_session;
 
@@ -360,10 +370,10 @@ TEST_F(SessionMediatorTest, connect_packs_display_configuration)
         .Times(1)
         .WillOnce(Return(mt::fake_shared(config)));
     mf::SessionMediator mediator(
-        shell, graphics_platform, mock_display,
-        buffer_allocator, report, 
+        __LINE__, shell, graphics_platform, mock_display,
+        surface_pixel_formats, report,
         std::make_shared<mtd::NullEventSink>(),
-        resource_cache);
+        resource_cache, std::make_shared<mtd::NullScreencast>());
 
     mp::ConnectParameters connect_parameters;
     mp::Connection connection;
@@ -442,8 +452,7 @@ TEST_F(SessionMediatorTest, session_only_sends_needed_buffers)
         mp::SurfaceId buffer_request;
         mp::Buffer buffer_response[3];
 
-        std::shared_ptr<mg::Buffer> tmp_buffer = stubbed_session->mock_buffer;
-        EXPECT_CALL(*graphics_platform, fill_ipc_package(_, tmp_buffer))
+        EXPECT_CALL(*graphics_platform, fill_ipc_package(_, stubbed_session->mock_buffer.get()))
             .Times(2);
 
         mp::SurfaceParameters surface_request;
@@ -467,6 +476,8 @@ TEST_F(SessionMediatorTest, session_with_multiple_surfaces_only_sends_needed_buf
     mediator.connect(nullptr, &connect_parameters, &connection, null_callback.get());
 
     {
+        // AFAICS these values are stubs to set up the test condition,
+        // the exact calls here are not a *requirement* on SessionMediator
         EXPECT_CALL(*stubbed_session->mock_buffer, id())
             .WillOnce(Return(mg::BufferID{4}))
             .WillOnce(Return(mg::BufferID{4}))
@@ -489,8 +500,7 @@ TEST_F(SessionMediatorTest, session_with_multiple_surfaces_only_sends_needed_buf
         mp::SurfaceId buffer_request[2];
         mp::Buffer buffer_response[6];
 
-        std::shared_ptr<mg::Buffer> tmp_buffer = stubbed_session->mock_buffer;
-        EXPECT_CALL(*graphics_platform, fill_ipc_package(_, tmp_buffer))
+        EXPECT_CALL(*graphics_platform, fill_ipc_package(_, stubbed_session->mock_buffer.get()))
             .Times(4);
 
         mp::SurfaceParameters surface_request;
@@ -509,48 +519,11 @@ TEST_F(SessionMediatorTest, session_with_multiple_surfaces_only_sends_needed_buf
     mediator.disconnect(nullptr, nullptr, nullptr, null_callback.get());
 }
 
-
-TEST_F(SessionMediatorTest, buffer_resource_held_over_call)
+TEST_F(SessionMediatorTest, buffer_resource_for_surface_unaffected_by_other_surfaces)
 {
     using namespace testing;
 
-    auto stub_buffer1 = std::make_shared<mtd::StubBuffer>();
-    auto stub_buffer2 = std::make_shared<mtd::StubBuffer>();
-
-    mp::ConnectParameters connect_parameters;
-    mp::Connection connection;
-
-    mediator.connect(nullptr, &connect_parameters, &connection, null_callback.get());
-    mp::Surface surface_response;
-    mp::SurfaceId buffer_request;
-    mp::Buffer buffer_response;
-    mp::SurfaceParameters surface_request;
-
-    EXPECT_CALL(*stubbed_session->mock_surface, advance_client_buffer())
-        .Times(2)
-        .WillOnce(Return(stub_buffer1))
-        .WillOnce(Return(stub_buffer2));
- 
-    auto refcount = stub_buffer1.use_count();
-    mediator.create_surface(nullptr, &surface_request, &surface_response, null_callback.get());
-    EXPECT_EQ(refcount+1, stub_buffer1.use_count());
-
-    buffer_request = surface_response.id();
-
-    auto refcount2 = stub_buffer2.use_count();
-    mediator.next_buffer(nullptr, &buffer_request, &buffer_response, null_callback.get());
-    EXPECT_EQ(refcount, stub_buffer1.use_count());
-    EXPECT_EQ(refcount2+1, stub_buffer2.use_count());
-
-    mediator.disconnect(nullptr, nullptr, nullptr, null_callback.get());
-}
-
-TEST_F(SessionMediatorTest, buffer_resource_for_surface_held_over_operations_on_other_surfaces)
-{
-    using namespace testing;
-
-    auto stub_buffer1 = std::make_shared<mtd::StubBuffer>();
-
+    mtd::StubBuffer buffer;
     mp::ConnectParameters connect_parameters;
     mp::Connection connection;
 
@@ -563,23 +536,30 @@ TEST_F(SessionMediatorTest, buffer_resource_for_surface_held_over_operations_on_
      * the pre-created stubbed_session->mock_surface. Further create_surface()
      * invocations create new surfaces in stubbed_session->mock_surfaces[].
      */
-    EXPECT_CALL(*stubbed_session->mock_surface, advance_client_buffer())
-        .WillOnce(Return(stub_buffer1));
+    EXPECT_CALL(*stubbed_session->mock_surface, swap_buffers(_, _))
+        .WillOnce(InvokeArgument<1>(&buffer));
 
     mediator.create_surface(nullptr, &surface_request, &surface_response, null_callback.get());
-    auto refcount = stub_buffer1.use_count();
+    mp::SurfaceId our_surface{surface_response.id()};
 
-    /* Creating a new surface should not affect other surfaces' buffers */
+    Mock::VerifyAndClearExpectations(stubbed_session->mock_surface.get());
+
+    /* Creating a new surface should not affect our surfaces' buffers */
+    EXPECT_CALL(*stubbed_session->mock_surface, swap_buffers(_, _)).Times(0);
     mediator.create_surface(nullptr, &surface_request, &surface_response, null_callback.get());
-    EXPECT_EQ(refcount, stub_buffer1.use_count());
 
-    mp::SurfaceId buffer_request{surface_response.id()};
+    mp::SurfaceId new_surface{surface_response.id()};
     mp::Buffer buffer_response;
 
-    /* Getting the next buffer of a surface should not affect other surfaces' buffers */
-    mediator.next_buffer(nullptr, &buffer_request, &buffer_response, null_callback.get());
-    EXPECT_EQ(refcount, stub_buffer1.use_count());
+    /* Getting the next buffer of new surface should not affect our surfaces' buffers */
+    mediator.next_buffer(nullptr, &new_surface, &buffer_response, null_callback.get());
 
+    Mock::VerifyAndClearExpectations(stubbed_session->mock_surface.get());
+
+    /* Getting the next buffer of our surface should post the original */
+    EXPECT_CALL(*stubbed_session->mock_surface, swap_buffers(Eq(&buffer), _)).Times(1);
+
+    mediator.next_buffer(nullptr, &our_surface, &buffer_response, null_callback.get());
     mediator.disconnect(nullptr, nullptr, nullptr, null_callback.get());
 }
 
@@ -591,7 +571,9 @@ TEST_F(SessionMediatorTest, display_config_request)
 
     bool used0 = false, used1 = true;
     geom::Point pt0{44,22}, pt1{3,2};
-    size_t mode_index0 = 1, mode_index1 = 3; 
+    size_t mode_index0 = 1, mode_index1 = 3;
+    MirPixelFormat format0{mir_pixel_format_invalid};
+    MirPixelFormat format1{mir_pixel_format_argb_8888};
     mg::DisplayConfigurationOutputId id0{6}, id1{3};
 
     NiceMock<MockConfig> mock_display_config;
@@ -601,35 +583,35 @@ TEST_F(SessionMediatorTest, display_config_request)
     Sequence seq;
     EXPECT_CALL(*mock_display_selector, active_configuration())
         .InSequence(seq)
-        .WillOnce(Return(mt::fake_shared(mock_display_config))); 
+        .WillOnce(Return(mt::fake_shared(mock_display_config)));
     EXPECT_CALL(*mock_display_selector, active_configuration())
         .InSequence(seq)
-        .WillOnce(Return(mt::fake_shared(mock_display_config))); 
-    EXPECT_CALL(mock_display_config, configure_output(id0, used0, pt0, mode_index0,  mir_power_mode_on))
-        .InSequence(seq);
-    EXPECT_CALL(mock_display_config, configure_output(id1, used1, pt1, mode_index1, mir_power_mode_off))
-        .InSequence(seq);
+        .WillOnce(Return(mt::fake_shared(mock_display_config)));
     EXPECT_CALL(*mock_display_selector, configure(_,_))
         .InSequence(seq);
     EXPECT_CALL(*mock_display_selector, active_configuration())
         .InSequence(seq)
         .WillOnce(Return(mt::fake_shared(stub_display_config)));
- 
+
     mf::SessionMediator session_mediator{
-            shell, graphics_platform, mock_display_selector,
-            buffer_allocator, report, std::make_shared<mtd::NullEventSink>(), resource_cache};
+        __LINE__, shell, graphics_platform, mock_display_selector,
+        surface_pixel_formats, report,
+        std::make_shared<mtd::NullEventSink>(), resource_cache,
+        std::make_shared<mtd::NullScreencast>()};
 
     session_mediator.connect(nullptr, &connect_parameters, &connection, null_callback.get());
 
     mp::DisplayConfiguration configuration_response;
-    mp::DisplayConfiguration configuration; 
+    mp::DisplayConfiguration configuration;
     auto disp0 = configuration.add_display_output();
     disp0->set_output_id(id0.as_value());
     disp0->set_used(used0);
     disp0->set_position_x(pt0.x.as_uint32_t());
     disp0->set_position_y(pt0.y.as_uint32_t());
     disp0->set_current_mode(mode_index0);
+    disp0->set_current_format(format0);
     disp0->set_power_mode(static_cast<uint32_t>(mir_power_mode_on));
+    disp0->set_orientation(mir_orientation_left);
 
     auto disp1 = configuration.add_display_output();
     disp1->set_output_id(id1.as_value());
@@ -637,7 +619,9 @@ TEST_F(SessionMediatorTest, display_config_request)
     disp1->set_position_x(pt1.x.as_uint32_t());
     disp1->set_position_y(pt1.y.as_uint32_t());
     disp1->set_current_mode(mode_index1);
+    disp1->set_current_format(format1);
     disp1->set_power_mode(static_cast<uint32_t>(mir_power_mode_off));
+    disp1->set_orientation(mir_orientation_inverted);
 
     session_mediator.configure_display(nullptr, &configuration,
                                        &configuration_response, null_callback.get());
@@ -646,3 +630,38 @@ TEST_F(SessionMediatorTest, display_config_request)
 
     session_mediator.disconnect(nullptr, nullptr, nullptr, null_callback.get());
 }
+
+TEST_F(SessionMediatorTest, fully_packs_buffer_for_create_screencast)
+{
+    using namespace testing;
+
+    mp::ScreencastParameters screencast_parameters;
+    mp::Screencast screencast;
+    auto const& stub_buffer = stub_screencast->stub_buffer;
+
+    EXPECT_CALL(*graphics_platform, fill_ipc_package(_, &stub_buffer));
+
+    mediator.create_screencast(nullptr, &screencast_parameters,
+                               &screencast, null_callback.get());
+
+    EXPECT_EQ(stub_buffer.id().as_uint32_t(),
+              screencast.buffer().buffer_id());
+}
+
+TEST_F(SessionMediatorTest, partially_packs_buffer_for_screencast_buffer)
+{
+    using namespace testing;
+
+    mp::ScreencastId screencast_id;
+    mp::Buffer protobuf_buffer;
+    auto const& stub_buffer = stub_screencast->stub_buffer;
+
+    EXPECT_CALL(*graphics_platform, fill_ipc_package(_, &stub_buffer))
+        .Times(0);
+
+    mediator.screencast_buffer(nullptr, &screencast_id,
+                               &protobuf_buffer, null_callback.get());
+
+    EXPECT_EQ(stub_buffer.id().as_uint32_t(),
+              protobuf_buffer.buffer_id());
+}
