@@ -16,11 +16,11 @@
  * Authored by: Alexandros Frantzis <alexandros.frantzis@canonical.com>
  */
 
-#include "mir/graphics/graphic_buffer_allocator.h"
 #include "mir/frontend/session_mediator_report.h"
-#include "mir/frontend/session_mediator.h"
-#include "mir/frontend/resource_cache.h"
-#include "mir/shell/application_session.h"
+#include "src/server/frontend/session_mediator.h"
+#include "src/server/frontend/resource_cache.h"
+#include "src/server/scene/application_session.h"
+#include "src/server/report/null_report_factory.h"
 #include "mir/frontend/shell.h"
 #include "mir/shell/surface_creation_parameters.h"
 #include "mir/graphics/display.h"
@@ -32,6 +32,8 @@
 #include "mir_test_doubles/stub_shell.h"
 #include "mir_test_doubles/null_platform.h"
 #include "mir_test_doubles/null_event_sink.h"
+#include "mir_test_doubles/stub_buffer_allocator.h"
+#include "mir_test_doubles/null_screencast.h"
 
 #include <gtest/gtest.h>
 
@@ -43,37 +45,24 @@ namespace geom = mir::geometry;
 namespace mp = mir::protobuf;
 namespace msh = mir::shell;
 namespace mtd = mir::test::doubles;
+namespace mr = mir::report;
 
 namespace
 {
 
-class StubGraphicBufferAllocator : public mg::GraphicBufferAllocator
-{
-public:
-    std::shared_ptr<mg::Buffer> alloc_buffer(mg::BufferProperties const&)
-    {
-        return std::shared_ptr<mg::Buffer>();
-    }
-
-    virtual std::vector<geom::PixelFormat> supported_pixel_formats()
-    {
-        return std::vector<geom::PixelFormat>();
-    }
-};
-
 struct SessionMediatorAndroidTest : public ::testing::Test
 {
     SessionMediatorAndroidTest()
         : shell{std::make_shared<mtd::StubShell>()},
           graphics_platform{std::make_shared<mtd::NullPlatform>()},
           display_changer{std::make_shared<mtd::NullDisplayChanger>()},
-          buffer_allocator{std::make_shared<StubGraphicBufferAllocator>()},
-          report{std::make_shared<mf::NullSessionMediatorReport>()},
+          surface_pixel_formats{mir_pixel_format_argb_8888, mir_pixel_format_xrgb_8888},
+          report{mr::null_session_mediator_report()},
           resource_cache{std::make_shared<mf::ResourceCache>()},
-          mediator{shell, graphics_platform, display_changer,
-                   buffer_allocator, report,
+          mediator{__LINE__, shell, graphics_platform, display_changer,
+                   surface_pixel_formats, report,
                    std::make_shared<mtd::NullEventSink>(),
-                   resource_cache},
+                   resource_cache, std::make_shared<mtd::NullScreencast>()},
           null_callback{google::protobuf::NewPermanentCallback(google::protobuf::DoNothing)}
     {
     }
@@ -81,7 +70,7 @@ struct SessionMediatorAndroidTest : public ::testing::Test
     std::shared_ptr<mtd::StubShell> const shell;
     std::shared_ptr<mtd::NullPlatform> const graphics_platform;
     std::shared_ptr<mf::DisplayChanger> const display_changer;
-    std::shared_ptr<mg::GraphicBufferAllocator> const buffer_allocator;
+    std::vector<MirPixelFormat> const surface_pixel_formats;
     std::shared_ptr<mf::SessionMediatorReport> const report;
     std::shared_ptr<mf::ResourceCache> const resource_cache;
     mf::SessionMediator mediator;
