@@ -16,7 +16,7 @@
  * Authored by: Kevin DuBois <kevin.dubois@canonical.com>
  */
 
-#include "src/server/graphics/android/android_alloc_adaptor.h"
+#include "src/platform/graphics/android/android_alloc_adaptor.h"
 #include "mir/graphics/android/native_buffer.h"
 
 #include "mir_test_doubles/mock_android_alloc_device.h"
@@ -48,7 +48,7 @@ public:
 
         alloc_adaptor = std::make_shared<mga::AndroidAllocAdaptor>(mock_alloc_device);
 
-        pf = geom::PixelFormat::abgr_8888;
+        pf = mir_pixel_format_abgr_8888;
         size = geom::Size{300, 200};
         usage = mga::BufferUsage::use_hardware;
     }
@@ -56,7 +56,7 @@ public:
     std::shared_ptr<mtd::MockAllocDevice> mock_alloc_device;
     std::shared_ptr<mga::AndroidAllocAdaptor> alloc_adaptor;
 
-    geom::PixelFormat pf;
+    MirPixelFormat pf;
     geom::Size size;
     mga::BufferUsage usage;
     int const fb_usage_flags;
@@ -197,7 +197,7 @@ TEST_F(AdaptorICSTest, handle_buffer_pf_is_converted_to_android_abgr_8888)
 
 TEST_F(AdaptorICSTest, handle_buffer_pf_is_converted_to_android_xbgr_8888)
 {
-    auto native_handle = alloc_adaptor->alloc_buffer(size, geom::PixelFormat::xbgr_8888, usage);
+    auto native_handle = alloc_adaptor->alloc_buffer(size, mir_pixel_format_xbgr_8888, usage);
     auto anwb = native_handle->anwb();
     EXPECT_EQ(HAL_PIXEL_FORMAT_RGBX_8888, anwb->format);
 }
@@ -236,7 +236,7 @@ TEST_F(AdaptorICSTest, handle_has_right_magic)
 
 TEST_F(AdaptorICSTest, handle_has_version)
 {
-    int version = 96;  /* version value shared by JB and ICS */
+    int version = sizeof(ANativeWindowBuffer);  /* version value shared by JB and ICS */
     auto native_handle = alloc_adaptor->alloc_buffer(size, pf, usage);
     auto anwb = native_handle->anwb();
     EXPECT_EQ(version, anwb->common.version);
