@@ -16,7 +16,7 @@
  * Authored by: Kevin DuBois <kevin.dubois@canonical.com>
  */
 
-#include "src/server/graphics/android/buffer.h"
+#include "src/platform/graphics/android/buffer.h"
 #include "mir/graphics/egl_extensions.h"
 #include "mir_test_doubles/mock_egl.h"
 #include "mir_test_doubles/mock_fence.h"
@@ -38,24 +38,17 @@ public:
     {
         using namespace testing;
 
-        mock_native_buffer = std::make_shared<mtd::MockAndroidNativeBuffer>();
+        mock_native_buffer = std::make_shared<NiceMock<mtd::MockAndroidNativeBuffer>>();
         size = geom::Size{300, 220};
-        pf = geom::PixelFormat::abgr_8888;
+        pf = mir_pixel_format_abgr_8888;
         extensions = std::make_shared<mg::EGLExtensions>();
-
-        mock_egl.silence_uninteresting();
     };
-    virtual void TearDown()
-    {
-        buffer.reset();
-    }
 
     geom::Size size;
-    geom::PixelFormat pf;
+    MirPixelFormat pf;
 
-    mtd::MockEGL mock_egl;
+    testing::NiceMock<mtd::MockEGL> mock_egl;
     std::shared_ptr<mg::EGLExtensions> extensions;
-    std::shared_ptr<mga::Buffer> buffer;
     std::shared_ptr<mtd::MockAndroidNativeBuffer> mock_native_buffer;
 };
 
@@ -108,7 +101,8 @@ TEST_F(AndroidBufferBinding, buffer_anwb_is_bound)
 TEST_F(AndroidBufferBinding, buffer_makes_new_image_with_new_display)
 {
     using namespace testing;
-    EGLDisplay second_fake_display = (EGLDisplay) ((int)mock_egl.fake_egl_display +1);
+    EGLDisplay second_fake_display =
+        reinterpret_cast<EGLDisplay>(&second_fake_display);
 
     /* return 1st fake display */
     EXPECT_CALL(mock_egl, eglCreateImageKHR(_,_,_,_,_))
@@ -128,7 +122,8 @@ TEST_F(AndroidBufferBinding, buffer_makes_new_image_with_new_display)
 TEST_F(AndroidBufferBinding, buffer_frees_images_it_makes)
 {
     using namespace testing;
-    EGLDisplay second_fake_display = (EGLDisplay) ((int)mock_egl.fake_egl_display +1);
+    EGLDisplay second_fake_display =
+        reinterpret_cast<EGLDisplay>(&second_fake_display);
 
     EXPECT_CALL(mock_egl, eglDestroyImageKHR(_,_))
         .Times(Exactly(2));
@@ -148,9 +143,12 @@ TEST_F(AndroidBufferBinding, buffer_frees_images_it_makes_with_proper_args)
     using namespace testing;
 
     EGLDisplay first_fake_display = mock_egl.fake_egl_display;
-    EGLImageKHR first_fake_egl_image = (EGLImageKHR) 0x84210;
-    EGLDisplay second_fake_display = (EGLDisplay) ((int)mock_egl.fake_egl_display +1);
-    EGLImageKHR second_fake_egl_image = (EGLImageKHR) 0x84211;
+    EGLImageKHR first_fake_egl_image =
+        reinterpret_cast<EGLImageKHR>(&first_fake_egl_image);
+    EGLDisplay second_fake_display =
+        reinterpret_cast<EGLDisplay>(&second_fake_display);
+    EGLImageKHR second_fake_egl_image =
+        reinterpret_cast<EGLImageKHR>(&second_fake_egl_image);
 
     /* actual expectations */
     EXPECT_CALL(mock_egl, eglDestroyImageKHR(first_fake_display, first_fake_egl_image))
@@ -328,8 +326,10 @@ TEST_F(AndroidBufferBinding, buffer_binding_uses_right_image)
 TEST_F(AndroidBufferBinding, buffer_binding_uses_right_image_after_display_swap)
 {
     using namespace testing;
-    EGLDisplay second_fake_display = (EGLDisplay) ((int)mock_egl.fake_egl_display +1);
-    EGLImageKHR second_fake_egl_image = (EGLImageKHR) 0x84211;
+    EGLDisplay second_fake_display =
+        reinterpret_cast<EGLDisplay>(&second_fake_display);
+    EGLImageKHR second_fake_egl_image =
+        reinterpret_cast<EGLImageKHR>(&second_fake_egl_image);
 
     EXPECT_CALL(mock_egl, glEGLImageTargetTexture2DOES(_, _))
         .Times(Exactly(1));
@@ -356,3 +356,37 @@ TEST_F(AndroidBufferBinding, bind_to_texture_waits_on_fence)
     mga::Buffer buffer(mock_native_buffer, extensions);
     buffer.bind_to_texture();
 }
+
+TEST_F(AndroidBufferBinding, different_egl_contexts_displays_generate_new_eglimages)
+{
+    using namespace testing;
+
+    int d1 = 0, d2 = 0, c1 = 0, c2 = 0;
+    EGLDisplay disp1 = reinterpret_cast<EGLDisplay>(&d1);
+    EGLDisplay disp2 = reinterpret_cast<EGLDisplay>(&d2);
+    EGLContext ctxt1 = reinterpret_cast<EGLContext>(&c1);
+    EGLContext ctxt2 = reinterpret_cast<EGLContext>(&c2);
+
+    EXPECT_CALL(mock_egl, eglGetCurrentDisplay())
+        .Times(3)
+        .WillOnce(Return(disp1))
+        .WillOnce(Return(disp1))
+        .WillOnce(Return(disp2));
+
+    EXPECT_CALL(mock_egl, eglGetCurrentContext())
+        .Times(3)
+        .WillOnce(Return(ctxt1))
+        .WillRepeatedly(Return(ctxt2));
+
+    EXPECT_CALL(mock_egl, eglCreateImageKHR(disp1,_,_,_,_))
+        .Times(2);
+    EXPECT_CALL(mock_egl, eglCreateImageKHR(disp2,_,_,_,_))
+        .Times(1);
+    EXPECT_CALL(mock_egl, eglDestroyImageKHR(_,_))
+        .Times(Exactly(3));
+
+    mga::Buffer buffer(mock_native_buffer, extensions);
+    buffer.bind_to_texture();
+    buffer.bind_to_texture();
+    buffer.bind_to_texture();
+}
