@@ -16,7 +16,7 @@
  * Authored by: Kevin DuBois <kevin.dubois@canonical.com>
  */
 
-#include "src/server/graphics/android/interpreter_cache.h"
+#include "src/platform/graphics/android/interpreter_cache.h"
 #include "mir_test_doubles/stub_buffer.h"
 #include "mir_test_doubles/mock_android_native_buffer.h"
 
@@ -34,7 +34,7 @@ struct InterpreterResourceTest : public ::testing::Test
         stub_buffer1 = std::make_shared<mtd::StubBuffer>();
         stub_buffer2 = std::make_shared<mtd::StubBuffer>();
         stub_buffer3 = std::make_shared<mtd::StubBuffer>();
-        native_buffer1 = std::make_shared<mtd::MockAndroidNativeBuffer>();
+        native_buffer1 = std::make_shared<testing::NiceMock<mtd::MockAndroidNativeBuffer>>();
         native_buffer2 = std::make_shared<mtd::StubAndroidNativeBuffer>();
         native_buffer3 = std::make_shared<mtd::StubAndroidNativeBuffer>();
     }
