@@ -17,31 +17,34 @@
  */
 
 #include "mir/graphics/display.h"
+#include "mir/graphics/display_configuration.h"
 #include "mir/graphics/gl_context.h"
+#include "mir/options/program_option.h"
 
 #include "mir_test_doubles/mock_egl.h"
 #include "mir_test_doubles/mock_gl.h"
+#include "mir_test_doubles/stub_gl_config.h"
+#include "src/server/graphics/default_display_configuration_policy.h"
 #ifndef ANDROID
 #include "mir_test_doubles/mock_drm.h"
 #include "mir_test_doubles/mock_gbm.h"
 #include "mir_test_doubles/null_virtual_terminal.h"
-#include "src/server/graphics/gbm/gbm_platform.h"
+#include "src/platform/graphics/mesa/platform.h"
 #include "mir_test_framework/udev_environment.h"
-#include "mir/graphics/default_display_configuration_policy.h"
 #else
-#include "src/server/graphics/android/android_framebuffer_window_query.h"
-#include "src/server/graphics/android/android_display.h"
-#include "src/server/graphics/android/gpu_android_display_buffer_factory.h"
-#include "mir_test_doubles/stub_display_support_provider.h"
+#include "src/platform/graphics/android/android_platform.h"
 #include "mir_test_doubles/mock_android_hw.h"
+#include "mir_test_doubles/mock_display_device.h"
 #endif
 
-#include "mir/graphics/null_display_report.h"
+#include "src/server/report/null_report_factory.h"
 
 #include <gtest/gtest.h>
+#include <gmock/gmock.h>
 
 namespace mg = mir::graphics;
 namespace mtd = mir::test::doubles;
+namespace mr = mir::report;
 #ifndef ANDROID
 namespace mtf = mir::mir_test_framework;
 #endif
@@ -67,37 +70,24 @@ public:
             .WillByDefault(Return(reinterpret_cast<const GLubyte*>(gl_exts)));
 
 #ifndef ANDROID
-        fake_devices.add_standard_drm_devices();
+        fake_devices.add_standard_device("standard-drm-devices");
 #endif
     }
 
     std::shared_ptr<mg::Display> create_display()
     {
+        auto report = mr::null_display_report();
 #ifdef ANDROID
-        struct StubAndroidFramebufferWindowQuery : public mg::android::AndroidFramebufferWindowQuery
-        {
-            EGLNativeWindowType android_native_window_type() const
-            {
-                return reinterpret_cast<EGLNativeWindowType>(0x123);
-            }
-            EGLConfig android_display_egl_config(EGLDisplay) const
-            {
-                return reinterpret_cast<EGLConfig>(0x789);
-            }
-        };
-
-        return std::make_shared<mg::android::AndroidDisplay>(
-            std::make_shared<StubAndroidFramebufferWindowQuery>(),
-            std::make_shared<mg::android::GPUAndroidDisplayBufferFactory>(),
-            std::make_shared<mtd::StubDisplaySupportProvider>(),
-            std::make_shared<mg::NullDisplayReport>());
+        auto platform = mg::create_platform(
+            std::make_shared<mir::options::ProgramOption>(),
+            report);
 #else
-        auto platform = std::make_shared<mg::gbm::GBMPlatform>(
-            std::make_shared<mg::NullDisplayReport>(),
+        auto platform = std::make_shared<mg::mesa::Platform>(report,
             std::make_shared<mir::test::doubles::NullVirtualTerminal>());
-        auto conf_policy = std::make_shared<mg::DefaultDisplayConfigurationPolicy>();
-        return platform->create_display(conf_policy);
 #endif
+        return platform->create_display(
+            std::make_shared<mg::DefaultDisplayConfigurationPolicy>(),
+            std::make_shared<mtd::StubGLConfig>());
     }
 
     ::testing::NiceMock<mtd::MockEGL> mock_egl;
@@ -111,6 +101,38 @@ public:
 #endif
 };
 
+namespace
+{
+
+class MockDisplayConfiguration : public mg::DisplayConfiguration
+{
+public:
+    MOCK_CONST_METHOD1(for_each_card,
+        void(std::function<void(mg::DisplayConfigurationCard const&)>));
+    MOCK_CONST_METHOD1(for_each_output,
+        void(std::function<void(mg::DisplayConfigurationOutput const&)>));
+    MOCK_METHOD1(for_each_output,
+        void(std::function<void(mg::UserDisplayConfigurationOutput&)>));
+    MOCK_CONST_METHOD0(valid, bool());
+};
+
+}
+
+TEST_F(DisplayTest, configure_disallows_invalid_configuration)
+{
+    using namespace testing;
+    auto display = create_display();
+    MockDisplayConfiguration config;
+
+    EXPECT_CALL(config, valid())
+        .WillOnce(Return(false));
+
+    EXPECT_THROW({display->configure(config);}, std::logic_error);
+
+    // Determining what counts as a valid configuration is a much trickier
+    // platform-dependent exercise, so won't be tested here.
+}
+
 TEST_F(DisplayTest, gl_context_make_current_uses_shared_context)
 {
     using namespace testing;
