@@ -35,8 +35,8 @@ TEST(AndroidInputChannel, packages_own_valid_fds)
 
         server_fd = package.server_fd();
         client_fd = package.client_fd();
-        EXPECT_GT(server_fd, 0);
-        EXPECT_GT(client_fd, 0);
+        EXPECT_LE(0, server_fd);
+        EXPECT_LE(0, client_fd);
 
         EXPECT_EQ(fcntl(server_fd, F_GETFD), 0);
         EXPECT_EQ(fcntl(client_fd, F_GETFD), 0);
